This patch is against ISODE 8.0.1. If you don't have ISODE 8.0 or the
patch 1 for it they can be found on src.doc.ic.ac.uk:packages/isode
among other archives.

  The major part of this adds support for building a Linux DLL library
to the makefiles. Do ./make first. This will build libraries, pepsy,
pepy etc. as normal. Then do ./make linux-libs to build the shared
library. It isn't clean, it isn't neat. You will probably have to do some
fudging by hand. A shared library is worth it though unless you have
gigabytes of free disk space to waste :-).

  There are also changes to add termios support to various places, POSIX
changes etc. However it is mostly a case of making some good choices in
the config.h and config.make files, see config/linux.*. Async mode is
done with the isore kludge. I looked at putting SIGIO in the Linux kernel
and decided this was not a trivial job. PP requires async mode so isore
is the only choice.

  These patches get most things working to a reasonable-ish degree I think.
Certainly quipu, dish, pod seem happy, the problem is in figuring out how
to set them up if you don't have much experience. The ISODE documentation
is not supplied with ISODE 8.0 - you need the documentation from one of
the earlier distributions. The documentation comes in the form of several
big, thick manuals in TeX format. These are development oriented rather
than end-user oriented though :-).

  PP still has problems. In particular qmgr bombs with a sig 11 apparently
due to heap corruption. Unfortunately this *only* happens with the libc
malloc and not my debugging malloc which detects no invalid pointers,
over/underruns, chain corruption etc. Given the rate libc malloc keeps
moving at the moment this problem isn't exactly amenable to solution
right now...

  You want a fair amount of memory to run ISODE. I have 16MB. 8MB is
swapsville. For ISODE development I wouldn't recommend less than 16MB.
I wish I had more :-(.

  This is *ALPHA*. It might change drastically for no apparent reason.
It hasn't for quite a while but then I haven't been working on it for
quite a while :-).

  I'll try and put some packages of binaries together at some stage too
perhaps...


  Mike Jagdis <jaggy@purplet.demon.co.uk>



diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/Makefile isode-8.0/Makefile
--- old/isode-8.0/Makefile	Tue Jun 16 13:05:02 1992
+++ isode-8.0/Makefile	Fri Aug 27 14:52:35 1993
@@ -31,7 +31,12 @@
 ##################################################################
 
 LIBDIRS	=	h compat dirent tsap ssap psap pepsy pepy psap2 \
-		acsap rosap rtsap ronot rosy 
+		acsap rosap rtsap ronot rosy
+# If you don't want lpp use psap2 instead of psap2-lpp
+LINUXISODE=	rosy ronot rosap rtsap acsap psap2 pepy pepsy psap \
+		ssap tsap dirent compat support
+LINUXDSAP=	dsap
+LINUXFTAM=	ftam
 DIRS	=	$(LIBDIRS) support imisc
 OTHERS	=	dsap ftam ftam2 ftam-ftp ftp-ftam others psap2-lpp quipu \
 		snmp vt
@@ -41,6 +46,26 @@
 		    do (echo "cd $$i; $(MAKE) all"; \
 			      cd $$i; $(MAKE) all); \
 		    done
+
+linux-libs:
+		@for i in $(LINUXISODE); \
+			do (echo "cd $$i; $(MAKE) linux-lib"; \
+				cd $$i; \
+				JUMP_DIR=../jump/ JUMP_LIB=libisode \
+				JUMP_OPT=-B/usr/dll/jump/ $(MAKE) linux-lib); \
+			done
+		@for i in $(LINUXDSAP); \
+			do (echo "cd $$i; $(MAKE) linux-lib"; \
+				cd $$i; \
+				JUMP_DIR=../jump/ JUMP_LIB=libdsap \
+				JUMP_OPT=-B/usr/dll/jump/ $(MAKE) linux-lib); \
+			done
+		@for i in $(LINUXFTAM); \
+			do (echo "cd $$i; $(MAKE) linux-lib"; \
+				cd $$i; \
+				JUMP_DIR=../jump/ JUMP_LIB=libftam \
+				JUMP_OPT=-B/usr/dll/jump/ $(MAKE) linux-lib); \
+			done
 
 inst-all:	make-dirs
 		@for i in $(DIRS); \
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/acsap/Makefile isode-8.0/acsap/Makefile
--- old/isode-8.0/acsap/Makefile	Tue Jun 16 13:05:59 1992
+++ isode-8.0/acsap/Makefile	Wed Aug 25 14:27:10 1993
@@ -84,6 +84,20 @@
 
 inst-libacsap:	$(LIBDIR)libacsap.a $(LINTDIR)llib-lacsap
 
+zap-acsap:
+		-rm -f $(OFILES) libacsap.a \
+			ACS_tables.o OACS_tables.o DSE_tables.o DASE_tables.o \
+			acsapvrsn.o
+
+linux-lib:	zap-acsap ../jump/libacsap.a
+
+../jump/libacsap.a:	libacsap
+		-rm -f $@
+		cp libacsap.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libacsap.a:	libacsap.a
 		-rm -f $@
 		cp libacsap.a $@
@@ -234,6 +248,7 @@
 		-@echo ""
 
 dased:		xdased
+		:
 
 xdased:		dased.o DASE_tables.o $(TOPDIR)libdsap.a $(TOPDIR)libisode.a
 		$(LDCC) $(LDFLAGS) -o $@ dased.o DASE_tables.o \
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/compat/Makefile isode-8.0/compat/Makefile
--- old/isode-8.0/compat/Makefile	Tue Jun 16 13:07:00 1992
+++ isode-8.0/compat/Makefile	Tue Aug 24 11:53:55 1993
@@ -79,6 +79,18 @@
 
 inst-libcompat:	$(LIBDIR)libicompat.a $(LINTDIR)llib-licompat
 
+zap-compat:
+		-rm -f $(OFILES) libcompat.a compatvrsn.o
+
+linux-lib:	zap-compat ../jump/libcompat.a
+
+../jump/libcompat.a:	libcompat.a
+		-rm -f $@
+		cp libcompat.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libicompat.a:	libcompat.a
 		-rm -f $@
 		cp libcompat.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/compat/asprintf.c isode-8.0/compat/asprintf.c
--- old/isode-8.0/compat/asprintf.c	Tue Jun 16 13:07:00 1992
+++ isode-8.0/compat/asprintf.c	Wed May 26 17:10:05 1993
@@ -27,8 +27,9 @@
 
 /* LINTLIBRARY */
 
-#include <stdio.h>
 #include <varargs.h>
+#define _STDARG_H
+#include <stdio.h>
 #include "general.h"
 #include "manifest.h"
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/compat/general.c isode-8.0/compat/general.c
--- old/isode-8.0/compat/general.c	Tue Jun 16 13:07:06 1992
+++ isode-8.0/compat/general.c	Mon Aug 23 10:05:08 1993
@@ -79,7 +79,7 @@
 
 /*    DUP2 */
 
-#ifndef	BSD42
+#if !defined(BSD42) && !defined(__linux__)
 #ifdef	SYS5
 #include <fcntl.h>
 #endif
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/compat/getpassword.c isode-8.0/compat/getpassword.c
--- old/isode-8.0/compat/getpassword.c	Tue Jun 16 13:07:06 1992
+++ isode-8.0/compat/getpassword.c	Thu Aug 19 12:45:14 1993
@@ -32,6 +32,9 @@
 #include "general.h"
 #include "manifest.h"
 #include "sys.file.h"
+#ifdef _POSIX_SOURCE
+#include <termios.h>
+#endif
 
 #ifdef	BSD44
 char   *getpass ();
@@ -51,7 +54,11 @@
     register char  *bp,
 		   *ep;
 #if	!defined(SYS5) && !defined(XOS_2)
+#if defined(_POSIX_SOURCE)
+    struct termios  sg;
+#else
     struct sgttyb   sg;
+#endif
 #else
     struct termio   sg;
 #endif
@@ -75,10 +82,17 @@
     istat = signal (SIGINT, SIG_IGN);
 
 #if	!defined(SYS5) && !defined(XOS_2)
+#if defined(_POSIX_SOURCE)
+    tcgetattr (fileno (fp), &sg);
+    flags = sg.c_lflag;
+    sg.c_lflag &= ~ECHO;
+    tcsetattr (fileno (fp), TCSADRAIN, &sg);
+#else
     (void) gtty (fileno (fp), &sg);
     flags = sg.sg_flags;
     sg.sg_flags &= ~ECHO;
     (void) stty (fileno (fp), &sg);
+#endif
 #else
     (void) ioctl (fileno (fp), TCGETA, (char *) &sg);
     flags = sg.c_lflag;
@@ -115,8 +129,13 @@
 #endif
 
 #if	!defined(SYS5) && !defined(XOS_2)
+#if defined(_POSIX_SOURCE)
+    sg.c_lflag = flags;	
+    tcsetattr (fileno (fp), TCSADRAIN, &sg);
+#else
     sg.sg_flags = flags;
     (void) stty (fileno (fp), &sg);
+#endif
 #else
     sg.c_lflag = flags;
     (void) ioctl (fileno (fp), TCSETAW, (char *) &sg);
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/compat/internet.c isode-8.0/compat/internet.c
--- old/isode-8.0/compat/internet.c	Tue Jun 16 13:07:09 1992
+++ isode-8.0/compat/internet.c	Tue Sep  7 11:49:18 1993
@@ -178,7 +178,7 @@
     }
 
 got_socket: ;
-#if	!defined(BSD43) && !defined(SVR4)
+#if	!defined(BSD43) && !defined(SVR4) && !defined(__linux__)
     if (setsockopt (sd, SOL_SOCKET, SO_KEEPALIVE, NULLCP, 0) == NOTOK)
 	SLOG (compat_log, LLOG_EXCEPTIONS, "failed", ("set SO_KEEPALIVE"));
     if (opt1 && setsockopt (sd, SOL_SOCKET, opt1, NULLCP, 0) == NOTOK)
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/compat/logger.c isode-8.0/compat/logger.c
--- old/isode-8.0/compat/logger.c	Tue Jun 16 13:07:16 1992
+++ isode-8.0/compat/logger.c	Wed May 26 17:08:46 1993
@@ -27,8 +27,9 @@
 
 /* LINTLIBRARY */
 
-#include <stdio.h>
 #include <varargs.h>
+#define _STDARG_H
+#include <stdio.h>
 #include "general.h"
 #include "manifest.h"
 #include "logger.h"
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/compat/putenv.c isode-8.0/compat/putenv.c
--- old/isode-8.0/compat/putenv.c	Tue Jun 16 13:07:19 1992
+++ isode-8.0/compat/putenv.c	Thu Aug 19 12:58:10 1993
@@ -31,6 +31,8 @@
 #include "general.h"
 #include "manifest.h"
 
+#ifndef _POSIX_SOURCE
+
 /*  */
 
 extern  char **environ;
@@ -104,3 +106,5 @@
 
     return (*s1 == '\0' && *--s2 == '=');
 }
+
+#endif /* _POSIX_SOURCE */
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/compat/strdup.c isode-8.0/compat/strdup.c
--- old/isode-8.0/compat/strdup.c	Tue Jun 16 13:07:33 1992
+++ isode-8.0/compat/strdup.c	Mon Aug 23 10:14:50 1993
@@ -33,7 +33,7 @@
 #include "tailor.h"
 
 /*  */
-#if !defined(SVR4) || defined(_AIX)
+#if (!defined(SVR4) && !defined(__linux__)) || defined(_AIX)
                       /* strdup in AIX does not seem to use QUIPUs malloc! */
 
 char   *strdup (str)
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/config/linux.h isode-8.0/config/linux.h
--- old/isode-8.0/config/linux.h	Thu Jan  1 01:00:00 1970
+++ isode-8.0/config/linux.h	Fri Sep 10 16:00:21 1993
@@ -0,0 +1,30 @@
+#ifndef	_CONFIG_
+#define	_CONFIG_
+
+#define WRITEV
+#define SVR4_UCB		/* we have some of these bits too */
+#define LINUX			/* more strictly Linux */
+
+#define BSDSIGS			/* BSD style signals work. */
+
+#undef	SIGPOLL			/* None of these actual work... */
+#undef	SIGIO
+#undef	SIGURG
+#undef	SIGEMT
+
+#define BSDLIBC			/* We have the BSD insque/remque. */
+#define SWAPLIB			/* Can swap between local and net byte order */
+#define SHADOW_PW		/* use shadow password file */
+#define VSPRINTF
+#define TEMPNAM
+
+#define GETDENTS
+#define NFS			/* NFS implies GETDENTS too I think. */
+
+#define	TCP			/* has TCP/IP (of course) */
+#define	SOCKETS			/*   provided by sockets */
+#define BIND
+
+#define RFINGER "/usr/bin/finger"
+
+#endif
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/config/linux.make isode-8.0/config/linux.make
--- old/isode-8.0/config/linux.make	Thu Jan  1 01:00:00 1970
+++ isode-8.0/config/linux.make	Thu Aug 26 16:25:07 1993
@@ -0,0 +1,86 @@
+###############################################################################
+#   Instructions to Make, for compilation of ISODE processes for 4.3BSD UNIX
+###############################################################################
+
+###############################################################################
+#
+# $Header: /xtel/isode/isode/config/RCS/bsd43.make,v 9.0 1992/06/16 12:08:13 isode Rel $
+#
+#
+# $Log: bsd43.make,v $
+# Revision 9.0  1992/06/16  12:08:13  isode
+# Release 8.0
+#
+#
+###############################################################################
+
+###############################################################################
+#
+#				 NOTICE
+#
+#    Acquisition, use, and distribution of this module and related
+#    materials are subject to the restrictions of a license agreement.
+#    Consult the Preface in the User's Manual for the full terms of
+#    this agreement.
+#
+###############################################################################
+
+
+###############################################################################
+# Options
+###############################################################################
+
+OPTIONS	=	-I. -I$(TOPDIR)h $(PEPYPATH) $(KRBOPT)
+
+HDIR	=	$(TOPDIR)h/
+UTILDIR	=	$(TOPDIR)util/
+BINDIR	=	/usr/local/bin/
+SBINDIR	=	/usr/etc/
+ETCDIR	=	/usr/etc/
+LOGDIR	=	/usr/tmp/
+INCDIRM	=	/usr/include/isode
+INCDIR	=	$(INCDIRM)/
+PEPYDIRM=	$(INCDIR)pepy
+PEPYDIR	=	$(PEPYDIRM)/
+PEPSYDIRM=	$(INCDIR)pepsy
+PEPSYDIR=	$(PEPSYDIRM)/
+LIBDIR	=	/usr/lib/
+LINTDIR	=	/usr/lib/lint/
+
+LIBISODE=	$(TOPDIR)libisode.a
+LIBDSAP	=	$(TOPDIR)libdsap.a
+
+SYSTEM	=	-bsd42
+MANDIR	=	/usr/man/
+MANOPTS	=	-bsd42
+
+
+###############################################################################
+# Programs and Libraries
+###############################################################################
+
+MAKE	=	./make DESTDIR=$(DESTDIR) $(MFLAGS) -k
+SHELL	=	/bin/sh
+
+CC      =	cc $(JUMP_OPT)
+CFLAGS  =	-O6 -fomit-frame-pointer -m486 -D__STDC__=1 -D__USE_BSD_SIGNALS $(OPTIONS)
+LIBCFLAGS=	      $(CFLAGS)
+LINT    =	lint
+LFLAGS  =	-bhuz $(OPTIONS)
+LD	=	ld
+LDCC	=	$(CC)
+LDFLAGS =	-s
+ARFLAGS	=
+
+LN	=	ln
+
+LSOCKET	=	$(KRBLIB) -lshadow -ldbm -lm
+
+
+###############################################################################
+# Generation Rules for library modules
+###############################################################################
+
+.c.o:;		$(CC) $(LIBCFLAGS) -c $*.c
+		-ld -x -r $@
+		mv a.out $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/dirent/Makefile isode-8.0/dirent/Makefile
--- old/isode-8.0/dirent/Makefile	Tue Jun 16 11:17:26 1992
+++ isode-8.0/dirent/Makefile	Tue Aug 24 11:53:42 1993
@@ -45,6 +45,18 @@
 
 inst-libdirent:	$(LIBDIR)libdirent.a $(LINTDIR)llib-ldirent
 
+zap-dirent:
+		-rm -f $(OFILES) libdirent.a direntvrsn.o
+
+linux-lib:	zap-dirent ../jump/libdirent.a
+
+../jump/libdirent.a:	libdirent.a
+		-rm -f $@
+		cp libdirent.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libdirent.a:	libdirent.a
 		-rm -f $@
 		cp libdirent.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/dirent/scandir.c isode-8.0/dirent/scandir.c
--- old/isode-8.0/dirent/scandir.c	Tue Jun 16 11:17:27 1992
+++ isode-8.0/dirent/scandir.c	Fri Dec  3 13:27:01 1993
@@ -19,6 +19,8 @@
  * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
+#ifndef __linux__
+
 #if defined(LIBC_SCCS) && !defined(lint)
 static char sccsid[] = "@(#)scandir.c	5.9 (Berkeley) 6/24/90";
 #endif /* LIBC_SCCS and not lint */
@@ -121,3 +123,8 @@
 	return(strcmp((*(struct dirent **)d1)->d_name,
 	    (*(struct dirent **)d2)->d_name));
 }
+
+#else
+int	_scandir_stub () {;}
+int	_alphasort_stub () {;}
+#endif
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/dsap/Makefile isode-8.0/dsap/Makefile
--- old/isode-8.0/dsap/Makefile	Tue Jun 16 13:12:27 1992
+++ isode-8.0/dsap/Makefile	Wed Aug 25 08:35:46 1993
@@ -48,6 +48,16 @@
 clean:		sub-clean
 	        rm -f lib*.a lib*.so* llib-l* _* *.tmp *.orig *.o z* dsapvrsn.c
 		rm -f libdsap-shared
+
+linux-lib:	dsap-linux linux-subs
+
+linux-subs:
+		@for i in $(DIRS); \
+			do (echo "cd $$i; $(MAKE) linux-lib"; \
+				cd $$i; \
+				JUMP_DIR=../../jump/ JUMP_LIB=libdsap \
+				JUMP_OPT=-B/usr/dll/jump/ $(MAKE) linux-lib); \
+			done
 sub-all:
 		@for i in $(DIRS); \
 		    do (echo "cd $$i; $(MAKE) all"; \
@@ -79,6 +89,18 @@
 inst-libdsap:   inst-headers $(LIBDIR)libdsap.a $(LINTDIR)llib-ldsap
 
 inst-headers:;	cd x500as; $(MAKE) inst-headers
+
+inst-libcompat:	$(LIBDIR)libicompat.a $(LINTDIR)llib-licompat
+
+zap-dsap:
+		-rm -f dsapvrsn.o
+
+dsap-linux:	zap-dsap ../jump/libdsap.a
+
+../jump/libdsap.a:	dsapvrsn.o
+		-rm -f $@
+		ar q $@ dsapvrsn.o
+		-@echo ""
 
 $(LIBDIR)libdsap.a:     libdsap.a
 		@for i in libdsap.* ;\
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/dsap/common/Makefile isode-8.0/dsap/common/Makefile
--- old/isode-8.0/dsap/common/Makefile	Tue Jun 16 13:12:40 1992
+++ isode-8.0/dsap/common/Makefile	Tue Aug 24 12:10:09 1993
@@ -128,6 +128,18 @@
 		$(LINT) $(LFLAGS) $(CFILES) $(LLIBS) \
 			| grep -v "warning: possible pointer alignment problem"
 
+zap-common:
+		-rm -f $(OFILES) libcommon.a commonvrsn.o
+
+linux-lib:	zap-common ../../jump/libcommon.a
+
+../../jump/libcommon.a:	libcommon.a
+		-rm -f $@
+		cp libcommon.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 test:		test.o libcommon.a ../libx500as.a
 		$(LDCC) $(LDFLAGS) test.o libcommon.a ../libx500as.a \
 			libcommon.a $(LIBISODE) -o test
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/dsap/common/integer.c isode-8.0/dsap/common/integer.c
--- old/isode-8.0/dsap/common/integer.c	Tue Jun 16 13:13:16 1992
+++ isode-8.0/dsap/common/integer.c	Fri Aug 20 10:52:48 1993
@@ -108,7 +108,9 @@
 static int * intparse (str)
 char * str;
 {
+#ifndef atoi
 int atoi();
+#endif
 int * x;
 
 	x = (int *) smalloc (sizeof (int));
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/dsap/net/Makefile isode-8.0/dsap/net/Makefile
--- old/isode-8.0/dsap/net/Makefile	Tue Jun 16 13:14:06 1992
+++ isode-8.0/dsap/net/Makefile	Tue Aug 24 12:11:13 1993
@@ -88,6 +88,18 @@
 netvrsn.c:      $(OFILES)
 		@$(UTILDIR)version.sh net > $@
 
+zap-net:
+		-rm -f $(OFILES) libnet.a netvrsn.o
+
+linux-lib:	zap-net ../../jump/libnet.a
+
+../../jump/libnet.a:	libnet.a
+		-rm -f $@
+		cp libnet.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 l-libnet:       $(CFILES) true
 		$(LINT) $(LFLAGS) $(CFILES) $(LLIBS) \
 			| grep -v "warning: possible pointer alignment problem"
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/dsap/x500as/Makefile isode-8.0/dsap/x500as/Makefile
--- old/isode-8.0/dsap/x500as/Makefile	Tue Jun 16 13:14:33 1992
+++ isode-8.0/dsap/x500as/Makefile	Tue Aug 24 12:08:21 1993
@@ -81,6 +81,18 @@
 l-libx500as:;	$(LINT) $(LFLAGS) $(CFILES) $(PEPY-C) $(LLIBS) \
 			| grep -v "warning: possible pointer alignment problem"
 
+zap-x500as:
+		-rm -f $(OFILES) libx500as.a x500asvrsn.o
+
+linux-lib:	zap-x500as ../../jump/libx500as.a
+
+../../jump/libx500as.a:	libx500as.a
+		-rm -f $@
+		cp libx500as.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 
 #######################################################
 # saber
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ftam/Makefile isode-8.0/ftam/Makefile
--- old/isode-8.0/ftam/Makefile	Tue Jun 16 13:14:56 1992
+++ isode-8.0/ftam/Makefile	Wed Aug 25 14:33:01 1993
@@ -78,6 +78,19 @@
 
 inst-libftam:	$(LIBDIR)libftam.a inst-headers $(LINTDIR)llib-lftam
 
+zap-ftam:
+		-rm -f $(OFILES) libftam.a \
+			CONT_tables.o FADU_tables.o FTAM_tables.o ftamvrsn.o
+
+linux-lib:	zap-ftam ../jump/libftam.a
+
+../jump/libftam.a:	libftam
+		-rm -f $@
+		cp libftam.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libftam.a:	libftam.a
 		-rm -f $@
 		cp libftam.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ftam2/Makefile isode-8.0/ftam2/Makefile
--- old/isode-8.0/ftam2/Makefile	Tue Jun 16 13:15:44 1992
+++ isode-8.0/ftam2/Makefile	Mon Aug 23 14:19:27 1993
@@ -72,6 +72,7 @@
 		-@echo ""
 
 ftamd:		xftamd
+		:
 
 xftamd:		ftamd.o ftamsystem.o ftamd-manage.o ftamd-select.o \
 			ftamd-trans.o ftamsbr.o DOCS_tables.o $(LIBD)
@@ -107,6 +108,7 @@
 		-@echo ""
 
 ftam:		xftam
+		:
 
 xftam:		ftam.o ftamuser.o ftam-assoc.o ftam-dir.o ftam-get.o \
 			ftam-glob.o ftam-ls.o ftam-mgmt.o ftam-put.o \
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ftam2/ftam-get.c isode-8.0/ftam2/ftam-get.c
--- old/isode-8.0/ftam2/ftam-get.c	Tue Jun 16 13:15:45 1992
+++ isode-8.0/ftam2/ftam-get.c	Fri Aug 20 12:56:07 1993
@@ -27,6 +27,9 @@
 
 #include <errno.h>
 #include <stdio.h>
+#ifdef _POSIX_SOURCE
+#include <unistd.h>
+#endif
 #include "ftamuser.h"
 
 /*  */
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ftam2/ftamd-select.c isode-8.0/ftam2/ftamd-select.c
--- old/isode-8.0/ftam2/ftamd-select.c	Tue Jun 16 13:15:49 1992
+++ isode-8.0/ftam2/ftamd-select.c	Fri Aug 20 12:42:19 1993
@@ -28,6 +28,9 @@
 #include <grp.h>
 #include <stdio.h>
 #include <pwd.h>
+#ifdef _POSIX_SOURCE
+#include <unistd.h>
+#endif
 #include "ftamsystem.h"
 
 
@@ -63,6 +66,10 @@
 #endif
 
 
+#if !defined(SYS5) && !defined(BRIDGE)
+static int  EACCESS ();
+#endif
+
 #ifdef	SYS5
 #define	EACCESS	access
 
@@ -1528,13 +1535,21 @@
 {
     int	    result;
 
+#ifdef _POSIX_SOURCE
+    (void) setreuid (myuid, 0);
+#else
     (void) seteuid (0);
     (void) setruid (myuid);
+#endif
 
     result = access (file, mode);
 
+#ifdef _POSIX_SOURCE
+    (void) setreuid (0, myuid);
+#else
     (void) setruid (0);
     (void) seteuid (myuid);
+#endif
 
     return result;
 }
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ftam2/ftamd-trans.c isode-8.0/ftam2/ftamd-trans.c
--- old/isode-8.0/ftam2/ftamd-trans.c	Tue Jun 16 13:15:50 1992
+++ isode-8.0/ftam2/ftamd-trans.c	Fri Aug 20 12:20:19 1993
@@ -31,6 +31,10 @@
 #include <sys/times.h>
 #define	TMS
 #endif
+#ifdef _POSIX_SOURCE
+#include <sys/times.h>
+#define TMS
+#endif
 
 /*    DATA */
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ftam2/ftamsystem.c isode-8.0/ftam2/ftamsystem.c
--- old/isode-8.0/ftam2/ftamsystem.c	Tue Jun 16 13:15:52 1992
+++ isode-8.0/ftam2/ftamsystem.c	Tue Aug 31 14:33:30 1993
@@ -44,6 +44,7 @@
 
 #ifdef SHADOW_PW
 #include <shadow.h>
+#include <shadow/pwauth.h>
 #endif
 
 #ifdef	SYS5
@@ -345,14 +346,23 @@
       else
           pw->pw_passwd = shad_res->sp_pwdp;
     }
-#endif /* SHADOW_PW */
-
 
+    if (!guest) {
+          if (pw->pw_passwd && pw->pw_passwd[0] == '@'
+          && pw_auth(pw->pw_passwd, pw->pw_name, PW_FTP, fts->fts_password)) {
+               seterr (FS_ACS_PASSWORD, EREF_RFSU, EREF_IFSU, "");
+          } else if (!valid(fts->fts_password, pw)) {
+               seterr (FS_ACS_PASSWORD, EREF_RFSU, EREF_IFSU, "");
+          }
+    }
+#else /* SHADOW_PW */
     if ((!guest && fts -> fts_password == NULL)
 	    || *pw -> pw_passwd == NULL
 	    || (!guest && !chkpassword (initiator, pw -> pw_passwd,
 					fts -> fts_password)))
 	seterr (FS_ACS_PASSWORD, EREF_RFSU, EREF_IFSU, "");
+#endif /* SHADOW_PW */
+
 
 #ifdef DEBUG
     advise (LLOG_DEBUG, NULLCP,
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ftam2/ftamuser.c isode-8.0/ftam2/ftamuser.c
--- old/isode-8.0/ftam2/ftamuser.c	Tue Jun 16 13:15:53 1992
+++ isode-8.0/ftam2/ftamuser.c	Fri Aug 20 12:54:35 1993
@@ -34,6 +34,10 @@
 #include <sys/times.h>
 #define	TMS
 #endif
+#ifdef _POSIX_SOURCE
+#include <sys/times.h>
+#define TMS
+#endif
 #ifdef	BSD42
 #include <sys/ioctl.h>
 #endif
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ftp-ftam/version isode-8.0/ftp-ftam/version
--- old/isode-8.0/ftp-ftam/version	Tue Jun 16 11:53:35 1992
+++ isode-8.0/ftp-ftam/version	Mon Aug 23 14:21:59 1993
@@ -1 +1 @@
-115
+117
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/h/general.h isode-8.0/h/general.h
--- old/isode-8.0/h/general.h	Wed Jun 17 11:32:31 1992
+++ isode-8.0/h/general.h	Thu Aug 19 10:08:42 1993
@@ -270,6 +270,7 @@
 
 /*  ntohs etc */
 
+#ifndef __linux__
 #ifndef	ntohs
 unsigned short	ntohs ();
 #endif
@@ -282,6 +283,7 @@
 #ifndef	htonl
 unsigned long	htonl ();
 #endif
+#endif /* __linux__ */
 
 int	char2bcd ();
 int	bcd2char ();
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/h/manifest.h isode-8.0/h/manifest.h
--- old/isode-8.0/h/manifest.h	Wed Jun 17 11:32:31 1992
+++ isode-8.0/h/manifest.h	Fri Sep 10 15:57:52 1993
@@ -200,7 +200,7 @@
 #include <sys/select.h>
 #endif
 
-#ifdef	SYS5NLY
+#ifdef SYS5NLY
 typedef unsigned char	u_char;
 typedef unsigned short	u_short;
 typedef unsigned int	u_int;
@@ -303,7 +303,7 @@
 /*    POSIX */
 
 #ifndef	SETSID
-#if	defined(SUNOS41) || defined(BSD44) || defined (SVR4) || defined(_AIX)
+#if	defined(SUNOS41) || defined(BSD44) || defined (SVR4) || defined(_AIX) | defined(__linux__)
 #define	SETSID
 #endif
 #endif
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/h/sys.file.h isode-8.0/h/sys.file.h
--- old/isode-8.0/h/sys.file.h	Wed Jun 17 11:32:31 1992
+++ isode-8.0/h/sys.file.h	Thu Sep 16 10:36:05 1993
@@ -31,7 +31,7 @@
 #include <sys/ioctl.h>
 #endif
 
-#ifdef  BSD42
+#if defined(BSD42) || defined(__linux__)
 #include <sys/file.h>
 #else    
 #ifdef  SYS5
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/h/usr.dirent.h isode-8.0/h/usr.dirent.h
--- old/isode-8.0/h/usr.dirent.h	Wed Jun 17 11:32:31 1992
+++ isode-8.0/h/usr.dirent.h	Fri Dec  3 13:27:48 1993
@@ -56,8 +56,9 @@
 
 extern char             *getcwd ();
 
-
+#ifndef __linux__
 #define	scandir	_scandir
 #define	alphasort _alphasort
+#endif
 
 extern char *direntversion;
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/imisc/Makefile isode-8.0/imisc/Makefile
--- old/isode-8.0/imisc/Makefile	Tue Jun 16 13:23:44 1992
+++ isode-8.0/imisc/Makefile	Mon Aug 23 13:49:29 1993
@@ -73,6 +73,7 @@
 		-@echo ""
 
 imiscd:		ximiscd$(LPP)
+		:
 
 ximiscd$(LPP):	imiscd.o IMISC-Rops.o ryresponder.o IMISC_tables.o $(LIBES)
 		$(LDCC) $(LDFLAGS) -o $@ imiscd.o IMISC-Rops.o ryresponder.o \
@@ -107,6 +108,7 @@
 		-@echo ""
 
 imisc:		ximisc$(LPP)
+		:
 
 ximisc$(LPP):	imisc.o IMISC-Iops.o ryinitiator.o IMISC_tables.o $(LIBES)
 		$(LDCC) $(LDFLAGS) -o $@ imisc.o IMISC-Iops.o ryinitiator.o \
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/jump/Makefile isode-8.0/jump/Makefile
--- old/isode-8.0/jump/Makefile	Thu Jan  1 01:00:00 1970
+++ isode-8.0/jump/Makefile	Fri Aug 27 12:16:36 1993
@@ -0,0 +1,42 @@
+IMAGE=		libisode
+VERSION=	0.1
+ADDRESS=	0x63d00000
+JUMPSIZE=	0x8000
+GOTSIZE=	0x2000
+
+
+all:		image stubs
+
+install:
+		ln -f libdsap.sa ../libdsap.a
+		ln -f libftam.sa ../libftam.a
+		ln -f libisode.sa ../libacsap.a
+		ln -f libisode.sa ../libcompat.a
+		ln -f libisode.sa ../libdirent.a
+		ln -f libisode.sa ../libisode.a
+		ln -f libisode.sa ../libpepsy.a
+		ln -f libisode.sa ../libpepy.a
+		ln -f libisode.sa ../libpsap.a
+		ln -f libisode.sa ../libpsap2.a
+		ln -f libisode.sa ../libronot.a
+		ln -f libisode.sa ../librosap.a
+		ln -f libisode.sa ../librosy.a
+		ln -f libisode.sa ../librtsap.a
+		ln -f libisode.sa ../libssap.a
+		ln -f libisode.sa ../libtsap.a
+
+image:
+		/usr/dll/bin/mkimage -l $(IMAGE) -v $(VERSION) \
+			-a $(ADDRESS) -j $(JUMPSIZE) -g $(GOTSIZE) \
+			-- \
+			libacsap.a libcommon.a libcompat.a libdirent.a \
+			libdsap.a libftam.a libnet.a libpepsy.a libpepy.a \
+			libpsap.a libpsap2.a libronot.a librosap.a librosy.a \
+			librtsap.a libssap.a libtsap.a libx500as.a libisode.a \
+			-lcurses -ltermcap -ldbm -lc -lm `gcc --print` -lc
+
+stubs:
+		/usr/dll/bin/mkstubs -l $(IMAGE) -v $(VERSION) \
+			-a $(ADDRESS) -j $(JUMPSIZE) -g $(GOTSIZE) \
+			-- \
+			libisode libdsap libftam
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/jump/jump.funcs isode-8.0/jump/jump.funcs
--- old/isode-8.0/jump/jump.funcs	Thu Jan  1 01:00:00 1970
+++ isode-8.0/jump/jump.funcs	Fri Dec  3 13:28:19 1993
@@ -0,0 +1,1447 @@
+00000000 T _PRyStub             libisode       p-rystub
+00000000 T _PRyDiscard          libisode       p-rydiscard
+00000000 T _PRyOperation        libisode       p-ryoper
+00000000 T _PRyOpInvoke         libisode       p-ryopinvoke
+00000000 T _PRyGenID            libisode       p-rygenid
+00000000 T _PRyDispatch         libisode       p-rydispatch
+00000000 T _PRyDsResult         libisode       p-rydsresult
+00000000 T _PRyDsError          libisode       p-rydserror
+00000000 T _PRyDsUReject        libisode       p-rydsurej
+00000000 T _PRyWait             libisode       p-rywait
+00000000 T _PRyWaitAux          libisode       p-rywait
+00000000 T _Pnewopblk           libisode       p-ryopblock
+00000000 T _Pfreeopblk          libisode       p-ryopblock
+00000000 T _Pfindopblk          libisode       p-ryopblock
+00000000 T _Pfirstopblk         libisode       p-ryopblock
+00000000 T _Ploseopblk          libisode       p-ryopblock
+00000000 T _Pnewdsblk           libisode       p-rydsblock
+00000000 T _Pfreedsblk          libisode       p-rydsblock
+00000000 T _Pfinddsblk          libisode       p-rydsblock
+00000000 T _Plosedsblk          libisode       p-rydsblock
+00000000 T _Pfindopbyop         libisode       p-ryfind
+00000000 T _Pfindopbyname       libisode       p-ryfind
+00000000 T _Pfinderrbyerr       libisode       p-ryfind
+00000000 T _Pfinderrbyname      libisode       p-ryfind
+00000000 T _PRyLose             libisode       p-rylose
+00000000 T _RyStub              libisode       rystub
+00000000 T _RyDiscard           libisode       rydiscard
+00000000 T _RyOperation         libisode       ryoper
+00000000 T _RyOpInvoke          libisode       ryopinvoke
+00000000 T _RyGenID             libisode       rygenid
+00000000 T _RyDispatch          libisode       rydispatch
+00000000 T _RyDsResult          libisode       rydsresult
+00000000 T _RyDsError           libisode       rydserror
+00000000 T _RyDsUReject         libisode       rydsurej
+00000000 T _RyWait              libisode       rywait
+00000000 T _RyWaitAux           libisode       rywait
+00000000 T _newopblk            libisode       ryopblock
+00000000 T _freeopblk           libisode       ryopblock
+00000000 T _findopblk           libisode       ryopblock
+00000000 T _firstopblk          libisode       ryopblock
+00000000 T _loseopblk           libisode       ryopblock
+00000000 T _newdsblk            libisode       rydsblock
+00000000 T _freedsblk           libisode       rydsblock
+00000000 T _finddsblk           libisode       rydsblock
+00000000 T _losedsblk           libisode       rydsblock
+00000000 T _findopbyop          libisode       ryfind
+00000000 T _findopbyname        libisode       ryfind
+00000000 T _finderrbyerr        libisode       ryfind
+00000000 T _finderrbyname       libisode       ryfind
+00000000 T _RyLose              libisode       rylose
+00000000 T _RoAsynBindRequest   libisode       ronotbind1
+00000000 T _RoAsynBindRetry     libisode       ronotbind1
+00000000 T _ParseRoBindResponse libisode       ronotbind1
+00000000 T _RoBindInit          libisode       ronotbind2
+00000000 T _ParseRoBindArgument libisode       ronotbind2
+00000000 T _RoBindResult        libisode       ronotbind2
+00000000 T _RoBindError         libisode       ronotbind2
+00000000 T _RoBindReject        libisode       ronotbind2
+00000000 T _RoUnBindRequest     libisode       ronotunbind1
+00000000 T _RoUnBindRetry       libisode       ronotunbind1
+00000000 T _ParseRoUnBindResponse libisode       ronotunbind1
+00000000 T _RoUnBindInit        libisode       ronotunbind2
+00000000 T _RoUnBindResult      libisode       ronotunbind2
+00000000 T _RoUnBindError       libisode       ronotunbind2
+00000000 T _RoUnBindReject      libisode       ronotunbind2
+00000000 T _RoBindUAbort        libisode       ronotabort
+00000000 T _ronotlose           libisode       ronotlose
+00000000 T _acs2ronotlose       libisode       ronotlose
+00000000 T _RoErrString         libisode       rosaperror
+00000000 T _RoInvokeRequest     libisode       rosapinvoke
+00000000 T _RoResultRequest     libisode       rosapresult
+00000000 T _RoErrorRequest      libisode       rosapuerror
+00000000 T _RoURejectRequest    libisode       rosapureject
+00000000 T _RoURejectRequestAux libisode       rosapureject
+00000000 T _RoIntrRequest       libisode       rosapintr
+00000000 T _RoWaitRequest       libisode       rosapwait
+00000000 T _RoSetService        libisode       rosapservice
+00000000 T _acb2osdu            libisode       rosapapdu
+00000000 T _RoSetIndications    libisode       rosapasync
+00000000 T _RoSelectMask        libisode       rosapselect
+00000000 T _ropktlose           libisode       rosaplose
+00000000 T _rosapreject         libisode       rosaplose
+00000000 T _rosaplose           libisode       rosaplose
+00000000 T _RoRtService         libisode       ro2rts
+00000000 T _ro2rtsasync         libisode       ro2rts
+00000000 T _ro2rtsmask          libisode       ro2rts
+00000000 T _ro2rtswait          libisode       ro2rts
+00000000 T _ro2rtswrite         libisode       ro2rts
+00000000 T _ro2rtsready         libisode       ro2rts
+00000000 T _RoPService          libisode       ro2ps
+00000000 T _ro2psasync          libisode       ro2ps
+00000000 T _ro2psmask           libisode       ro2ps
+00000000 T _ro2pswait           libisode       ro2ps
+00000000 T _ro2pswrite          libisode       ro2ps
+00000000 T _RoExec              libisode       ro2ssexec
+00000000 T _RoInit              libisode       ro2ssrespond
+00000000 T _RoBeginResponse     libisode       ro2ssrespond
+00000000 T _RoBeginRequest      libisode       ro2ssinitiat
+00000000 T _RoEndRequest        libisode       ro2ssreleas1
+00000000 T _RoEndResponse       libisode       ro2ssreleas2
+00000000 T _RoSService          libisode       ro2ss
+00000000 T _ro2ssasync          libisode       ro2ss
+00000000 T _ro2ssmask           libisode       ro2ss
+00000000 T _ro2sslose           libisode       ro2ss
+00000000 T _ro2sswait           libisode       ro2ss
+00000000 T _ro2ssready          libisode       ro2ss
+00000000 T _ro2sswrite          libisode       ro2ss
+00000000 T _ss2rosabort         libisode       ro2ss
+00000000 T _ss2roslose          libisode       ro2ss
+00000000 T _RoSetThorn          libisode       ro2ssthorn
+00000000 T _RtErrString         libisode       rtsaperror
+00000000 T _RtPTurnRequest      libisode       rtsappturn
+00000000 T _RtGTurnRequest      libisode       rtsapgturn
+00000000 T _RtTransferRequest   libisode       rtsaptrans
+00000000 T _RtWaitRequest       libisode       rtsapwait
+00000000 T _RtWaitRequestAux    libisode       rtsapwait
+00000000 T _RtSetIndications    libisode       rtsapasync
+00000000 T _RtSelectMask        libisode       rtsapselect
+00000000 T _rtpktlose           libisode       rtsaplose
+00000000 T _rtsaplose           libisode       rtsaplose
+00000000 T _RtSetDownTrans      libisode       rtsapdtrans
+00000000 T _RtSetUpTrans        libisode       rtsaputrans
+00000000 T _RtInit_Aux          libisode       rt2psrespond
+00000000 T _RtOpenResponse      libisode       rt2psrespond
+00000000 T _RtOpenRequest2      libisode       rt2psinitiat
+00000000 T _RtUAbortRequest     libisode       rt2psabort
+00000000 T _RtCloseRequest      libisode       rt2psreleas1
+00000000 T _RtCloseResponse     libisode       rt2psreleas2
+00000000 T _rt2pspturn          libisode       rt2ps
+00000000 T _rt2psgturn          libisode       rt2ps
+00000000 T _rt2pstrans          libisode       rt2ps
+00000000 T _rt2pswait           libisode       rt2ps
+00000000 T _rt2psasync          libisode       rt2ps
+00000000 T _rt2psmask           libisode       rt2ps
+00000000 T _rt2pslose           libisode       rt2ps
+00000000 T _acs2rtslose         libisode       rt2ps
+00000000 T _acs2rtsabort        libisode       rt2ps
+00000000 T _ps2rtslose          libisode       rt2ps
+00000000 T _RtExec              libisode       rt2ssexec
+00000000 T _RtBInit             libisode       rt2ssrespond
+00000000 T _RtBeginResponse     libisode       rt2ssrespond
+00000000 T _RtBeginRequest2     libisode       rt2ssinitiat
+00000000 T _RtEndRequest        libisode       rt2ssreleas1
+00000000 T _RtEndResponse       libisode       rt2ssreleas2
+00000000 T _rt2sspturn          libisode       rt2ss
+00000000 T _rt2ssgturn          libisode       rt2ss
+00000000 T _rt2sstrans          libisode       rt2ss
+00000000 T _rt2sswait           libisode       rt2ss
+00000000 T _rt2ssasync          libisode       rt2ss
+00000000 T _rt2ssmask           libisode       rt2ss
+00000000 T _rt2sslose           libisode       rt2ss
+00000000 T _ss2rtsabort         libisode       rt2ss
+00000000 T _ss2rtslose          libisode       rt2ss
+00000000 T _ps2acslose          libisode       acsaprovider
+00000000 T _info2apdu           libisode       acsaprovider
+00000000 T _apdu2info           libisode       acsaprovider
+00000000 T _newacblk            libisode       acsapblock
+00000000 T _freeacblk           libisode       acsapblock
+00000000 T _findacblk           libisode       acsapblock
+00000000 T _AcErrString         libisode       acsaperror
+00000000 T _acpktlose           libisode       acsaplose
+00000000 T _acsaplose           libisode       acsaplose
+00000000 T _AcInit              libisode       acsaprespond
+00000000 T _AcAssocResponse     libisode       acsaprespond
+00000000 T _AcAsynAssocRequest  libisode       acsapinitiat
+00000000 T _AcAsynRetryRequest  libisode       acsapinitiat
+00000000 T _AcAsynNextRequest   libisode       acsapinitiat
+00000000 T _AcRelRequest        libisode       acsapreleas1
+00000000 T _AcRelRetryRequest   libisode       acsapreleas1
+00000000 T _AcRelResponse       libisode       acsapreleas2
+00000000 T _AcFINISHser         libisode       acsapreleas3
+00000000 T _AcUAbortRequest     libisode       acsapabort1
+00000000 T _AcABORTser          libisode       acsapabort2
+00000000 T _ps2acsabort         libisode       acsapabort2
+00000000 T _AcFindPCI           libisode       acsapfindpci
+00000000 T __str2aei            libisode       acsapaddr
+00000000 T _aei2addr            libisode       acsapaddr
+00000000 T _str2aei_dse         libisode       acsapdse
+00000000 T _aei2addr_dse        libisode       acsapdse
+00000000 T _name2value_dase     libisode       aetdase
+00000000 T _set_lookup_dase     libisode       aetdase
+00000000 T _alias2name          libisode       isoalias
+00000000 T _add_alias           libisode       isoalias
+00000000 T _str2aei_stub        libisode       acsapstub
+00000000 T _aei2addr_stub       libisode       acsapstub
+00000000 T _str2aet_seq         libisode       aetseq
+00000000 T _setisoentity        libisode       isoentity
+00000000 T _endisoentity        libisode       isoentity
+00000000 T _getisoentity        libisode       isoentity
+00000000 T __startisoentity     libisode       isoentity
+00000000 T __stopisoentity      libisode       isoentity
+00000000 T __printent           libisode       isoentity
+00000000 T _oid2aei             libisode       oid2aei
+00000000 T _sprintaei           libisode       sprintaei
+00000000 T _is2paddr            libisode       is2paddr
+00000000 T _is2saddr            libisode       is2saddr
+00000000 T _is2taddr            libisode       is2taddr
+00000000 T _isodeserver         libisode       acserver1
+00000000 T _iserver_init        libisode       acserver2
+00000000 T _iserver_init_aux    libisode       acserver2
+00000000 T _iserver_initAux     libisode       acserver2
+00000000 T _iserver_wait        libisode       acserver2
+00000000 T _iserver_mask        libisode       acserver2
+00000000 T _build_DSE_PSAPaddr  libisode       dse-c
+00000000 T _parse_DSE_PSAPaddr  libisode       dse-c
+00000000 T _PDataRequest        libisode       psaprovider
+00000000 T _PDataRequestAux     libisode       psaprovider
+00000000 T _PReadRequest        libisode       psaprovider
+00000000 T _ss2psabort          libisode       psaprovider
+00000000 T _PSetIndications     libisode       psaprovider
+00000000 T _ss2pslose           libisode       psaprovider
+00000000 T _newpblk             libisode       psaprovider
+00000000 T _freepblk            libisode       psaprovider
+00000000 T _findpblk            libisode       psaprovider
+00000000 T _info2ppdu           libisode       psaprovider
+00000000 T _ppdu2info           libisode       psaprovider
+00000000 T _info2ssdu           libisode       psaprovider
+00000000 T _ssdu2info           libisode       psaprovider
+00000000 T _qbuf2info           libisode       psaprovider
+00000000 T _info2qb             libisode       psaprovider
+00000000 T _qb2info             libisode       psaprovider
+00000000 T _silly_list          libisode       psaprovider
+00000000 T _PErrString          libisode       psap2error
+00000000 T _PExec               libisode       psapexec
+00000000 T _PInit               libisode       psaprespond
+00000000 T _PConnResponse       libisode       psaprespond
+00000000 T _PAsynConnRequest    libisode       psapinitiate
+00000000 T _PAsynRetryRequest   libisode       psapinitiate
+00000000 T _PAsynNextRequest    libisode       psapinitiate
+00000000 T _PGTokenRequest      libisode       psaptoken
+00000000 T _PPTokenRequest      libisode       psaptoken
+00000000 T _PGControlRequest    libisode       psapactivity
+00000000 T _PActStartRequest    libisode       psapactivity
+00000000 T _PActResumeRequest   libisode       psapactivity
+00000000 T _PActIntrRequestAux  libisode       psapactivity
+00000000 T _PActIntrResponseAux libisode       psapactivity
+00000000 T _PMajSyncRequestAux  libisode       psapmajor1
+00000000 T _PMajSyncResponseAux libisode       psapmajor2
+00000000 T _PMinSyncRequest     libisode       psapminor1
+00000000 T _PMinSyncResponse    libisode       psapminor2
+00000000 T _PReSyncRequest      libisode       psapresync1
+00000000 T _PReSyncResponse     libisode       psapresync2
+00000000 T _PUAbortRequest      libisode       psapabort
+00000000 T _PUReportRequest     libisode       psapreport
+00000000 T _PRelRequest         libisode       psaprelease1
+00000000 T _PRelRetryRequest    libisode       psaprelease1
+00000000 T _PRelResponse        libisode       psaprelease2
+00000000 T _PSelectMask         libisode       psapselect
+00000000 T _ppktlose            libisode       psaplose
+00000000 T _psaplose            libisode       psaplose
+00000000 T _build_UNIV_IA5String libisode       UPEPY-01
+00000000 T _parse_UNIV_IA5String libisode       UPEPY-02
+00000000 T _print_UNIV_IA5String libisode       UPEPY-03
+00000000 T _build_UNIV_NumericString libisode       UPEPY-04
+00000000 T _parse_UNIV_NumericString libisode       UPEPY-05
+00000000 T _print_UNIV_NumericString libisode       UPEPY-06
+00000000 T _build_UNIV_PrintableString libisode       UPEPY-07
+00000000 T _parse_UNIV_PrintableString libisode       UPEPY-08
+00000000 T _print_UNIV_PrintableString libisode       UPEPY-09
+00000000 T _build_UNIV_T61String libisode       UPEPY-10
+00000000 T _parse_UNIV_T61String libisode       UPEPY-11
+00000000 T _print_UNIV_T61String libisode       UPEPY-12
+00000000 T _build_UNIV_TeletexString libisode       UPEPY-13
+00000000 T _parse_UNIV_TeletexString libisode       UPEPY-14
+00000000 T _print_UNIV_TeletexString libisode       UPEPY-15
+00000000 T _build_UNIV_VideotexString libisode       UPEPY-16
+00000000 T _parse_UNIV_VideotexString libisode       UPEPY-17
+00000000 T _print_UNIV_VideotexString libisode       UPEPY-18
+00000000 T _build_UNIV_GeneralizedTime libisode       UPEPY-19
+00000000 T _parse_UNIV_GeneralizedTime libisode       UPEPY-20
+00000000 T _print_UNIV_GeneralizedTime libisode       UPEPY-21
+00000000 T _build_UNIV_GeneralisedTime libisode       UPEPY-22
+00000000 T _parse_UNIV_GeneralisedTime libisode       UPEPY-23
+00000000 T _print_UNIV_GeneralisedTime libisode       UPEPY-24
+00000000 T _build_UNIV_UTCTime  libisode       UPEPY-25
+00000000 T _parse_UNIV_UTCTime  libisode       UPEPY-26
+00000000 T _print_UNIV_UTCTime  libisode       UPEPY-27
+00000000 T _build_UNIV_UniversalTime libisode       UPEPY-28
+00000000 T _parse_UNIV_UniversalTime libisode       UPEPY-29
+00000000 T _print_UNIV_UniversalTime libisode       UPEPY-30
+00000000 T _build_UNIV_GraphicString libisode       UPEPY-31
+00000000 T _parse_UNIV_GraphicString libisode       UPEPY-32
+00000000 T _print_UNIV_GraphicString libisode       UPEPY-33
+00000000 T _build_UNIV_VisibleString libisode       UPEPY-34
+00000000 T _parse_UNIV_VisibleString libisode       UPEPY-35
+00000000 T _print_UNIV_VisibleString libisode       UPEPY-36
+00000000 T _build_UNIV_ISO646String libisode       UPEPY-37
+00000000 T _parse_UNIV_ISO646String libisode       UPEPY-38
+00000000 T _print_UNIV_ISO646String libisode       UPEPY-39
+00000000 T _build_UNIV_GeneralString libisode       UPEPY-40
+00000000 T _parse_UNIV_GeneralString libisode       UPEPY-41
+00000000 T _print_UNIV_GeneralString libisode       UPEPY-42
+00000000 T _build_UNIV_CharacterString libisode       UPEPY-43
+00000000 T _parse_UNIV_CharacterString libisode       UPEPY-44
+00000000 T _print_UNIV_CharacterString libisode       UPEPY-45
+00000000 T _build_UNIV_EXTERNAL libisode       UPEPY-46
+00000000 T _parse_UNIV_EXTERNAL libisode       UPEPY-47
+00000000 T _print_UNIV_EXTERNAL libisode       UPEPY-48
+00000000 T _build_UNIV_ObjectDescriptor libisode       UPEPY-49
+00000000 T _parse_UNIV_ObjectDescriptor libisode       UPEPY-50
+00000000 T _print_UNIV_ObjectDescriptor libisode       UPEPY-51
+00000000 T _encode_UNIV_IA5String libisode       VPEPY-01
+00000000 T _encode_UNIV_NumericString libisode       VPEPY-02
+00000000 T _encode_UNIV_PrintableString libisode       VPEPY-03
+00000000 T _encode_UNIV_T61String libisode       VPEPY-04
+00000000 T _encode_UNIV_TeletexString libisode       VPEPY-05
+00000000 T _encode_UNIV_VideotexString libisode       VPEPY-06
+00000000 T _encode_UNIV_GeneralizedTime libisode       VPEPY-07
+00000000 T _encode_UNIV_GeneralisedTime libisode       VPEPY-08
+00000000 T _encode_UNIV_UTCTime libisode       VPEPY-09
+00000000 T _encode_UNIV_UniversalTime libisode       VPEPY-10
+00000000 T _encode_UNIV_GraphicString libisode       VPEPY-11
+00000000 T _encode_UNIV_VisibleString libisode       VPEPY-12
+00000000 T _encode_UNIV_ISO646String libisode       VPEPY-13
+00000000 T _encode_UNIV_GeneralString libisode       VPEPY-14
+00000000 T _encode_UNIV_CharacterString libisode       VPEPY-15
+00000000 T _encode_UNIV_EXTERNAL libisode       VPEPY-16
+00000000 T _encode_UNIV_ObjectDescriptor libisode       VPEPY-17
+00000000 T _decode_UNIV_IA5String libisode       VPEPY-18
+00000000 T _decode_UNIV_NumericString libisode       VPEPY-19
+00000000 T _decode_UNIV_PrintableString libisode       VPEPY-20
+00000000 T _decode_UNIV_T61String libisode       VPEPY-21
+00000000 T _decode_UNIV_TeletexString libisode       VPEPY-22
+00000000 T _decode_UNIV_VideotexString libisode       VPEPY-23
+00000000 T _decode_UNIV_GeneralizedTime libisode       VPEPY-24
+00000000 T _decode_UNIV_GeneralisedTime libisode       VPEPY-25
+00000000 T _decode_UNIV_UTCTime libisode       VPEPY-26
+00000000 T _decode_UNIV_UniversalTime libisode       VPEPY-27
+00000000 T _decode_UNIV_GraphicString libisode       VPEPY-28
+00000000 T _decode_UNIV_VisibleString libisode       VPEPY-29
+00000000 T _decode_UNIV_ISO646String libisode       VPEPY-30
+00000000 T _decode_UNIV_GeneralString libisode       VPEPY-31
+00000000 T _decode_UNIV_CharacterString libisode       VPEPY-32
+00000000 T _decode_UNIV_EXTERNAL libisode       VPEPY-33
+00000000 T _decode_UNIV_ObjectDescriptor libisode       VPEPY-34
+00000000 T _free_UNIV_EXTERNAL  libisode       VPEPY-35
+00000000 T _PY_pp               libisode       py_pp
+00000000 T _testdebug           libisode       testdebug
+00000000 T _enc_f               libisode       enc
+00000000 T _dec_f               libisode       dec
+00000000 T _fre_obj             libisode       fre
+00000000 T _fre_type            libisode       fre
+00000000 T _callsfn             libisode       fre
+00000000 T _prnt_f              libisode       prnt
+00000000 T _next_ptpe           libisode       prnt
+00000000 T _p_ismatch           libisode       prnt
+00000000 T _p_setpresent        libisode       prnt
+00000000 T _printable           libisode       prnt
+00000000 T _dmp_ptpe            libisode       prnt
+00000000 T _pepsylose           libisode       util
+00000000 T _ppepsylose          libisode       util
+00000000 T _ferr                libisode       util
+00000000 T _ferrd               libisode       util
+00000000 T _dmp_tpe             libisode       util
+00000000 T _pr_petype           libisode       util
+00000000 T _pr_entry            libisode       util
+00000000 T _f_null              libisode       util
+00000000 T _bitscmp             libisode       util
+00000000 T _ostrcmp             libisode       util
+00000000 T _hasdata             libisode       util
+00000000 T _same                libisode       util
+00000000 T _next_tpe            libisode       util
+00000000 T _ismatch             libisode       util
+00000000 T _fdflt_f             libisode       util
+00000000 T _fdflt_b             libisode       util
+00000000 T _vpush               libisode       vprint
+00000000 T _vpop                libisode       vprint
+00000000 T _vname               libisode       vprint
+00000000 T _vtag                libisode       vprint
+00000000 T _vprint              libisode       vprint
+00000000 T _vstring             libisode       vprint
+00000000 T _bit2str             libisode       vprint
+00000000 T _vunknown            libisode       vprint
+00000000 T _vpushfp             libisode       vprint
+00000000 T _vsetfp              libisode       vprint
+00000000 T _vpopfp              libisode       vprint
+00000000 T _vpushstr            libisode       vprint
+00000000 T _vpopstr             libisode       vprint
+00000000 T _vpushpp             libisode       vprint
+00000000 T _vpopp               libisode       vprint
+00000000 T _vpushquipu          libisode       vprint
+00000000 T _vpopquipu           libisode       vprint
+00000000 T _pvpdu               libisode       vprint
+00000000 T __vpdu               libisode       vprint
+00000000 T _PY_advise           libisode       py_advise
+00000000 T _addr2ref            libisode       addr2ref
+00000000 T _bit2prim            libisode       bit2prim
+00000000 T _bitstr2strb         libisode       bitstr2strb
+00000000 T _bit_on              libisode       bit_ops
+00000000 T _bit_off             libisode       bit_ops
+00000000 T _bit_test            libisode       bit_ops
+00000000 T _dg_open             libisode       dg2ps
+00000000 T _dg_setup            libisode       dg2ps
+00000000 T _fdx_open            libisode       fdx2ps
+00000000 T _fdx_setup           libisode       fdx2ps
+00000000 T _fdx_reset           libisode       fdx2ps
+00000000 T _flag2prim           libisode       flag2prim
+00000000 T _gtime               libisode       gtime
+00000000 T _int2strb            libisode       int2strb
+00000000 T _setisobject         libisode       isobject
+00000000 T _endisobject         libisode       isobject
+00000000 T _getisobject         libisode       isobject
+00000000 T _num2prim            libisode       num2prim
+00000000 T _obj2prim            libisode       obj2prim
+00000000 T _getisobjectbyname   libisode       objectbyname
+00000000 T _getisobjectbyoid    libisode       objectbyoid
+00000000 T _ode2oid             libisode       ode2oid
+00000000 T _oid_cmp             libisode       oid_cmp
+00000000 T _elem_cmp            libisode       oid_cmp
+00000000 T _oid_cpy             libisode       oid_cpy
+00000000 T _oid_free            libisode       oid_free
+00000000 T _oid2ode_aux         libisode       oid2ode
+00000000 T _pe2pl               libisode       pe2pl
+00000000 T _pe2ps_aux           libisode       pe2ps
+00000000 T _ps_write_id         libisode       pe2ps
+00000000 T _ps_write_len        libisode       pe2ps
+00000000 T _pe2qb_f             libisode       pe2qb_f
+00000000 T _pe2ssdu             libisode       pe2ssdu
+00000000 T _pe2text             libisode       pe2text
+00000000 T _pe2uvec             libisode       pe2uvec
+00000000 T _pe_alloc            libisode       pe_alloc
+00000000 T _pe_cmp              libisode       pe_cmp
+00000000 T _pe_cpy              libisode       pe_cpy
+00000000 T _pe_error            libisode       pe_error
+00000000 T _pe_expunge          libisode       pe_expunge
+00000000 T _pe_extract          libisode       pe_extract
+00000000 T _pe_free             libisode       pe_free
+00000000 T _pe_pullup           libisode       pe_pullup
+00000000 T _pl2pe               libisode       pl2pe
+00000000 T _prim2bit            libisode       prim2bit
+00000000 T _prim2flag           libisode       prim2flag
+00000000 T _prim2num            libisode       prim2num
+00000000 T _prim2oid            libisode       prim2oid
+00000000 T _prim2qb             libisode       prim2qb
+00000000 T _prim2real           libisode       prim2real
+00000000 T _prim2set            libisode       prim2set
+00000000 T _prim2str            libisode       prim2str
+00000000 T _prim2time           libisode       prim2time
+00000000 T _str2utct            libisode       prim2time
+00000000 T _str2gent            libisode       prim2time
+00000000 T _ps2pe_aux           libisode       ps2pe
+00000000 T _ps_read_id          libisode       ps2pe
+00000000 T _ps_read_len         libisode       ps2pe
+00000000 T _ps_read_cons        libisode       ps2pe
+00000000 T _ps_alloc            libisode       ps_alloc
+00000000 T _ps_error            libisode       ps_error
+00000000 T _ps_flush            libisode       ps_flush
+00000000 T _ps_free             libisode       ps_free
+00000000 T _ps_get_abs          libisode       ps_get_abs
+00000000 T _ps_io               libisode       ps_io
+00000000 T _ps_prime            libisode       ps_prime
+00000000 T _qb2pe               libisode       qb2pe
+00000000 T _qb2prim_aux         libisode       qb2prim
+00000000 T _qb2str              libisode       qb2str
+00000000 T _qb_free             libisode       qb_free
+00000000 T _qb_pullup           libisode       qb_pullup
+00000000 T _qbuf2pe             libisode       qbuf2pe
+00000000 T _qbuf2pe_f           libisode       qbuf2pe_f
+00000000 T _qbuf_open           libisode       qbuf2ps
+00000000 T _real2prim           libisode       real2prim
+00000000 T _seq_add             libisode       seq_add
+00000000 T _seq_addon           libisode       seq_addon
+00000000 T _seq_del             libisode       seq_del
+00000000 T _seq_find            libisode       seq_find
+00000000 T _set_add             libisode       set_add
+00000000 T _set_addon           libisode       set_addon
+00000000 T _set_del             libisode       set_del
+00000000 T _set_find            libisode       set_find
+00000000 T _sprintoid           libisode       sprintoid
+00000000 T _sprintref           libisode       sprintref
+00000000 T _ssdu2pe             libisode       ssdu2pe
+00000000 T _std_flush           libisode       std2ps
+00000000 T _std_open            libisode       std2ps
+00000000 T _str2oid             libisode       str2oid
+00000000 T _str2pe              libisode       str2pe
+00000000 T _str2prim            libisode       str2prim
+00000000 T _str_open            libisode       str2ps
+00000000 T _str_setup           libisode       str2ps
+00000000 T _str2qb              libisode       str2qb
+00000000 T _strb2bitstr         libisode       strb2bitstr
+00000000 T _strb2int            libisode       strb2int
+00000000 T _time2prim           libisode       time2prim
+00000000 T _time2str            libisode       time2str
+00000000 T _tm2ut               libisode       tm2ut
+00000000 T _ts_read             libisode       ts2ps
+00000000 T _ts_write            libisode       ts2ps
+00000000 T _ut2tm               libisode       ut2tm
+00000000 T _uvec_open           libisode       uvec2ps
+00000000 T _uvec_setup          libisode       uvec2ps
+00000000 T _ps_get_plen         libisode       uvec2ps
+00000000 T _SDataRequest        libisode       ssaprovider
+00000000 T _SSendRequest        libisode       ssaprovider
+00000000 T _SWriteRequest       libisode       ssaprovider
+00000000 T _SDataRequestAux     libisode       ssaprovider
+00000000 T _SReadRequest        libisode       ssaprovider
+00000000 T _SDoCollideAux       libisode       ssaprovider
+00000000 T _SSetIndications     libisode       ssaprovider
+00000000 T _spkt2sd             libisode       ssaprovider
+00000000 T _sb2spkt             libisode       ssaprovider
+00000000 T _ts2sslose           libisode       ssaprovider
+00000000 T _newsblk             libisode       ssaprovider
+00000000 T _freesblk            libisode       ssaprovider
+00000000 T _findsblk            libisode       ssaprovider
+00000000 T _SErrString          libisode       ssaperror
+00000000 T _spkt2str            libisode       str2spkt
+00000000 T _str2spkt            libisode       str2spkt
+00000000 T _spkt2text           libisode       text2spkt
+00000000 T _text2spkt           libisode       text2spkt
+00000000 T _spkt2tsdu           libisode       tsdu2spkt
+00000000 T _tsdu2spkt           libisode       tsdu2spkt
+00000000 T _newspkt             libisode       tsdu2spkt
+00000000 T _freespkt            libisode       tsdu2spkt
+00000000 T _SExec               libisode       ssapexec
+00000000 T _SInit               libisode       ssaprespond
+00000000 T _SConnResponse       libisode       ssaprespond
+00000000 T _SAsynConnRequest    libisode       ssapinitiate
+00000000 T _SAsynRetryRequest   libisode       ssapinitiate
+00000000 T _SAsynNextRequest    libisode       ssapinitiate
+00000000 T _SExpdRequest        libisode       ssapexpd
+00000000 T _STypedRequest       libisode       ssaptyped
+00000000 T _SCapdRequest        libisode       ssapcapd1
+00000000 T _SCapdResponse       libisode       ssapcapd2
+00000000 T _SGTokenRequest      libisode       ssaptoken
+00000000 T _SPTokenRequest      libisode       ssaptoken
+00000000 T _SGControlRequest    libisode       ssapactivity
+00000000 T _SActStartRequest    libisode       ssapactivity
+00000000 T _SActResumeRequest   libisode       ssapactivity
+00000000 T _SActIntrRequest     libisode       ssapactivity
+00000000 T _SActIntrResponse    libisode       ssapactivity
+00000000 T _SActDiscRequest     libisode       ssapactivity
+00000000 T _SActDiscResponse    libisode       ssapactivity
+00000000 T _SActEndRequest      libisode       ssapactivity
+00000000 T _SActEndResponse     libisode       ssapactivity
+00000000 T _SMajSyncRequest     libisode       ssapmajor1
+00000000 T _SMajSyncRequestAux  libisode       ssapmajor1
+00000000 T _SMajSyncResponse    libisode       ssapmajor2
+00000000 T _SMajSyncResponseAux libisode       ssapmajor2
+00000000 T _SMinSyncRequest     libisode       ssapminor1
+00000000 T _SMinSyncResponse    libisode       ssapminor2
+00000000 T _SReSyncRequest      libisode       ssapresync1
+00000000 T _SReSyncResponse     libisode       ssapresync2
+00000000 T _SUAbortRequest      libisode       ssapabort
+00000000 T _SUReportRequest     libisode       ssapreport
+00000000 T _SRelRequest         libisode       ssaprelease1
+00000000 T _SRelRetryRequest    libisode       ssaprelease1
+00000000 T _SRelResponse        libisode       ssaprelease2
+00000000 T _SWriteRequestAux    libisode       ssapwrite
+00000000 T _SDoActivityAux      libisode       ssapactchk
+00000000 T _SSelectMask         libisode       ssapselect
+00000000 T _spktlose            libisode       ssaplose
+00000000 T _ssaplose            libisode       ssaplose
+00000000 T _TDataRequest        libisode       tsaprovider
+00000000 T _TExpdRequest        libisode       tsaprovider
+00000000 T _TWriteRequest       libisode       tsaprovider
+00000000 T _TReadRequest        libisode       tsaprovider
+00000000 T _TDiscRequest        libisode       tsaprovider
+00000000 T _TSetIndications     libisode       tsaprovider
+00000000 T _TSelectMask         libisode       tsaprovider
+00000000 T _newtblk             libisode       tsaprovider
+00000000 T _freetblk            libisode       tsaprovider
+00000000 T _findtblk            libisode       tsaprovider
+00000000 T _copyTSAPaddrX       libisode       tsaprovider
+00000000 T _copyTSAPaddrY       libisode       tsaprovider
+00000000 T _TErrString          libisode       tsaperror
+00000000 T _TSaveState          libisode       tsapstate
+00000000 T _TRestoreState       libisode       tsapstate
+00000000 T _fd2tpkt             libisode       fd2tpkt
+00000000 T _tpkt2fd             libisode       fd2tpkt
+00000000 T _newtpkt             libisode       fd2tpkt
+00000000 T _freetpkt            libisode       fd2tpkt
+00000000 T _tpkt2str            libisode       str2tpkt
+00000000 T _str2tpkt            libisode       str2tpkt
+00000000 T _tpkt2text           libisode       text2tpkt
+00000000 T _text2tpkt           libisode       text2tpkt
+00000000 T _TInit               libisode       tsaprespond
+00000000 T _TConnResponse       libisode       tsaprespond
+00000000 T _TAsynConnRequest    libisode       tsapinitiate
+00000000 T _TAsynRetryRequest   libisode       tsapinitiate
+00000000 T _TAsynNextRequest    libisode       tsapinitiate
+00000000 T _ta2norm             libisode       tsapinitiate
+00000000 T _tpktlose            libisode       tsaplose
+00000000 T _tsaplose            libisode       tsaplose
+00000000 T _TNetListen          libisode       tsaplisten
+00000000 T _TNetListenAux       libisode       tsaplisten
+00000000 T _TNetUnique          libisode       tsaplisten
+00000000 T _TNetAcceptAux       libisode       tsaplisten
+00000000 T _TGetReadMask        libisode       tsaplisten
+00000000 T _TGetWriteMask       libisode       tsaplisten
+00000000 T _TNetCheck           libisode       tsaplisten
+00000000 T _TNetClose           libisode       tsaplisten
+00000000 T _TNetFork            libisode       tsaplisten
+00000000 T _TSetQueuesOK        libisode       tsaplisten
+00000000 T __tsapmgmt_stub      libisode       tsapmgmt
+00000000 T _TSelectOctets       libisode       tsapmisc
+00000000 T _TGetAddresses       libisode       tsapmisc
+00000000 T _tp0write            libisode       tp0ts
+00000000 T _tp0init             libisode       tp0ts
+00000000 T _tcpopen             libisode       ts2tcp
+00000000 T _tcpsave             libisode       ts2tcp
+00000000 T _tcprestore          libisode       ts2tcp
+00000000 T _TTService           libisode       ts2tcp
+00000000 T __ts2x25_stub        libisode       ts2x25
+00000000 T __ts2bsd_stub        libisode       ts2bsd
+00000000 T __ts2sunlink_stub    libisode       ts2sunlink
+00000000 T __ts2tli_stub        libisode       ts2tli
+00000000 T __ts2xti_stub        libisode       ts2xti
+00000000 T __closedir_stub      libisode       closedir
+00000000 T __getdents_stub      libisode       getdents
+00000000 T __opendir_stub       libisode       opendir
+00000000 T __readdir_stub       libisode       readdir
+00000000 T __rewinddir_stub     libisode       rewinddir
+00000000 T __seekdir_stub       libisode       seekdir
+00000000 T __telldir_stub       libisode       telldir
+00000000 T __getcwd             libisode       getcwd
+00000000 T __scandir_stub       libisode       scandir
+00000000 T __alphasort_stub     libisode       scandir
+00000000 T _ll_open             libisode       logger
+00000000 T _ll_close            libisode       logger
+00000000 T _ll_log              libisode       logger
+00000000 T __ll_log             libisode       logger
+00000000 T _ll_hdinit           libisode       logger
+00000000 T _ll_dbinit           libisode       logger
+00000000 T _ll_printf           libisode       logger
+00000000 T _ll_sync             libisode       logger
+00000000 T _ll_preset           libisode       logger
+00000000 T _ll_check            libisode       logger
+00000000 T _ll_defmhdr          libisode       logger
+00000000 T _ll_setmhdr          libisode       logger
+00000000 T _selsocket           libisode       select
+00000000 T _set_check_fd        libisode       select
+00000000 T _xselect             libisode       select
+00000000 T _asprintf            libisode       asprintf
+00000000 T __asprintf           libisode       asprintf
+00000000 T _explode             libisode       explode
+00000000 T _implode             libisode       implode
+00000000 T __isodefile          libisode       isofiles
+00000000 T _getlocalhost        libisode       isohost
+00000000 T _sel2str             libisode       sel2str
+00000000 T _sys_errname         libisode       serror
+00000000 T _sprintb             libisode       sprintb
+00000000 T _str2elem            libisode       str2elem
+00000000 T _str2sel             libisode       str2sel
+00000000 T _str2vecX            libisode       str2vec
+00000000 T _isodesetailor       libisode       tailor
+00000000 T _isodetailor         libisode       tailor
+00000000 T _isodesetvar         libisode       tailor
+00000000 T _isodexport          libisode       tailor
+00000000 T _baduser             libisode       baduser
+00000000 T _chkpassword         libisode       chkpassword
+00000000 T _getpassword         libisode       getpassword
+00000000 T _cmd_srch            libisode       cmd_srch
+00000000 T _lexequ              libisode       lexequ
+00000000 T _lexnequ             libisode       lexnequ
+00000000 T _log_tai             libisode       log_tai
+00000000 T _rcmd_srch           libisode       rcmd_srch
+00000000 T _set_smalloc_handler libisode       smalloc
+00000000 T _smalloc             libisode       smalloc
+00000000 T _sstr2arg            libisode       sstr2arg
+00000000 T _strdup_stub         libisode       strdup
+00000000 T _setisoservent       libisode       isoservent
+00000000 T _endisoservent       libisode       isoservent
+00000000 T _getisoservent       libisode       isoservent
+00000000 T _getisoserventbyname libisode       servbyname
+00000000 T _getisoserventbyport libisode       servbyport
+00000000 T _getisoserventbyselector libisode       servbysel
+00000000 T _macro2str           libisode       isoaddrs
+00000000 T _str2paddr           libisode       isoaddrs
+00000000 T _macro2comm          libisode       isoaddrs
+00000000 T __paddr2str          libisode       isoaddrs
+00000000 T _str2saddr           libisode       str2saddr
+00000000 T _str2taddr           libisode       str2taddr
+00000000 T _saddr2str           libisode       saddr2str
+00000000 T _taddr2str           libisode       taddr2str
+00000000 T _na2norm             libisode       na2norm
+00000000 T _norm2na             libisode       norm2na
+00000000 T _na2str              libisode       na2str
+00000000 T _pa2str              libisode       pa2str
+00000000 T _nsap_addr_cmp       libisode       nsapcmp
+00000000 T _tsap_addr_cmp       libisode       nsapcmp
+00000000 T _ssap_addr_cmp       libisode       nsapcmp
+00000000 T _psap_addr_cmp       libisode       nsapcmp
+00000000 T _start_tcp_client    libisode       internet
+00000000 T _start_tcp_server    libisode       internet
+00000000 T _join_tcp_client     libisode       internet
+00000000 T _join_tcp_server     libisode       internet
+00000000 T _close_tcp_socket    libisode       internet
+00000000 T _gethostbystring     libisode       internet
+00000000 T _start_udp_server    libisode       dgram
+00000000 T _join_dgram_aux      libisode       dgram
+00000000 T _read_dgram_socket   libisode       dgram
+00000000 T _hack_dgram_socket   libisode       dgram
+00000000 T _write_dgram_socket  libisode       dgram
+00000000 T _close_dgram_socket  libisode       dgram
+00000000 T _select_dgram_socket libisode       dgram
+00000000 T _check_dgram_socket  libisode       dgram
+00000000 T __camtec_sunlink_stub libisode       camtec
+00000000 T __sunlink_stub       libisode       sunlink
+00000000 T __ubcx25_stub        libisode       ubcx25
+00000000 T __hpuxx25_stub       libisode       hpuxx25
+00000000 T __ultrix25_stub      libisode       ultrix25
+00000000 T __x25addr_stub       libisode       x25addr
+00000000 T _setisonsapsnpa      libisode       isonsapsnpa
+00000000 T _endisonsapsnpa      libisode       isonsapsnpa
+00000000 T _getisonsapsnpa      libisode       isonsapsnpa
+00000000 T _getisosnpa          libisode       isonsapsnpa
+00000000 T _getnsapinfo         libisode       isonsapsnpa
+00000000 T _char2bcd            libisode       char2bcd
+00000000 T _bcd2char            libisode       bcd2char
+00000000 T _grab_pe1            libdsap        IF_tables
+00000000 T _grab_pe2            libdsap        IF_tables
+00000000 T _grab_pe3            libdsap        IF_tables
+00000000 T _dec_av1             libdsap        IF_tables
+00000000 T _dec_at              libdsap        IF_tables
+00000000 T _free_at_dummy       libdsap        IF_tables
+00000000 T _encode_IF_AttributeType libdsap        IF_tables
+00000000 T _decode_IF_AttributeType libdsap        IF_tables
+00000000 T _encode_IF_AttributeValue libdsap        IF_tables
+00000000 T _decode_IF_AttributeValue libdsap        IF_tables
+00000000 T _encode_IF_DistinguishedName libdsap        IF_tables
+00000000 T _decode_IF_DistinguishedName libdsap        IF_tables
+00000000 T _encode_IF_Name      libdsap        IF_tables
+00000000 T _decode_IF_Name      libdsap        IF_tables
+00000000 T _enc_ipa             libdsap        DO_tables
+00000000 T _dec_ipa             libdsap        DO_tables
+00000000 T _fr_ipa              libdsap        DO_tables
+00000000 T _int2strb_alloc      libdsap        DAS_tables
+00000000 T _encode_DAS_TokenToSign libdsap        DAS_tables
+00000000 T _encode_DAS_ReadArgumentData libdsap        DAS_tables
+00000000 T _encode_DAS_CompareArgumentData libdsap        DAS_tables
+00000000 T _encode_DAS_ListArgumentData libdsap        DAS_tables
+00000000 T _encode_DAS_SearchArgumentData libdsap        DAS_tables
+00000000 T _encode_DAS_AddEntryArgumentData libdsap        DAS_tables
+00000000 T _encode_DAS_RemoveEntryArgumentData libdsap        DAS_tables
+00000000 T _encode_DAS_ModifyEntryArgumentData libdsap        DAS_tables
+00000000 T _encode_DAS_ModifyRDNArgumentData libdsap        DAS_tables
+00000000 T _substring_encode    libdsap        asn_ext
+00000000 T _substring_decode    libdsap        asn_ext
+00000000 T _substring_free      libdsap        asn_ext
+00000000 T _treestruct_encode   libdsap        asn_ext
+00000000 T _treestruct_decode   libdsap        asn_ext
+00000000 T _EDB_encode          libdsap        asn_ext
+00000000 T _EDB_decode_force    libdsap        asn_ext
+00000000 T _EDB_decode          libdsap        asn_ext
+00000000 T _EDB_free            libdsap        asn_ext
+00000000 T _acl_info_free       libdsap        acl
+00000000 T _acl_cmp             libdsap        acl
+00000000 T _acl_info_cmp        libdsap        acl
+00000000 T _acl_info_new        libdsap        acl
+00000000 T _acl_default         libdsap        acl
+00000000 T _get_default_acl     libdsap        acl
+00000000 T _set_default_acl     libdsap        acl
+00000000 T _test_acl_default    libdsap        acl
+00000000 T _acl_syntax          libdsap        acl
+00000000 T _add_attribute_syntax libdsap        attrv
+00000000 T _set_attribute_syntax libdsap        attrv
+00000000 T _set_av_pe_print     libdsap        attrv
+00000000 T _set_av_printer      libdsap        attrv
+00000000 T _modify_av_printer   libdsap        attrv
+00000000 T _split_attr          libdsap        attrv
+00000000 T _approxfn            libdsap        attrv
+00000000 T _syntax2str          libdsap        attrv
+00000000 T _str2syntax          libdsap        attrv
+00000000 T _get_syntax_table    libdsap        attrv
+00000000 T _AttrV_free          libdsap        attrv
+00000000 T _AttrV_free_aux      libdsap        attrv
+00000000 T _grab_pe             libdsap        attrv
+00000000 T _AttrV_decode        libdsap        attrv
+00000000 T _str_at2AttrV_aux    libdsap        attrv
+00000000 T _str_at2AttrV        libdsap        attrv
+00000000 T _str2AttrV           libdsap        attrv
+00000000 T _str2AttrV_aux       libdsap        attrv
+00000000 T _AttrV_cpy           libdsap        attrv
+00000000 T _AttrV_cpy_aux       libdsap        attrv
+00000000 T _AttrV_cpy_enc       libdsap        attrv
+00000000 T _rdn_cmp             libdsap        attrv
+00000000 T _rdn_cmp_reverse     libdsap        attrv
+00000000 T _AttrV_cmp           libdsap        attrv
+00000000 T _av_cmp_fn           libdsap        attrv
+00000000 T _AttrV_print         libdsap        attrv
+00000000 T _get_ca_ref          libdsap        ca
+00000000 T _cha_loopdetected    libdsap        ca
+00000000 T _ti_is_elem          libdsap        ca
+00000000 T _ti_cpy              libdsap        ca
+00000000 T _dn_seq_free         libdsap        dn_seq
+00000000 T _dn_seq_cpy          libdsap        dn_seq
+00000000 T _check_dnseq         libdsap        dn_seq
+00000000 T _dn_seq_cmp          libdsap        dn_seq
+00000000 T _check_dnseq_prefix  libdsap        dn_seq
+00000000 T _dn_seq_print        libdsap        dn_seq
+00000000 T _str2dnseq           libdsap        dn_seq
+00000000 T _dn_in_dnseq         libdsap        dn_seq
+00000000 T _dn_seq_push         libdsap        dn_seq
+00000000 T _dn_seq_pop          libdsap        dn_seq
+00000000 T _de_print            libdsap        ds_error
+00000000 T _ds_error            libdsap        ds_error
+00000000 T _log_ds_error        libdsap        ds_error
+00000000 T _ds_error_free       libdsap        ds_error
+00000000 T _ds_bind_error_aux   libdsap        ds_error
+00000000 T _ds_bind_error       libdsap        ds_error
+00000000 T _print_bind_error    libdsap        ds_error
+00000000 T _edbinfo_syntax      libdsap        dsa_info
+00000000 T _entryinfo_comp_free libdsap        entryinfo
+00000000 T _entryinfo_free      libdsap        entryinfo
+00000000 T _entryinfo_cpy       libdsap        entryinfo
+00000000 T _entryinfo_append    libdsap        entryinfo
+00000000 T _entryinfo_merge     libdsap        entryinfo
+00000000 T _entryinfo_print     libdsap        entryinfo
+00000000 T _filter_free         libdsap        filter
+00000000 T _filter_append       libdsap        filter
+00000000 T _strfilter           libdsap        filter
+00000000 T _ocfilter            libdsap        filter
+00000000 T _joinfilter          libdsap        filter
+00000000 T _fi_print            libdsap        filter
+00000000 T _print_filter        libdsap        filter
+00000000 T _load_oid_table      libdsap        oid
+00000000 T _add_entry_aux       libdsap        oid
+00000000 T _get_oid             libdsap        oid
+00000000 T _name2attr           libdsap        oid
+00000000 T _set_heap            libdsap        oid
+00000000 T _oid2attr            libdsap        oid
+00000000 T _name2oc             libdsap        oid
+00000000 T _oid2oc              libdsap        oid
+00000000 T _attr2name           libdsap        oid
+00000000 T _oc2name             libdsap        oid
+00000000 T _oid2name            libdsap        oid
+00000000 T _name2oid            libdsap        oid
+00000000 T _oid2pe              libdsap        oid
+00000000 T _oidprint            libdsap        oid
+00000000 T _dup_prim2oid        libdsap        oid
+00000000 T _free_oid_buckets    libdsap        oid
+00000000 T _oid_syntax          libdsap        oid
+00000000 T _want_oc_hierarchy   libdsap        oid2
+00000000 T _load_obj_hier       libdsap        oid2
+00000000 T _dumpalloid          libdsap        oid2
+00000000 T _add_oc_macro        libdsap        oid2
+00000000 T _table_seq_free      libdsap        oid2
+00000000 T _free_oid_table      libdsap        oid2
+00000000 T _oid_seq_free        libdsap        oidseq
+00000000 T _oid_seq_free_aux    libdsap        oidseq
+00000000 T _oid_seq_merge       libdsap        oidseq
+00000000 T _oid_seq_cmp         libdsap        oidseq
+00000000 T _oid_seq_cpy         libdsap        oidseq
+00000000 T _oid_seq_print       libdsap        oidseq
+00000000 T _str2oidseq          libdsap        oidseq
+00000000 T _oc_add              libdsap        oc
+00000000 T _str2oc              libdsap        oc
+00000000 T _add_oc_avs          libdsap        oc
+00000000 T _objectclass_cmp     libdsap        oc
+00000000 T _check_in_oc         libdsap        oc
+00000000 T _oc_print            libdsap        oc
+00000000 T _objectclass_syntax  libdsap        oc
+00000000 T _parse_error         libdsap        parse_error
+00000000 T _pe_print            libdsap        pe
+00000000 T _asn2pe              libdsap        pe
+00000000 T _show_picture        libdsap        picture
+00000000 T _exec_print          libdsap        picture
+00000000 T _hide_picture        libdsap        picture
+00000000 T _picture_print       libdsap        picture
+00000000 T _photo_syntax        libdsap        picture
+00000000 T _psap_free           libdsap        psap
+00000000 T _psap_cpy            libdsap        psap
+00000000 T _psap_dup            libdsap        psap
+00000000 T _psap_syntax         libdsap        psap
+00000000 T _tree_struct_free    libdsap        tree_struct
+00000000 T _schema_syntax       libdsap        tree_struct
+00000000 T _SkipSpace           libdsap        util
+00000000 T _StripSpace          libdsap        util
+00000000 T _StripSpace2         libdsap        util
+00000000 T _TidyString2         libdsap        util
+00000000 T _TidyString          libdsap        util
+00000000 T _test_prim_pe        libdsap        util
+00000000 T _ps_printf           libdsap        util
+00000000 T _fatal               libdsap        util
+00000000 T _pslog               libdsap        util
+00000000 T _stop_listeners      libdsap        util
+00000000 T _quipu_pe_cmp        libdsap        util
+00000000 T _acl_dflt            libdsap        util
+00000000 T _correlate_search_results libdsap        correlate
+00000000 T _merge_search_results libdsap        correlate
+00000000 T _search_result_free  libdsap        correlate
+00000000 T _standard_syntaxes   libdsap        std_sntx
+00000000 T _quipu_syntaxes      libdsap        quipu_sntx
+00000000 T _dflt_attr_file      libdsap        file_print
+00000000 T _fileattr_print      libdsap        file_print
+00000000 T _as_write_files      libdsap        file_print
+00000000 T _grab_filepe         libdsap        file_enc
+00000000 T _file_decode         libdsap        file_enc
+00000000 T _fileattr_cpy        libdsap        file_cpy
+00000000 T _file_cmp            libdsap        file_cpy
+00000000 T _str2file_aux        libdsap        file_str
+00000000 T _str2file            libdsap        file_str
+00000000 T _file_free           libdsap        file_str
+00000000 T _AttrT_cmp_old       libdsap        attrt_cmp
+00000000 T _AttrT_decode_aux    libdsap        attrt_dec
+00000000 T _AttrT_new           libdsap        attrt_new
+00000000 T _AttrT_cpy           libdsap        attrt_cpy
+00000000 T _AttrT_print         libdsap        attrt_print
+00000000 T _as_cmp_comp         libdsap        as_cmp
+00000000 T _as_cmp              libdsap        as_cmp
+00000000 T _as_comp_cpy         libdsap        as_cpy
+00000000 T _as_cpy              libdsap        as_cpy
+00000000 T _as_delnext          libdsap        as_del
+00000000 T _as_merge            libdsap        as_merge
+00000000 T _as_merge_aux        libdsap        as_merge
+00000000 T _as_fast_merge       libdsap        as_merge
+00000000 T _as_comp_new         libdsap        as_new
+00000000 T _as_comp_free        libdsap        as_free
+00000000 T _as_free             libdsap        as_free
+00000000 T _as_find_type        libdsap        as_find
+00000000 T _as_comp_print       libdsap        as_print
+00000000 T _as_print            libdsap        as_print
+00000000 T _str2as              libdsap        as_str
+00000000 T _as_combine          libdsap        as_str
+00000000 T _avs_cmp             libdsap        avs_cmp
+00000000 T _avs_comp_cpy        libdsap        avs_cpy
+00000000 T _avs_cpy             libdsap        avs_cpy
+00000000 T _avs_cpy_enc         libdsap        avs_cpy
+00000000 T _avs_delnext         libdsap        avs_del
+00000000 T _avs_merge           libdsap        avs_merge
+00000000 T _avs_fast_merge      libdsap        avs_merge
+00000000 T _avs_comp_fill       libdsap        avs_new
+00000000 T _avs_comp_new        libdsap        avs_new
+00000000 T _avs_comp_free       libdsap        avs_free
+00000000 T _avs_free            libdsap        avs_free
+00000000 T _avs_print           libdsap        avs_print
+00000000 T _avs_print_aux       libdsap        avs_print
+00000000 T _str2avs             libdsap        avs_str
+00000000 T _fast_str2avs        libdsap        avs_str
+00000000 T _dn_cmp              libdsap        dn_cmp
+00000000 T _dn_cmp_prefix       libdsap        dn_cmp
+00000000 T _dn_order_cmp        libdsap        dn_cmp
+00000000 T _dn_comp_cpy         libdsap        dn_cpy
+00000000 T _dn_cpy              libdsap        dn_cpy
+00000000 T _dn_append           libdsap        dn_append
+00000000 T _dn_comp_free        libdsap        dn_free
+00000000 T _dn_free             libdsap        dn_free
+00000000 T _dn_print            libdsap        dn_print
+00000000 T _dn_rfc_print        libdsap        dn_print
+00000000 T _ufn_dn_print        libdsap        dn_print
+00000000 T _ufn_dn_print_aux    libdsap        dn_print
+00000000 T _ufn_rdn_print       libdsap        dn_print
+00000000 T _dn2str              libdsap        dn_print
+00000000 T _dn2ufn              libdsap        dn_print
+00000000 T _dn2rfc              libdsap        dn_print
+00000000 T _str2dn              libdsap        dn_str
+00000000 T _str2dn_aux          libdsap        dn_str
+00000000 T _str2dnX             libdsap        dn_str
+00000000 T _dn_dec              libdsap        dn_str
+00000000 T _dn_enc              libdsap        dn_str
+00000000 T _dn_syntax           libdsap        dn_str
+00000000 T _dn_comp_new         libdsap        dn_new
+00000000 T _rdn_cmp_comp        libdsap        rdn_cmp
+00000000 T _rdn_comp_cpy        libdsap        rdn_cpy
+00000000 T _rdn_cpy             libdsap        rdn_cpy
+00000000 T _rdn_comp_new        libdsap        rdn_new
+00000000 T _rdn_comp_free       libdsap        rdn_free
+00000000 T _rdn_free            libdsap        rdn_free
+00000000 T _rdn_comp_print      libdsap        rdn_print
+00000000 T _rdn_print           libdsap        rdn_print
+00000000 T _str2rdn_aux         libdsap        rdn_str
+00000000 T _str2rdn             libdsap        rdn_str
+00000000 T _rdn_merge           libdsap        rdn_merge
+00000000 T _utcprint            libdsap        time
+00000000 T _time_syntax         libdsap        time
+00000000 T _integer_syntax      libdsap        integer
+00000000 T _boolean_syntax      libdsap        boolean
+00000000 T _iso8859print        libdsap        string
+00000000 T _r_octenc            libdsap        string
+00000000 T _check_3166          libdsap        string
+00000000 T _r_octsdec           libdsap        string
+00000000 T _check_print_string  libdsap        string
+00000000 T _r_octparse          libdsap        string
+00000000 T _octparse            libdsap        string
+00000000 T _prtparse            libdsap        string
+00000000 T _cryptstring         libdsap        string
+00000000 T _cryptparse          libdsap        string
+00000000 T _sfree               libdsap        string
+00000000 T _pstrcmp             libdsap        string
+00000000 T _passwdcmp           libdsap        string
+00000000 T _telcmp              libdsap        string
+00000000 T _telstrlen           libdsap        string
+00000000 T _telncmp             libdsap        string
+00000000 T _strprint            libdsap        string
+00000000 T _cryptprint          libdsap        string
+00000000 T _r_octprint          libdsap        string
+00000000 T _octprint            libdsap        string
+00000000 T _qb_cmp              libdsap        string
+00000000 T _nbcmp               libdsap        string
+00000000 T _qb_cpy              libdsap        string
+00000000 T _part_print          libdsap        string
+00000000 T _part_parse          libdsap        string
+00000000 T _case_exact_match    libdsap        string
+00000000 T _approx_string       libdsap        string
+00000000 T _sub_string          libdsap        string
+00000000 T _telephone_match     libdsap        string
+00000000 T _string_syntaxes     libdsap        string
+00000000 T _mailbox_syntax      libdsap        mailbox
+00000000 T _fax_syntax          libdsap        fax
+00000000 T _post_syntax         libdsap        post
+00000000 T _telex_syntax        libdsap        telex
+00000000 T _teletex_syntax      libdsap        teletex
+00000000 T _pref_deliv_syntax   libdsap        pdm
+00000000 T _guide_syntax        libdsap        guide
+00000000 T _first_word          libdsap        soundex
+00000000 T _next_word           libdsap        soundex
+00000000 T _soundex             libdsap        soundex
+00000000 T _soundex_cmp         libdsap        soundex
+00000000 T _soundex_match       libdsap        soundex
+00000000 T _dsap_tai            libdsap        sys_tai
+00000000 T _dsap_init           libdsap        sys_init
+00000000 T _dsap_tai_init       libdsap        tai_init
+00000000 T _tai_string          libdsap        tai_init
+00000000 T _tai_args            libdsap        tai_args
+00000000 T _cert_enc            libdsap        certificate
+00000000 T _cert_dec            libdsap        certificate
+00000000 T _alg_cpy             libdsap        certificate
+00000000 T _cert_cpy            libdsap        certificate
+00000000 T _cert_free           libdsap        certificate
+00000000 T _str2alg             libdsap        certificate
+00000000 T _str2encrypted       libdsap        certificate
+00000000 T _str2cert            libdsap        certificate
+00000000 T _print_algid         libdsap        certificate
+00000000 T _print_encrypted     libdsap        certificate
+00000000 T _printcert           libdsap        certificate
+00000000 T _cert_cmp            libdsap        certificate
+00000000 T _certificate_syntax  libdsap        certificate
+00000000 T _cpair_enc           libdsap        cpair
+00000000 T _cpair_dec           libdsap        cpair
+00000000 T _str2cpair           libdsap        cpair
+00000000 T _printcpair          libdsap        cpair
+00000000 T _cpair_cpy           libdsap        cpair
+00000000 T _cpair_cmp           libdsap        cpair
+00000000 T _cpair_free          libdsap        cpair
+00000000 T _certificate_pair_syntax libdsap        cpair
+00000000 T _hash2str            libdsap        protected
+00000000 T _hash_passwd         libdsap        protected
+00000000 T _check_guard         libdsap        protected
+00000000 T _protected_password_syntax libdsap        protected
+00000000 T _subord_cpy          libdsap        cache
+00000000 T _cache_list          libdsap        cache
+00000000 T _delete_list_cache   libdsap        cache
+00000000 T _find_list_cache     libdsap        cache
+00000000 T _free_all_list_cache libdsap        cache
+00000000 T _cache_entry         libdsap        cache
+00000000 T _delete_cache        libdsap        cache
+00000000 T _local_find_entry    libdsap        cache
+00000000 T _local_find_entry_aux libdsap        cache
+00000000 T _get_copy_dn         libdsap        cache
+00000000 T _unravel_attribute   libdsap        cache
+00000000 T _check_schema        libdsap        cache
+00000000 T _new_version         libdsap        cache
+00000000 T _directory_free      libdsap        entry
+00000000 T _entry_free          libdsap        entry
+00000000 T _entry_replace       libdsap        entry
+00000000 T _entry_cpy           libdsap        entry
+00000000 T _get_default_entry   libdsap        entry
+00000000 T _check_known_oids    libdsap        entry
+00000000 T _entryrdn_cmp        libdsap        entry
+00000000 T _entry_cmp           libdsap        entry
+00000000 T _free_phylinebuf     libdsap        parse
+00000000 T _getline             libdsap        parse
+00000000 T _getnextline         libdsap        parse
+00000000 T _unesc_cont          libdsap        parse
+00000000 T _fpwr_esc            libdsap        parse
+00000000 T _pswr_esc            libdsap        parse
+00000000 T _cnt_escp            libdsap        parse
+00000000 T _srealloc            libdsap        parse
+00000000 T _get_attributes_aux  libdsap        parse
+00000000 T _get_attributes      libdsap        parse
+00000000 T _get_entry_aux       libdsap        parse
+00000000 T _get_entry           libdsap        parse
+00000000 T _new_constructor     libdsap        parse
+00000000 T _make_path           libdsap        parse
+00000000 T _aet_match           libdsap        ufn_aet
+00000000 T _DNS_append          libdsap        ufn_parse
+00000000 T _dnSelect            libdsap        ufn_parse
+00000000 T _ufn_search          libdsap        ufn_parse
+00000000 T _read_envlist        libdsap        ufn_parse
+00000000 T _ufn_match           libdsap        ufn_parse
+00000000 T _ufn_init            libdsap        ufn_parse
+00000000 T _set_lookup_ufn      libdsap        aetufn
+00000000 T _set_lookup_dap      libdsap        aetdap
+00000000 T _asnstr2pe           libdsap        nrs_info
+00000000 T _nrs_info_syntax     libdsap        nrs_info
+00000000 T _setAttributeLine    libdsap        inherit
+00000000 T _nextAttributeLine   libdsap        inherit
+00000000 T _inherit_syntax      libdsap        inherit
+00000000 T _audio_print         libdsap        audio
+00000000 T _audio_syntax        libdsap        audio
+00000000 T _reset_arg           libdsap        cstrings
+00000000 T _print_arg_error     libdsap        cstrings
+00000000 T _test_arg            libdsap        cstrings
+00000000 T _set_default_service libdsap        service
+00000000 T _get_default_service libdsap        service
+00000000 T _service_control     libdsap        service
+00000000 T _do_service_control  libdsap        service
+00000000 T _shuffle_up          libdsap        service
+00000000 T _new_service         libdsap        service
+00000000 T _set_sequence        libdsap        service
+00000000 T _unset_sequence      libdsap        service
+00000000 T _add_sequence        libdsap        service
+00000000 T _sequence_dn         libdsap        service
+00000000 T _show_sequence       libdsap        service
+00000000 T _check_security_parms libdsap        security
+00000000 T _cilist_syntax       libdsap        cilist
+00000000 T _str2permission      libdsap        policy
+00000000 T _subords_free        libdsap        ds_ext
+00000000 T _ems_free            libdsap        ds_ext
+00000000 T _aps_free            libdsap        ds_ext
+00000000 T _crefs_free          libdsap        ds_ext
+00000000 T _qap_cpy             libdsap        ap
+00000000 T _ap_syntax           libdsap        ap
+00000000 T _avl_insert          libdsap        turbo_avl
+00000000 T _avl_delete          libdsap        turbo_avl
+00000000 T _avl_inapply         libdsap        turbo_avl
+00000000 T _avl_postapply       libdsap        turbo_avl
+00000000 T _avl_preapply        libdsap        turbo_avl
+00000000 T _avl_apply           libdsap        turbo_avl
+00000000 T _avl_prefixapply     libdsap        turbo_avl
+00000000 T _avl_free            libdsap        turbo_avl
+00000000 T _avl_find            libdsap        turbo_avl
+00000000 T _avl_getfirst        libdsap        turbo_avl
+00000000 T _avl_getnext         libdsap        turbo_avl
+00000000 T _avl_dup_error       libdsap        turbo_avl
+00000000 T _strrev              libdsap        turbo_index
+00000000 T _index_soundex_cmp   libdsap        turbo_index
+00000000 T _index_soundex_prefix libdsap        turbo_index
+00000000 T _substring_prefix_cmp libdsap        turbo_index
+00000000 T _substring_prefix_tel_cmp libdsap        turbo_index
+00000000 T _substring_prefix_case_cmp libdsap        turbo_index
+00000000 T _indexav_cmp         libdsap        turbo_index
+00000000 T _new_indexnode       libdsap        turbo_index
+00000000 T _idn_cmp             libdsap        turbo_index
+00000000 T _th_prefix           libdsap        turbo_index
+00000000 T _turbo_add2index     libdsap        turbo_index
+00000000 T _turbo_index_delete  libdsap        turbo_index
+00000000 T _turbo_isoptimized   libdsap        turbo_index
+00000000 T _turbo_optimize      libdsap        turbo_index
+00000000 T _index_subtree       libdsap        turbo_index
+00000000 T _index_siblings      libdsap        turbo_index
+00000000 T _check_dsa_known_oids libdsap        attribute
+00000000 T _real_unravel_attribute libdsap        attribute
+00000000 T _set_inheritance     libdsap        attribute
+00000000 T _entry_find_type     libdsap        attribute
+00000000 T _documentStore_syntax libdsap        docstore
+00000000 T _QoS_syntax          libdsap        qos
+00000000 T _find_nest           libdsap        attr_sntx
+00000000 T _str2attrSeq         libdsap        attr_sntx
+00000000 T _attrSntx_enc        libdsap        attr_sntx
+00000000 T _attrSntx_dec        libdsap        attr_sntx
+00000000 T _attribute_syntax    libdsap        attr_sntx
+00000000 T _decode_t4           libdsap        photo_dec
+00000000 T _decode_t4_aux       libdsap        photo_dec
+00000000 T _next_run            libdsap        photo_dec
+00000000 T _decode_one          libdsap        photo_dec
+00000000 T _decode_two          libdsap        photo_dec
+00000000 T _undo_uncompressed_mode libdsap        photo_dec
+00000000 T _undo_pass_mode      libdsap        photo_dec
+00000000 T _undo_horiz_mode     libdsap        photo_dec
+00000000 T _undo_vert_mode      libdsap        photo_dec
+00000000 T _goto_b1             libdsap        photo_dec
+00000000 T _put_run             libdsap        photo_dec
+00000000 T _set_doutput         libdsap        photo_dec
+00000000 T _flush_doutput       libdsap        photo_dec
+00000000 T _set_dinput          libdsap        photo_dec
+00000000 T _get_node            libdsap        photo_build
+00000000 T _build_trees         libdsap        photo_build
+00000000 T _add_tree            libdsap        photo_build
+00000000 T _get_bit             libdsap        photo_util
+00000000 T _set_bit             libdsap        photo_util
+00000000 T _clr_bit             libdsap        photo_util
+00000000 T _photo_start         libdsap        photo_stub
+00000000 T _photo_end           libdsap        photo_stub
+00000000 T _photo_black         libdsap        photo_stub
+00000000 T _photo_white         libdsap        photo_stub
+00000000 T _photo_line_end      libdsap        photo_stub
+00000000 T _dsa_control_syntax  libdsap        dsa_control
+00000000 T _dsa_control_print   libdsap        dsa_control
+00000000 T _dsa_control_cmp     libdsap        dsa_control
+00000000 T _dsa_control_free    libdsap        dsa_control
+00000000 T _str2dsa_control     libdsap        dsa_control
+00000000 T _optional_dn_free    libdsap        dsa_control
+00000000 T _quipu_call_syntax   libdsap        dsa_control
+00000000 T _str2quipu_call      libdsap        dsa_control
+00000000 T _quipu_call_print    libdsap        dsa_control
+00000000 T _quipu_call_cpy      libdsap        dsa_control
+00000000 T _op_list_cpy         libdsap        dsa_control
+00000000 T _ops_cpy             libdsap        dsa_control
+00000000 T _chain_list_cpy      libdsap        dsa_control
+00000000 T _sub_ch_list_cpy     libdsap        dsa_control
+00000000 T _quipu_call_cmp      libdsap        dsa_control
+00000000 T _quipu_call_free     libdsap        dsa_control
+00000000 T _op_list_free        libdsap        dsa_control
+00000000 T _ops_free            libdsap        dsa_control
+00000000 T _chain_list_free     libdsap        dsa_control
+00000000 T _auth_level_free     libdsap        dsa_control
+00000000 T _use_serv_null       libdsap        osisec-int
+00000000 T _nullsigned          libdsap        osisec-int
+00000000 T _nullverify          libdsap        osisec-int
+00000000 T _null_ckpath         libdsap        osisec-int
+00000000 T _null_mkpath         libdsap        osisec-int
+00000000 T _nullencrypted       libdsap        osisec-int
+00000000 T _nulldecrypted       libdsap        osisec-int
+00000000 T _nullmknonce         libdsap        osisec-int
+00000000 T _nullcknonce         libdsap        osisec-int
+00000000 T _sacl_free           libdsap        searchacl
+00000000 T _lacl_free           libdsap        searchacl
+00000000 T _sacl_cmp            libdsap        searchacl
+00000000 T _sacl_print          libdsap        searchacl
+00000000 T _str2lacl            libdsap        searchacl
+00000000 T _lacl_print          libdsap        searchacl
+00000000 T _sacl_syntax         libdsap        searchacl
+00000000 T _lacl_syntax         libdsap        searchacl
+00000000 T _authp_cmp           libdsap        authpolicy
+00000000 T _authp_print         libdsap        authpolicy
+00000000 T _authp_syntax        libdsap        authpolicy
+00000000 T _DspAsynBindReqAux   libdsap        dsapbind1
+00000000 T _DspAsynBindRequest  libdsap        dsapbind1
+00000000 T _QspAsynBindReqAux   libdsap        dsapbind1
+00000000 T _QspAsynBindRequest  libdsap        dsapbind1
+00000000 T _DspAsynBindRetry    libdsap        dsapbind1
+00000000 T _QspAsynBindRetry    libdsap        dsapbind1
+00000000 T _DBindDecode         libdsap        dsapbind1
+00000000 T _IspAsynBindReqAux   libdsap        dsapbind1
+00000000 T _IspAsynBindRequest  libdsap        dsapbind1
+00000000 T _IspAsynBindRetry    libdsap        dsapbind1
+00000000 T _DBindInit           libdsap        dsapbind2
+00000000 T _DBindResult         libdsap        dsapbind2
+00000000 T _DBindError          libdsap        dsapbind2
+00000000 T _DBindReject         libdsap        dsapbind2
+00000000 T _select_context      libdsap        dsapcontexts
+00000000 T _judge_ctxlist       libdsap        dsapcontexts
+00000000 T _find_ctx_id         libdsap        dsapcontexts
+00000000 T _check_dap_ctxlist   libdsap        dsapcontexts
+00000000 T _check_dsp_ctxlist   libdsap        dsapcontexts
+00000000 T _check_qsp_ctxlist   libdsap        dsapcontexts
+00000000 T _check_isp_ctxlist   libdsap        dsapcontexts
+00000000 T _DUnBindRequest      libdsap        dsapunbind1
+00000000 T _DUnBindRetry        libdsap        dsapunbind1
+00000000 T _DUnBindAccept       libdsap        dsapunbind2
+00000000 T _DUnBindReject       libdsap        dsapunbind2
+00000000 T _DWaitRequest        libdsap        dsapwait
+00000000 T _DapRespWaitRequest  libdsap        dsapwait
+00000000 T _DspWaitRequest      libdsap        dsapwait
+00000000 T _QspWaitRequest      libdsap        dsapwait
+00000000 T _DapDecodeInvoke     libdsap        dsapwait
+00000000 T _DspDecodeInvoke     libdsap        dsapwait
+00000000 T _DspDecodeResult     libdsap        dsapwait
+00000000 T _QspDecodeInvoke     libdsap        dsapwait
+00000000 T _QspDecodeResult     libdsap        dsapwait
+00000000 T _DDecodeError        libdsap        dsapwait
+00000000 T _DDecodeUnbind       libdsap        dsapwait
+00000000 T _IspWaitRequest      libdsap        dsapwait
+00000000 T _IspDecodeInvoke     libdsap        dsapwait
+00000000 T _IspDecodeResult     libdsap        dsapwait
+00000000 T _watch_dog_final     libdsap        dsapwait
+00000000 T _watch_dog           libdsap        dsapwait
+00000000 T _watch_dog_aux       libdsap        dsapwait
+00000000 T _watch_dog_reset     libdsap        dsapwait
+00000000 T _watch_dog_final_reset libdsap        dsapwait
+00000000 T _DapInvokeRequest    libdsap        dsapinvoke
+00000000 T _DapEncodeInvoke     libdsap        dsapinvoke
+00000000 T _DspInvokeRequest    libdsap        dsapinvoke
+00000000 T _DspEncodeInvoke     libdsap        dsapinvoke
+00000000 T _QspInvokeRequest    libdsap        dsapinvoke
+00000000 T _QspEncodeInvoke     libdsap        dsapinvoke
+00000000 T _IspInvokeRequest    libdsap        dsapinvoke
+00000000 T _IspEncodeInvoke     libdsap        dsapinvoke
+00000000 T _DapResultRequest    libdsap        dsapresult
+00000000 T _DapEncodeResult     libdsap        dsapresult
+00000000 T _DspResultRequest    libdsap        dsapresult
+00000000 T _DspEncodeResult     libdsap        dsapresult
+00000000 T _QspResultRequest    libdsap        dsapresult
+00000000 T _QspEncodeResult     libdsap        dsapresult
+00000000 T _IspResultRequest    libdsap        dsapresult
+00000000 T _IspEncodeResult     libdsap        dsapresult
+00000000 T _DapErrorRequest     libdsap        dsaperror
+00000000 T _DspErrorRequest     libdsap        dsaperror
+00000000 T _QspErrorRequest     libdsap        dsaperror
+00000000 T _DEncodeError        libdsap        dsaperror
+00000000 T _IspErrorRequest     libdsap        dsaperror
+00000000 T _DRejectRequest      libdsap        dsapreject
+00000000 T _DUAbortRequest      libdsap        dsapabort
+00000000 T _ronot2dsaplose      libdsap        dsaprovider
+00000000 T _ros2dsaplose        libdsap        dsaprovider
+00000000 T _ros2dsapreject      libdsap        dsaprovider
+00000000 T _dsaplose            libdsap        dsaplose
+00000000 T _dsapreject          libdsap        dsaplose
+00000000 T _DapInitWaitRequest  libdsap        dapwait
+00000000 T _DapDecodeResult     libdsap        dapwait
+00000000 T _DapDecodeError      libdsap        dapwait
+00000000 T _ds_bind             libdsap        dapbind
+00000000 T _secure_ds_bind      libdsap        dapbind
+00000000 T _dap_bind            libdsap        dapbind
+00000000 T _DapAsynBindReqAux   libdsap        dapbind
+00000000 T _DapAsynBindRequest  libdsap        dapbind
+00000000 T _DapAsynBindRetry    libdsap        dapbind
+00000000 T _DapBindDecode       libdsap        dapbind
+00000000 T _ds_unbind           libdsap        dapunbind
+00000000 T _dap_unbind          libdsap        dapunbind
+00000000 T _DapUnBindRequest    libdsap        dapunbind
+00000000 T _DapUnBindRetry      libdsap        dapunbind
+00000000 T _dap_abandon         libdsap        dapabandon
+00000000 T _DapAbandon          libdsap        dapabandon
+00000000 T _dap_addentry        libdsap        dapaddent
+00000000 T _DapAddEntry         libdsap        dapaddent
+00000000 T _dap_compare         libdsap        dapcompare
+00000000 T _DapCompare          libdsap        dapcompare
+00000000 T _DapInvokeReqAux     libdsap        dapinvoke
+00000000 T _DapSyncInvokeRequest libdsap        dapinvoke
+00000000 T _DapIntrInvokeRequest libdsap        dapinvoke
+00000000 T _DapAsynInvokeRequest libdsap        dapinvoke
+00000000 T _DapInterrupt        libdsap        dapinvoke
+00000000 T _pdu_dump_init       libdsap        dapinvoke
+00000000 T _pdu_dump            libdsap        dapinvoke
+00000000 T _dap_list            libdsap        daplist
+00000000 T _DapList             libdsap        daplist
+00000000 T _dap_modifyentry     libdsap        dapmodent
+00000000 T _DapModifyEntry      libdsap        dapmodent
+00000000 T _dap_modifyrdn       libdsap        dapmodrdn
+00000000 T _DapModifyRDN        libdsap        dapmodrdn
+00000000 T _dap_read            libdsap        dapread
+00000000 T _DapRead             libdsap        dapread
+00000000 T _dap_removeentry     libdsap        daprement
+00000000 T _DapRemoveEntry      libdsap        daprement
+00000000 T _dap_search          libdsap        dapsearch
+00000000 T _DapSearch           libdsap        dapsearch
+00000000 T _daplose             libdsap        daplose
+00000000 T _dapreject           libdsap        daplose
+00000000 T _ronot2daplose       libdsap        daprovider
+00000000 T _ros2daplose         libdsap        daprovider
+00000000 T _ros2dapreject       libdsap        daprovider
+00000000 T _bind_arg_free       libdsap        ds_types
+00000000 T _op_arg_free         libdsap        ds_types
+00000000 T _ch_arg_free         libdsap        ds_types
+00000000 T _ds_arg_free         libdsap        ds_types
+00000000 T _read_arg_free       libdsap        ds_types
+00000000 T _compare_arg_free    libdsap        ds_types
+00000000 T _list_arg_free       libdsap        ds_types
+00000000 T _search_arg_free     libdsap        ds_types
+00000000 T _addentry_arg_free   libdsap        ds_types
+00000000 T _removeentry_arg_free libdsap        ds_types
+00000000 T _modifyentry_arg_free libdsap        ds_types
+00000000 T _modifyrdn_arg_free  libdsap        ds_types
+00000000 T _getedb_arg_free     libdsap        ds_types
+00000000 T _op_res_free         libdsap        ds_types
+00000000 T _ch_res_free         libdsap        ds_types
+00000000 T _ds_res_free         libdsap        ds_types
+00000000 T _trace_info_free     libdsap        ds_types
+00000000 T _ca_free             libdsap        ds_types
+00000000 T _extension_free      libdsap        ds_types
+00000000 T _cross_refs_free     libdsap        ds_types
+00000000 T _ds_arg_dup          libdsap        ds_types
+00000000 T _read_arg_dup        libdsap        ds_types
+00000000 T _compare_arg_dup     libdsap        ds_types
+00000000 T _abandon_arg_dup     libdsap        ds_types
+00000000 T _list_arg_dup        libdsap        ds_types
+00000000 T _search_arg_dup      libdsap        ds_types
+00000000 T _addentry_arg_dup    libdsap        ds_types
+00000000 T _removeentry_arg_dup libdsap        ds_types
+00000000 T _modifyentry_arg_dup libdsap        ds_types
+00000000 T _modifyrdn_arg_dup   libdsap        ds_types
+00000000 T _getedb_arg_dup      libdsap        ds_types
+00000000 T _ca_dup              libdsap        ds_types
+00000000 T _secp_cpy            libdsap        ds_types
+00000000 T _random_cpy          libdsap        ds_types
+00000000 T _sig_cpy             libdsap        ds_types
+00000000 T _ext_cpy             libdsap        ds_types
+00000000 T _filter_cpy          libdsap        ds_types
+00000000 T _filter_item_dup     libdsap        ds_types
+00000000 T _fi_sub_dup          libdsap        ds_types
+00000000 T _ems_cpy             libdsap        ds_types
+00000000 T _eis_dup             libdsap        ds_types
+00000000 T _ava_dup             libdsap        ds_types
+00000000 T _ros_log             libdsap        plog
+00000000 T _acs_log             libdsap        plog
+00000000 T _td_log              libdsap        plog
+00000000 T _SetROPS             libdsap        plog
+00000000 T _FWaitRequest        libftam        ftamprovider
+00000000 T _FWaitRequestAux     libftam        ftamprovider
+00000000 T _FSetIndications     libftam        ftamprovider
+00000000 T _acs2ftamlose        libftam        ftamprovider
+00000000 T _acs2ftamabort       libftam        ftamprovider
+00000000 T _ps2ftamlose         libftam        ftamprovider
+00000000 T _newfsblk            libftam        ftamprovider
+00000000 T _freefsblk           libftam        ftamprovider
+00000000 T _findfsblk           libftam        ftamprovider
+00000000 T _FErrString          libftam        ftamerror
+00000000 T _FInitializeRequest  libftam        ftaminitiate
+00000000 T _FInit               libftam        ftamrespond
+00000000 T _FInitializeResponse libftam        ftamrespond
+00000000 T _FTerminateRequest   libftam        ftamrelease1
+00000000 T _FTerminateResponse  libftam        ftamrelease2
+00000000 T _FUAbortRequest      libftam        ftamabort
+00000000 T _FAbortRequestAux    libftam        ftamabort
+00000000 T _FManageRequest      libftam        ftamgroup1
+00000000 T _FBulkBeginRequest   libftam        ftamgroup1
+00000000 T _FBulkEndRequest     libftam        ftamgroup1
+00000000 T _FManageResponse     libftam        ftamgroup2
+00000000 T _FBulkBeginResponse  libftam        ftamgroup2
+00000000 T _FBulkEndResponse    libftam        ftamgroup2
+00000000 T _FAccessRequest      libftam        ftamaccess1
+00000000 T _FAccessResponse     libftam        ftamaccess2
+00000000 T _FDataRequest        libftam        ftambulk
+00000000 T _FDataEndRequest     libftam        ftambulk
+00000000 T _FCancelRequest      libftam        ftambulk
+00000000 T _FCancelResponse     libftam        ftambulk
+00000000 T _FCancelResponseAux  libftam        ftambulk
+00000000 T _FReadWriteRequest   libftam        ftambulk1
+00000000 T _FTransEndRequest    libftam        ftambulk1
+00000000 T _FTransEndResponse   libftam        ftambulk2
+00000000 T _FSelectMask         libftam        ftamselect
+00000000 T _FHookRequest        libftam        ftamtrace
+00000000 T _FTraceHook          libftam        ftamtrace
+00000000 T _acl2fpm             libftam        ftamacl
+00000000 T _fpm2acl             libftam        ftamacl
+00000000 T _attr2fpm            libftam        ftamattr
+00000000 T _fpm2attr            libftam        ftamattr
+00000000 T _FAFREE              libftam        ftamattr
+00000000 T _bits2fpm            libftam        ftambits
+00000000 T _fpm2bits            libftam        ftambits
+00000000 T _chrg2fpm            libftam        ftamchrg
+00000000 T _fpm2chrg            libftam        ftamchrg
+00000000 T _conctl2fpm          libftam        ftamconctl
+00000000 T _fpm2conctl          libftam        ftamconctl
+00000000 T _conacc2fpm          libftam        ftamconctl
+00000000 T _fpm2conacc          libftam        ftamconctl
+00000000 T _diag2fpm            libftam        ftamdiag
+00000000 T _fpm2diag            libftam        ftamdiag
+00000000 T _faduid2fpm          libftam        ftamfaduid
+00000000 T _fpm2faduid          libftam        ftamfaduid
+00000000 T _pass2fpm            libftam        ftampass
+00000000 T _fpm2pass            libftam        ftampass
+00000000 T _shared2fpm          libftam        ftamshare
+00000000 T _fpm2shared          libftam        ftamshare
+00000000 T _fpktlose            libftam        ftamlose
+00000000 T _ftamlose            libftam        ftamlose
+00000000 T _ftamoops            libftam        ftamlose
+00000000 T _setisodocument      libftam        ftamdocument
+00000000 T _endisodocument      libftam        ftamdocument
+00000000 T _getisodocument      libftam        ftamdocument
+00000000 T _getisodocumentbyentry libftam        ftamdocument
+00000000 T _getisodocumentbytype libftam        ftamdocument
+00000000 T _fdf_p2names         libftam        ftamfdf
+00000000 T _fdf_names2p         libftam        ftamfdf
+00000000 T _fdf_attrs2d         libftam        ftamfdf
+00000000 T _fdf_d2attrs         libftam        ftamfdf
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/jump/jump.import isode-8.0/jump/jump.import
--- old/isode-8.0/jump/jump.import	Thu Jan  1 01:00:00 1970
+++ isode-8.0/jump/jump.import	Thu Aug 26 14:24:23 1993
@@ -0,0 +1,917 @@
+/usr/lib/libc.sa(__libc.o):00001000 a __GOT_SIZE
+/usr/lib/libc.sa(__libc.o):6008f0b0 A _AL
+/usr/lib/libc.sa(__libc.o):6008f198 A _AL_PARM
+/usr/lib/libc.sa(__libc.o):6008f060 A _AM
+/usr/lib/libc.sa(__libc.o):6008f0b4 A _BC
+/usr/lib/libc.sa(__libc.o):6008f064 A _BS
+/usr/lib/libc.sa(__libc.o):6008f0bc A _BT
+/usr/lib/libc.sa(__libc.o):6008f068 A _CA
+/usr/lib/libc.sa(__libc.o):6008f0c0 A _CD
+/usr/lib/libc.sa(__libc.o):6008f0c4 A _CE
+/usr/lib/libc.sa(__libc.o):6008f0c8 A _CL
+/usr/lib/libc.sa(__libc.o):6008f0cc A _CM
+/usr/lib/libc.sa(__libc.o):6008f048 A _COLS
+/usr/lib/libc.sa(__libc.o):6008f0d0 A _CR
+/usr/lib/libc.sa(__libc.o):6008f0d4 A _CS
+/usr/lib/libc.sa(__libc.o):6008f06c A _DA
+/usr/lib/libc.sa(__libc.o):6008f070 A _DB
+/usr/lib/libc.sa(__libc.o):6008f0d8 A _DC
+/usr/lib/libc.sa(__libc.o):6008f0dc A _DL
+/usr/lib/libc.sa(__libc.o):6008f19c A _DL_PARM
+/usr/lib/libc.sa(__libc.o):6008f0e0 A _DM
+/usr/lib/libc.sa(__libc.o):6008f0e4 A _DO
+/usr/lib/libc.sa(__libc.o):6008f1a4 A _DOWN_PARM
+/usr/lib/libc.sa(__libc.o):6008f03c A _Def_term
+/usr/lib/libc.sa(__libc.o):6008f0e8 A _ED
+/usr/lib/libc.sa(__libc.o):6008f0ec A _EI
+/usr/lib/libc.sa(__libc.o):6008f074 A _EO
+/usr/lib/libc.sa(__libc.o):6008f1b8 A _GT
+/usr/lib/libc.sa(__libc.o):6008f078 A _HC
+/usr/lib/libc.sa(__libc.o):6008f118 A _HO
+/usr/lib/libc.sa(__libc.o):6008f07c A _HZ
+/usr/lib/libc.sa(__libc.o):6008f11c A _IC
+/usr/lib/libc.sa(__libc.o):6008f120 A _IM
+/usr/lib/libc.sa(__libc.o):6008f080 A _IN
+/usr/lib/libc.sa(__libc.o):6008f124 A _IP
+/usr/lib/libc.sa(__libc.o):6008f0f0 A _K0
+/usr/lib/libc.sa(__libc.o):6008f0f4 A _K1
+/usr/lib/libc.sa(__libc.o):6008f0f8 A _K2
+/usr/lib/libc.sa(__libc.o):6008f0fc A _K3
+/usr/lib/libc.sa(__libc.o):6008f100 A _K4
+/usr/lib/libc.sa(__libc.o):6008f104 A _K5
+/usr/lib/libc.sa(__libc.o):6008f108 A _K6
+/usr/lib/libc.sa(__libc.o):6008f10c A _K7
+/usr/lib/libc.sa(__libc.o):6008f110 A _K8
+/usr/lib/libc.sa(__libc.o):6008f114 A _K9
+/usr/lib/libc.sa(__libc.o):6008f128 A _KD
+/usr/lib/libc.sa(__libc.o):6008f12c A _KE
+/usr/lib/libc.sa(__libc.o):6008f130 A _KH
+/usr/lib/libc.sa(__libc.o):6008f134 A _KL
+/usr/lib/libc.sa(__libc.o):6008f138 A _KR
+/usr/lib/libc.sa(__libc.o):6008f13c A _KS
+/usr/lib/libc.sa(__libc.o):6008f140 A _KU
+/usr/lib/libc.sa(__libc.o):6008f1a8 A _LEFT_PARM
+/usr/lib/libc.sa(__libc.o):6008f044 A _LINES
+/usr/lib/libc.sa(__libc.o):6008f144 A _LL
+/usr/lib/libc.sa(__libc.o):6008f148 A _MA
+/usr/lib/libc.sa(__libc.o):6008f084 A _MI
+/usr/lib/libc.sa(__libc.o):6008f088 A _MS
+/usr/lib/libc.sa(__libc.o):6008f030 A _My_term
+/usr/lib/libc.sa(__libc.o):6008f08c A _NC
+/usr/lib/libc.sa(__libc.o):6008f14c A _ND
+/usr/lib/libc.sa(__libc.o):6008f150 A _NL
+/usr/lib/libc.sa(__libc.o):6008f1bc A _NONL
+/usr/lib/libc.sa(__libc.o):6008f090 A _NS
+/usr/lib/libc.sa(__libc.o):6008f094 A _OS
+/usr/lib/libc.sa(__libc.o):6008f1b0 A _PC
+/usr/lib/libc.sa(__libc.o):6008f154 A _RC
+/usr/lib/libc.sa(__libc.o):6008f1ac A _RIGHT_PARM
+/usr/lib/libc.sa(__libc.o):6008f158 A _SC
+/usr/lib/libc.sa(__libc.o):6008f15c A _SE
+/usr/lib/libc.sa(__libc.o):6008f160 A _SF
+/usr/lib/libc.sa(__libc.o):6008f164 A _SO
+/usr/lib/libc.sa(__libc.o):6008f168 A _SR
+/usr/lib/libc.sa(__libc.o):6008f16c A _TA
+/usr/lib/libc.sa(__libc.o):6008f170 A _TE
+/usr/lib/libc.sa(__libc.o):6008f174 A _TI
+/usr/lib/libc.sa(__libc.o):6008f178 A _UC
+/usr/lib/libc.sa(__libc.o):6008f17c A _UE
+/usr/lib/libc.sa(__libc.o):6008f098 A _UL
+/usr/lib/libc.sa(__libc.o):6008f180 A _UP
+/usr/lib/libc.sa(__libc.o):6008f1c0 A _UPPERCASE
+/usr/lib/libc.sa(__libc.o):6008f1a0 A _UP_PARM
+/usr/lib/libc.sa(__libc.o):6008f188 A _US
+/usr/lib/libc.sa(__libc.o):6008f18c A _VB
+/usr/lib/libc.sa(__libc.o):6008f194 A _VE
+/usr/lib/libc.sa(__libc.o):6008f190 A _VS
+/usr/lib/libc.sa(__libc.o):6008f09c A _XB
+/usr/lib/libc.sa(__libc.o):6008f0a0 A _XN
+/usr/lib/libc.sa(__libc.o):6008f0a8 A _XS
+/usr/lib/libc.sa(__libc.o):6008f0a4 A _XT
+/usr/lib/libc.sa(__libc.o):6008f0ac A _XX
+/usr/lib/libc.sa(__libc.o):6008f1f4 A __9streambuf$_list_all
+/usr/lib/libc.sa(__libc.o):6008f214 A ____brk_addr
+/usr/lib/libc.sa(__libc.o):6008f01c A ___ctype_b
+/usr/lib/libc.sa(__libc.o):6008f020 A ___ctype_tolower
+/usr/lib/libc.sa(__libc.o):6008f024 A ___ctype_toupper
+/usr/lib/libc.sa(__libc.o):6008f1fc A ___environ
+/usr/lib/libc.sa(__libc.o):6008f250 A ___exit_funcs
+/usr/lib/libc.sa(__libc.o):6008f2f0 A ___glob_closedir_hook
+/usr/lib/libc.sa(__libc.o):6008f2f4 A ___glob_opendir_hook
+/usr/lib/libc.sa(__libc.o):6008f2f8 A ___glob_readdir_hook
+/usr/lib/libc.sa(__libc.o):6008f018 A ___new_handler
+/usr/lib/libc.sa(__libc.o):6008f1e4 A ___std_filebuf_0
+/usr/lib/libc.sa(__libc.o):6008f1e8 A ___std_filebuf_1
+/usr/lib/libc.sa(__libc.o):6008f1ec A ___std_filebuf_2
+/usr/lib/libc.sa(__libc.o):6008f278 A ___ttyname
+/usr/lib/libc.sa(__libc.o):6008f238 A __collate_info
+/usr/lib/libc.sa(__libc.o):6008f23c A __ctype_info
+/usr/lib/libc.sa(__libc.o):6008f028 A __echoit
+/usr/lib/libc.sa(__libc.o):6008f034 A __endwin
+/usr/lib/libc.sa(__libc.o):6008f288 A __gdbm_fetch_val
+/usr/lib/libc.sa(__libc.o):6008f280 A __gdbm_file
+/usr/lib/libc.sa(__libc.o):6008f284 A __gdbm_memory
+/usr/lib/libc.sa(__libc.o):6008f1f8 A __iob
+/usr/lib/libc.sa(__libc.o):6008f240 A __monetary_info
+/usr/lib/libc.sa(__libc.o):6008f234 A __null_auth
+/usr/lib/libc.sa(__libc.o):6008f244 A __numeric_info
+/usr/lib/libc.sa(__libc.o):6008f2ec A __obstack
+/usr/lib/libc.sa(__libc.o):6008f1c8 A __pfast
+/usr/lib/libc.sa(__libc.o):6008f02c A __rawmode
+/usr/lib/libc.sa(__libc.o):6008f1dc A __res
+/usr/lib/libc.sa(__libc.o):6008f04c A __res_iflg
+/usr/lib/libc.sa(__libc.o):6008f050 A __res_lflg
+/usr/lib/libc.sa(__libc.o):6008f270 A __res_opcodes
+/usr/lib/libc.sa(__libc.o):6008f274 A __res_resultcodes
+/usr/lib/libc.sa(__libc.o):6008f248 A __response_info
+/usr/lib/libc.sa(__libc.o):6008f2fc A __sigintr
+/usr/lib/libc.sa(__libc.o):6008f00c A __sys_errlist
+/usr/lib/libc.sa(__libc.o):6008f010 A __sys_nerr
+/usr/lib/libc.sa(__libc.o):6008f014 A __sys_siglist
+/usr/lib/libc.sa(__libc.o):6008f24c A __time_info
+/usr/lib/libc.sa(__libc.o):6008f05c A __tty
+/usr/lib/libc.sa(__libc.o):6008f040 A __tty_ch
+/usr/lib/libc.sa(__libc.o):6008f1cc A __unctrl
+/usr/lib/libc.sa(__libc.o):6008f2c8 A __vt$10istrstream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2c4 A __vt$10ostrstream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2e0 A __vt$11fstreambase$3ios
+/usr/lib/libc.sa(__libc.o):6008f2cc A __vt$13strstreambase$3ios
+/usr/lib/libc.sa(__libc.o):6008f2d4 A __vt$7fstream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2ac A __vt$7ostream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2dc A __vt$8ifstream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2a4 A __vt$8iostream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2d8 A __vt$8ofstream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2c0 A __vt$9strstream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2b4 A __vt$backupbuf
+/usr/lib/libc.sa(__libc.o):6008f2b0 A __vt$filebuf
+/usr/lib/libc.sa(__libc.o):6008f2bc A __vt$ios
+/usr/lib/libc.sa(__libc.o):6008f2a8 A __vt$istream$3ios
+/usr/lib/libc.sa(__libc.o):6008f2b8 A __vt$streambuf
+/usr/lib/libc.sa(__libc.o):6008f2d0 A __vt$strstreambuf
+/usr/lib/libc.sa(__libc.o):6008f27c A __win
+/usr/lib/libc.sa(__libc.o):6008f294 A _cerr
+/usr/lib/libc.sa(__libc.o):6008f298 A _cin
+/usr/lib/libc.sa(__libc.o):6008f29c A _clog
+/usr/lib/libc.sa(__libc.o):6008f290 A _cout
+/usr/lib/libc.sa(__libc.o):6008f058 A _curscr
+/usr/lib/libc.sa(__libc.o):6008f228 A _daylight
+/usr/lib/libc.sa(__libc.o):6008f200 A _errno
+/usr/lib/libc.sa(__libc.o):6008f1d0 A _gdbm_errno
+/usr/lib/libc.sa(__libc.o):6008f28c A _gdbm_version
+/usr/lib/libc.sa(__libc.o):6008f008 A _h_errlist
+/usr/lib/libc.sa(__libc.o):6008f1d8 A _h_errno
+/usr/lib/libc.sa(__libc.o):6008f2a0 A _h_nerr
+/usr/lib/libc.sa(__libc.o):6008f1c4 A _normtty
+/usr/lib/libc.sa(__libc.o):6008f1f0 A _not_open_filebuf
+/usr/lib/libc.sa(__libc.o):6008f204 A _optarg
+/usr/lib/libc.sa(__libc.o):6008f20c A _opterr
+/usr/lib/libc.sa(__libc.o):6008f208 A _optind
+/usr/lib/libc.sa(__libc.o):6008f2e4 A _optopt
+/usr/lib/libc.sa(__libc.o):6008f218 A _ospeed
+/usr/lib/libc.sa(__libc.o):6008f26c A _re_max_failures
+/usr/lib/libc.sa(__libc.o):6008f210 A _re_syntax_options
+/usr/lib/libc.sa(__libc.o):6008f1e0 A _rexecoptions
+/usr/lib/libc.sa(__libc.o):6008f230 A _rpc_createerr
+/usr/lib/libc.sa(__libc.o):6008f25c A _stderr
+/usr/lib/libc.sa(__libc.o):6008f254 A _stdin
+/usr/lib/libc.sa(__libc.o):6008f258 A _stdout
+/usr/lib/libc.sa(__libc.o):6008f054 A _stdscr
+/usr/lib/libc.sa(__libc.o):6008f2e8 A _svc_fdset
+/usr/lib/libc.sa(__libc.o):6008f224 A _timezone
+/usr/lib/libc.sa(__libc.o):6008f21c A _tputs_baud_rate
+/usr/lib/libc.sa(__libc.o):6008f038 A _ttytype
+/usr/lib/libc.sa(__libc.o):6008f220 A _tzname
+/usr/lib/libcurses.sa(__libc.o):00001000 a __GOT_SIZE
+/usr/lib/libcurses.sa(__libc.o):6008f0b0 A _AL
+/usr/lib/libcurses.sa(__libc.o):6008f198 A _AL_PARM
+/usr/lib/libcurses.sa(__libc.o):6008f060 A _AM
+/usr/lib/libcurses.sa(__libc.o):6008f0b4 A _BC
+/usr/lib/libcurses.sa(__libc.o):6008f064 A _BS
+/usr/lib/libcurses.sa(__libc.o):6008f0bc A _BT
+/usr/lib/libcurses.sa(__libc.o):6008f068 A _CA
+/usr/lib/libcurses.sa(__libc.o):6008f0c0 A _CD
+/usr/lib/libcurses.sa(__libc.o):6008f0c4 A _CE
+/usr/lib/libcurses.sa(__libc.o):6008f0c8 A _CL
+/usr/lib/libcurses.sa(__libc.o):6008f0cc A _CM
+/usr/lib/libcurses.sa(__libc.o):6008f048 A _COLS
+/usr/lib/libcurses.sa(__libc.o):6008f0d0 A _CR
+/usr/lib/libcurses.sa(__libc.o):6008f0d4 A _CS
+/usr/lib/libcurses.sa(__libc.o):6008f06c A _DA
+/usr/lib/libcurses.sa(__libc.o):6008f070 A _DB
+/usr/lib/libcurses.sa(__libc.o):6008f0d8 A _DC
+/usr/lib/libcurses.sa(__libc.o):6008f0dc A _DL
+/usr/lib/libcurses.sa(__libc.o):6008f19c A _DL_PARM
+/usr/lib/libcurses.sa(__libc.o):6008f0e0 A _DM
+/usr/lib/libcurses.sa(__libc.o):6008f0e4 A _DO
+/usr/lib/libcurses.sa(__libc.o):6008f1a4 A _DOWN_PARM
+/usr/lib/libcurses.sa(__libc.o):6008f03c A _Def_term
+/usr/lib/libcurses.sa(__libc.o):6008f0e8 A _ED
+/usr/lib/libcurses.sa(__libc.o):6008f0ec A _EI
+/usr/lib/libcurses.sa(__libc.o):6008f074 A _EO
+/usr/lib/libcurses.sa(__libc.o):6008f1b8 A _GT
+/usr/lib/libcurses.sa(__libc.o):6008f078 A _HC
+/usr/lib/libcurses.sa(__libc.o):6008f118 A _HO
+/usr/lib/libcurses.sa(__libc.o):6008f07c A _HZ
+/usr/lib/libcurses.sa(__libc.o):6008f11c A _IC
+/usr/lib/libcurses.sa(__libc.o):6008f120 A _IM
+/usr/lib/libcurses.sa(__libc.o):6008f080 A _IN
+/usr/lib/libcurses.sa(__libc.o):6008f124 A _IP
+/usr/lib/libcurses.sa(__libc.o):6008f0f0 A _K0
+/usr/lib/libcurses.sa(__libc.o):6008f0f4 A _K1
+/usr/lib/libcurses.sa(__libc.o):6008f0f8 A _K2
+/usr/lib/libcurses.sa(__libc.o):6008f0fc A _K3
+/usr/lib/libcurses.sa(__libc.o):6008f100 A _K4
+/usr/lib/libcurses.sa(__libc.o):6008f104 A _K5
+/usr/lib/libcurses.sa(__libc.o):6008f108 A _K6
+/usr/lib/libcurses.sa(__libc.o):6008f10c A _K7
+/usr/lib/libcurses.sa(__libc.o):6008f110 A _K8
+/usr/lib/libcurses.sa(__libc.o):6008f114 A _K9
+/usr/lib/libcurses.sa(__libc.o):6008f128 A _KD
+/usr/lib/libcurses.sa(__libc.o):6008f12c A _KE
+/usr/lib/libcurses.sa(__libc.o):6008f130 A _KH
+/usr/lib/libcurses.sa(__libc.o):6008f134 A _KL
+/usr/lib/libcurses.sa(__libc.o):6008f138 A _KR
+/usr/lib/libcurses.sa(__libc.o):6008f13c A _KS
+/usr/lib/libcurses.sa(__libc.o):6008f140 A _KU
+/usr/lib/libcurses.sa(__libc.o):6008f1a8 A _LEFT_PARM
+/usr/lib/libcurses.sa(__libc.o):6008f044 A _LINES
+/usr/lib/libcurses.sa(__libc.o):6008f144 A _LL
+/usr/lib/libcurses.sa(__libc.o):6008f148 A _MA
+/usr/lib/libcurses.sa(__libc.o):6008f084 A _MI
+/usr/lib/libcurses.sa(__libc.o):6008f088 A _MS
+/usr/lib/libcurses.sa(__libc.o):6008f030 A _My_term
+/usr/lib/libcurses.sa(__libc.o):6008f08c A _NC
+/usr/lib/libcurses.sa(__libc.o):6008f14c A _ND
+/usr/lib/libcurses.sa(__libc.o):6008f150 A _NL
+/usr/lib/libcurses.sa(__libc.o):6008f1bc A _NONL
+/usr/lib/libcurses.sa(__libc.o):6008f090 A _NS
+/usr/lib/libcurses.sa(__libc.o):6008f094 A _OS
+/usr/lib/libcurses.sa(__libc.o):6008f1b0 A _PC
+/usr/lib/libcurses.sa(__libc.o):6008f154 A _RC
+/usr/lib/libcurses.sa(__libc.o):6008f1ac A _RIGHT_PARM
+/usr/lib/libcurses.sa(__libc.o):6008f158 A _SC
+/usr/lib/libcurses.sa(__libc.o):6008f15c A _SE
+/usr/lib/libcurses.sa(__libc.o):6008f160 A _SF
+/usr/lib/libcurses.sa(__libc.o):6008f164 A _SO
+/usr/lib/libcurses.sa(__libc.o):6008f168 A _SR
+/usr/lib/libcurses.sa(__libc.o):6008f16c A _TA
+/usr/lib/libcurses.sa(__libc.o):6008f170 A _TE
+/usr/lib/libcurses.sa(__libc.o):6008f174 A _TI
+/usr/lib/libcurses.sa(__libc.o):6008f178 A _UC
+/usr/lib/libcurses.sa(__libc.o):6008f17c A _UE
+/usr/lib/libcurses.sa(__libc.o):6008f098 A _UL
+/usr/lib/libcurses.sa(__libc.o):6008f180 A _UP
+/usr/lib/libcurses.sa(__libc.o):6008f1c0 A _UPPERCASE
+/usr/lib/libcurses.sa(__libc.o):6008f1a0 A _UP_PARM
+/usr/lib/libcurses.sa(__libc.o):6008f188 A _US
+/usr/lib/libcurses.sa(__libc.o):6008f18c A _VB
+/usr/lib/libcurses.sa(__libc.o):6008f194 A _VE
+/usr/lib/libcurses.sa(__libc.o):6008f190 A _VS
+/usr/lib/libcurses.sa(__libc.o):6008f09c A _XB
+/usr/lib/libcurses.sa(__libc.o):6008f0a0 A _XN
+/usr/lib/libcurses.sa(__libc.o):6008f0a8 A _XS
+/usr/lib/libcurses.sa(__libc.o):6008f0a4 A _XT
+/usr/lib/libcurses.sa(__libc.o):6008f0ac A _XX
+/usr/lib/libcurses.sa(__libc.o):6008f1f4 A __9streambuf$_list_all
+/usr/lib/libcurses.sa(__libc.o):6008f214 A ____brk_addr
+/usr/lib/libcurses.sa(__libc.o):6008f01c A ___ctype_b
+/usr/lib/libcurses.sa(__libc.o):6008f020 A ___ctype_tolower
+/usr/lib/libcurses.sa(__libc.o):6008f024 A ___ctype_toupper
+/usr/lib/libcurses.sa(__libc.o):6008f1fc A ___environ
+/usr/lib/libcurses.sa(__libc.o):6008f250 A ___exit_funcs
+/usr/lib/libcurses.sa(__libc.o):6008f2f0 A ___glob_closedir_hook
+/usr/lib/libcurses.sa(__libc.o):6008f2f4 A ___glob_opendir_hook
+/usr/lib/libcurses.sa(__libc.o):6008f2f8 A ___glob_readdir_hook
+/usr/lib/libcurses.sa(__libc.o):6008f018 A ___new_handler
+/usr/lib/libcurses.sa(__libc.o):6008f1e4 A ___std_filebuf_0
+/usr/lib/libcurses.sa(__libc.o):6008f1e8 A ___std_filebuf_1
+/usr/lib/libcurses.sa(__libc.o):6008f1ec A ___std_filebuf_2
+/usr/lib/libcurses.sa(__libc.o):6008f278 A ___ttyname
+/usr/lib/libcurses.sa(__libc.o):6008f238 A __collate_info
+/usr/lib/libcurses.sa(__libc.o):6008f23c A __ctype_info
+/usr/lib/libcurses.sa(__libc.o):6008f028 A __echoit
+/usr/lib/libcurses.sa(__libc.o):6008f034 A __endwin
+/usr/lib/libcurses.sa(__libc.o):6008f288 A __gdbm_fetch_val
+/usr/lib/libcurses.sa(__libc.o):6008f280 A __gdbm_file
+/usr/lib/libcurses.sa(__libc.o):6008f284 A __gdbm_memory
+/usr/lib/libcurses.sa(__libc.o):6008f1f8 A __iob
+/usr/lib/libcurses.sa(__libc.o):6008f240 A __monetary_info
+/usr/lib/libcurses.sa(__libc.o):6008f234 A __null_auth
+/usr/lib/libcurses.sa(__libc.o):6008f244 A __numeric_info
+/usr/lib/libcurses.sa(__libc.o):6008f2ec A __obstack
+/usr/lib/libcurses.sa(__libc.o):6008f1c8 A __pfast
+/usr/lib/libcurses.sa(__libc.o):6008f02c A __rawmode
+/usr/lib/libcurses.sa(__libc.o):6008f1dc A __res
+/usr/lib/libcurses.sa(__libc.o):6008f04c A __res_iflg
+/usr/lib/libcurses.sa(__libc.o):6008f050 A __res_lflg
+/usr/lib/libcurses.sa(__libc.o):6008f270 A __res_opcodes
+/usr/lib/libcurses.sa(__libc.o):6008f274 A __res_resultcodes
+/usr/lib/libcurses.sa(__libc.o):6008f248 A __response_info
+/usr/lib/libcurses.sa(__libc.o):6008f2fc A __sigintr
+/usr/lib/libcurses.sa(__libc.o):6008f00c A __sys_errlist
+/usr/lib/libcurses.sa(__libc.o):6008f010 A __sys_nerr
+/usr/lib/libcurses.sa(__libc.o):6008f014 A __sys_siglist
+/usr/lib/libcurses.sa(__libc.o):6008f24c A __time_info
+/usr/lib/libcurses.sa(__libc.o):6008f05c A __tty
+/usr/lib/libcurses.sa(__libc.o):6008f040 A __tty_ch
+/usr/lib/libcurses.sa(__libc.o):6008f1cc A __unctrl
+/usr/lib/libcurses.sa(__libc.o):6008f2c8 A __vt$10istrstream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2c4 A __vt$10ostrstream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2e0 A __vt$11fstreambase$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2cc A __vt$13strstreambase$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2d4 A __vt$7fstream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2ac A __vt$7ostream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2dc A __vt$8ifstream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2a4 A __vt$8iostream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2d8 A __vt$8ofstream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2c0 A __vt$9strstream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2b4 A __vt$backupbuf
+/usr/lib/libcurses.sa(__libc.o):6008f2b0 A __vt$filebuf
+/usr/lib/libcurses.sa(__libc.o):6008f2bc A __vt$ios
+/usr/lib/libcurses.sa(__libc.o):6008f2a8 A __vt$istream$3ios
+/usr/lib/libcurses.sa(__libc.o):6008f2b8 A __vt$streambuf
+/usr/lib/libcurses.sa(__libc.o):6008f2d0 A __vt$strstreambuf
+/usr/lib/libcurses.sa(__libc.o):6008f27c A __win
+/usr/lib/libcurses.sa(__libc.o):6008f294 A _cerr
+/usr/lib/libcurses.sa(__libc.o):6008f298 A _cin
+/usr/lib/libcurses.sa(__libc.o):6008f29c A _clog
+/usr/lib/libcurses.sa(__libc.o):6008f290 A _cout
+/usr/lib/libcurses.sa(__libc.o):6008f058 A _curscr
+/usr/lib/libcurses.sa(__libc.o):6008f228 A _daylight
+/usr/lib/libcurses.sa(__libc.o):6008f200 A _errno
+/usr/lib/libcurses.sa(__libc.o):6008f1d0 A _gdbm_errno
+/usr/lib/libcurses.sa(__libc.o):6008f28c A _gdbm_version
+/usr/lib/libcurses.sa(__libc.o):6008f008 A _h_errlist
+/usr/lib/libcurses.sa(__libc.o):6008f1d8 A _h_errno
+/usr/lib/libcurses.sa(__libc.o):6008f2a0 A _h_nerr
+/usr/lib/libcurses.sa(__libc.o):6008f1c4 A _normtty
+/usr/lib/libcurses.sa(__libc.o):6008f1f0 A _not_open_filebuf
+/usr/lib/libcurses.sa(__libc.o):6008f204 A _optarg
+/usr/lib/libcurses.sa(__libc.o):6008f20c A _opterr
+/usr/lib/libcurses.sa(__libc.o):6008f208 A _optind
+/usr/lib/libcurses.sa(__libc.o):6008f2e4 A _optopt
+/usr/lib/libcurses.sa(__libc.o):6008f218 A _ospeed
+/usr/lib/libcurses.sa(__libc.o):6008f26c A _re_max_failures
+/usr/lib/libcurses.sa(__libc.o):6008f210 A _re_syntax_options
+/usr/lib/libcurses.sa(__libc.o):6008f1e0 A _rexecoptions
+/usr/lib/libcurses.sa(__libc.o):6008f230 A _rpc_createerr
+/usr/lib/libcurses.sa(__libc.o):6008f25c A _stderr
+/usr/lib/libcurses.sa(__libc.o):6008f254 A _stdin
+/usr/lib/libcurses.sa(__libc.o):6008f258 A _stdout
+/usr/lib/libcurses.sa(__libc.o):6008f054 A _stdscr
+/usr/lib/libcurses.sa(__libc.o):6008f2e8 A _svc_fdset
+/usr/lib/libcurses.sa(__libc.o):6008f224 A _timezone
+/usr/lib/libcurses.sa(__libc.o):6008f21c A _tputs_baud_rate
+/usr/lib/libcurses.sa(__libc.o):6008f038 A _ttytype
+/usr/lib/libcurses.sa(__libc.o):6008f220 A _tzname
+/usr/lib/libdbm.sa(__libc.o):00001000 a __GOT_SIZE
+/usr/lib/libdbm.sa(__libc.o):6008f0b0 A _AL
+/usr/lib/libdbm.sa(__libc.o):6008f198 A _AL_PARM
+/usr/lib/libdbm.sa(__libc.o):6008f060 A _AM
+/usr/lib/libdbm.sa(__libc.o):6008f0b4 A _BC
+/usr/lib/libdbm.sa(__libc.o):6008f064 A _BS
+/usr/lib/libdbm.sa(__libc.o):6008f0bc A _BT
+/usr/lib/libdbm.sa(__libc.o):6008f068 A _CA
+/usr/lib/libdbm.sa(__libc.o):6008f0c0 A _CD
+/usr/lib/libdbm.sa(__libc.o):6008f0c4 A _CE
+/usr/lib/libdbm.sa(__libc.o):6008f0c8 A _CL
+/usr/lib/libdbm.sa(__libc.o):6008f0cc A _CM
+/usr/lib/libdbm.sa(__libc.o):6008f048 A _COLS
+/usr/lib/libdbm.sa(__libc.o):6008f0d0 A _CR
+/usr/lib/libdbm.sa(__libc.o):6008f0d4 A _CS
+/usr/lib/libdbm.sa(__libc.o):6008f06c A _DA
+/usr/lib/libdbm.sa(__libc.o):6008f070 A _DB
+/usr/lib/libdbm.sa(__libc.o):6008f0d8 A _DC
+/usr/lib/libdbm.sa(__libc.o):6008f0dc A _DL
+/usr/lib/libdbm.sa(__libc.o):6008f19c A _DL_PARM
+/usr/lib/libdbm.sa(__libc.o):6008f0e0 A _DM
+/usr/lib/libdbm.sa(__libc.o):6008f0e4 A _DO
+/usr/lib/libdbm.sa(__libc.o):6008f1a4 A _DOWN_PARM
+/usr/lib/libdbm.sa(__libc.o):6008f03c A _Def_term
+/usr/lib/libdbm.sa(__libc.o):6008f0e8 A _ED
+/usr/lib/libdbm.sa(__libc.o):6008f0ec A _EI
+/usr/lib/libdbm.sa(__libc.o):6008f074 A _EO
+/usr/lib/libdbm.sa(__libc.o):6008f1b8 A _GT
+/usr/lib/libdbm.sa(__libc.o):6008f078 A _HC
+/usr/lib/libdbm.sa(__libc.o):6008f118 A _HO
+/usr/lib/libdbm.sa(__libc.o):6008f07c A _HZ
+/usr/lib/libdbm.sa(__libc.o):6008f11c A _IC
+/usr/lib/libdbm.sa(__libc.o):6008f120 A _IM
+/usr/lib/libdbm.sa(__libc.o):6008f080 A _IN
+/usr/lib/libdbm.sa(__libc.o):6008f124 A _IP
+/usr/lib/libdbm.sa(__libc.o):6008f0f0 A _K0
+/usr/lib/libdbm.sa(__libc.o):6008f0f4 A _K1
+/usr/lib/libdbm.sa(__libc.o):6008f0f8 A _K2
+/usr/lib/libdbm.sa(__libc.o):6008f0fc A _K3
+/usr/lib/libdbm.sa(__libc.o):6008f100 A _K4
+/usr/lib/libdbm.sa(__libc.o):6008f104 A _K5
+/usr/lib/libdbm.sa(__libc.o):6008f108 A _K6
+/usr/lib/libdbm.sa(__libc.o):6008f10c A _K7
+/usr/lib/libdbm.sa(__libc.o):6008f110 A _K8
+/usr/lib/libdbm.sa(__libc.o):6008f114 A _K9
+/usr/lib/libdbm.sa(__libc.o):6008f128 A _KD
+/usr/lib/libdbm.sa(__libc.o):6008f12c A _KE
+/usr/lib/libdbm.sa(__libc.o):6008f130 A _KH
+/usr/lib/libdbm.sa(__libc.o):6008f134 A _KL
+/usr/lib/libdbm.sa(__libc.o):6008f138 A _KR
+/usr/lib/libdbm.sa(__libc.o):6008f13c A _KS
+/usr/lib/libdbm.sa(__libc.o):6008f140 A _KU
+/usr/lib/libdbm.sa(__libc.o):6008f1a8 A _LEFT_PARM
+/usr/lib/libdbm.sa(__libc.o):6008f044 A _LINES
+/usr/lib/libdbm.sa(__libc.o):6008f144 A _LL
+/usr/lib/libdbm.sa(__libc.o):6008f148 A _MA
+/usr/lib/libdbm.sa(__libc.o):6008f084 A _MI
+/usr/lib/libdbm.sa(__libc.o):6008f088 A _MS
+/usr/lib/libdbm.sa(__libc.o):6008f030 A _My_term
+/usr/lib/libdbm.sa(__libc.o):6008f08c A _NC
+/usr/lib/libdbm.sa(__libc.o):6008f14c A _ND
+/usr/lib/libdbm.sa(__libc.o):6008f150 A _NL
+/usr/lib/libdbm.sa(__libc.o):6008f1bc A _NONL
+/usr/lib/libdbm.sa(__libc.o):6008f090 A _NS
+/usr/lib/libdbm.sa(__libc.o):6008f094 A _OS
+/usr/lib/libdbm.sa(__libc.o):6008f1b0 A _PC
+/usr/lib/libdbm.sa(__libc.o):6008f154 A _RC
+/usr/lib/libdbm.sa(__libc.o):6008f1ac A _RIGHT_PARM
+/usr/lib/libdbm.sa(__libc.o):6008f158 A _SC
+/usr/lib/libdbm.sa(__libc.o):6008f15c A _SE
+/usr/lib/libdbm.sa(__libc.o):6008f160 A _SF
+/usr/lib/libdbm.sa(__libc.o):6008f164 A _SO
+/usr/lib/libdbm.sa(__libc.o):6008f168 A _SR
+/usr/lib/libdbm.sa(__libc.o):6008f16c A _TA
+/usr/lib/libdbm.sa(__libc.o):6008f170 A _TE
+/usr/lib/libdbm.sa(__libc.o):6008f174 A _TI
+/usr/lib/libdbm.sa(__libc.o):6008f178 A _UC
+/usr/lib/libdbm.sa(__libc.o):6008f17c A _UE
+/usr/lib/libdbm.sa(__libc.o):6008f098 A _UL
+/usr/lib/libdbm.sa(__libc.o):6008f180 A _UP
+/usr/lib/libdbm.sa(__libc.o):6008f1c0 A _UPPERCASE
+/usr/lib/libdbm.sa(__libc.o):6008f1a0 A _UP_PARM
+/usr/lib/libdbm.sa(__libc.o):6008f188 A _US
+/usr/lib/libdbm.sa(__libc.o):6008f18c A _VB
+/usr/lib/libdbm.sa(__libc.o):6008f194 A _VE
+/usr/lib/libdbm.sa(__libc.o):6008f190 A _VS
+/usr/lib/libdbm.sa(__libc.o):6008f09c A _XB
+/usr/lib/libdbm.sa(__libc.o):6008f0a0 A _XN
+/usr/lib/libdbm.sa(__libc.o):6008f0a8 A _XS
+/usr/lib/libdbm.sa(__libc.o):6008f0a4 A _XT
+/usr/lib/libdbm.sa(__libc.o):6008f0ac A _XX
+/usr/lib/libdbm.sa(__libc.o):6008f1f4 A __9streambuf$_list_all
+/usr/lib/libdbm.sa(__libc.o):6008f214 A ____brk_addr
+/usr/lib/libdbm.sa(__libc.o):6008f01c A ___ctype_b
+/usr/lib/libdbm.sa(__libc.o):6008f020 A ___ctype_tolower
+/usr/lib/libdbm.sa(__libc.o):6008f024 A ___ctype_toupper
+/usr/lib/libdbm.sa(__libc.o):6008f1fc A ___environ
+/usr/lib/libdbm.sa(__libc.o):6008f250 A ___exit_funcs
+/usr/lib/libdbm.sa(__libc.o):6008f2f0 A ___glob_closedir_hook
+/usr/lib/libdbm.sa(__libc.o):6008f2f4 A ___glob_opendir_hook
+/usr/lib/libdbm.sa(__libc.o):6008f2f8 A ___glob_readdir_hook
+/usr/lib/libdbm.sa(__libc.o):6008f018 A ___new_handler
+/usr/lib/libdbm.sa(__libc.o):6008f1e4 A ___std_filebuf_0
+/usr/lib/libdbm.sa(__libc.o):6008f1e8 A ___std_filebuf_1
+/usr/lib/libdbm.sa(__libc.o):6008f1ec A ___std_filebuf_2
+/usr/lib/libdbm.sa(__libc.o):6008f278 A ___ttyname
+/usr/lib/libdbm.sa(__libc.o):6008f238 A __collate_info
+/usr/lib/libdbm.sa(__libc.o):6008f23c A __ctype_info
+/usr/lib/libdbm.sa(__libc.o):6008f028 A __echoit
+/usr/lib/libdbm.sa(__libc.o):6008f034 A __endwin
+/usr/lib/libdbm.sa(__libc.o):6008f288 A __gdbm_fetch_val
+/usr/lib/libdbm.sa(__libc.o):6008f280 A __gdbm_file
+/usr/lib/libdbm.sa(__libc.o):6008f284 A __gdbm_memory
+/usr/lib/libdbm.sa(__libc.o):6008f1f8 A __iob
+/usr/lib/libdbm.sa(__libc.o):6008f240 A __monetary_info
+/usr/lib/libdbm.sa(__libc.o):6008f234 A __null_auth
+/usr/lib/libdbm.sa(__libc.o):6008f244 A __numeric_info
+/usr/lib/libdbm.sa(__libc.o):6008f2ec A __obstack
+/usr/lib/libdbm.sa(__libc.o):6008f1c8 A __pfast
+/usr/lib/libdbm.sa(__libc.o):6008f02c A __rawmode
+/usr/lib/libdbm.sa(__libc.o):6008f1dc A __res
+/usr/lib/libdbm.sa(__libc.o):6008f04c A __res_iflg
+/usr/lib/libdbm.sa(__libc.o):6008f050 A __res_lflg
+/usr/lib/libdbm.sa(__libc.o):6008f270 A __res_opcodes
+/usr/lib/libdbm.sa(__libc.o):6008f274 A __res_resultcodes
+/usr/lib/libdbm.sa(__libc.o):6008f248 A __response_info
+/usr/lib/libdbm.sa(__libc.o):6008f2fc A __sigintr
+/usr/lib/libdbm.sa(__libc.o):6008f00c A __sys_errlist
+/usr/lib/libdbm.sa(__libc.o):6008f010 A __sys_nerr
+/usr/lib/libdbm.sa(__libc.o):6008f014 A __sys_siglist
+/usr/lib/libdbm.sa(__libc.o):6008f24c A __time_info
+/usr/lib/libdbm.sa(__libc.o):6008f05c A __tty
+/usr/lib/libdbm.sa(__libc.o):6008f040 A __tty_ch
+/usr/lib/libdbm.sa(__libc.o):6008f1cc A __unctrl
+/usr/lib/libdbm.sa(__libc.o):6008f2c8 A __vt$10istrstream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2c4 A __vt$10ostrstream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2e0 A __vt$11fstreambase$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2cc A __vt$13strstreambase$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2d4 A __vt$7fstream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2ac A __vt$7ostream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2dc A __vt$8ifstream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2a4 A __vt$8iostream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2d8 A __vt$8ofstream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2c0 A __vt$9strstream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2b4 A __vt$backupbuf
+/usr/lib/libdbm.sa(__libc.o):6008f2b0 A __vt$filebuf
+/usr/lib/libdbm.sa(__libc.o):6008f2bc A __vt$ios
+/usr/lib/libdbm.sa(__libc.o):6008f2a8 A __vt$istream$3ios
+/usr/lib/libdbm.sa(__libc.o):6008f2b8 A __vt$streambuf
+/usr/lib/libdbm.sa(__libc.o):6008f2d0 A __vt$strstreambuf
+/usr/lib/libdbm.sa(__libc.o):6008f27c A __win
+/usr/lib/libdbm.sa(__libc.o):6008f294 A _cerr
+/usr/lib/libdbm.sa(__libc.o):6008f298 A _cin
+/usr/lib/libdbm.sa(__libc.o):6008f29c A _clog
+/usr/lib/libdbm.sa(__libc.o):6008f290 A _cout
+/usr/lib/libdbm.sa(__libc.o):6008f058 A _curscr
+/usr/lib/libdbm.sa(__libc.o):6008f228 A _daylight
+/usr/lib/libdbm.sa(__libc.o):6008f200 A _errno
+/usr/lib/libdbm.sa(__libc.o):6008f1d0 A _gdbm_errno
+/usr/lib/libdbm.sa(__libc.o):6008f28c A _gdbm_version
+/usr/lib/libdbm.sa(__libc.o):6008f008 A _h_errlist
+/usr/lib/libdbm.sa(__libc.o):6008f1d8 A _h_errno
+/usr/lib/libdbm.sa(__libc.o):6008f2a0 A _h_nerr
+/usr/lib/libdbm.sa(__libc.o):6008f1c4 A _normtty
+/usr/lib/libdbm.sa(__libc.o):6008f1f0 A _not_open_filebuf
+/usr/lib/libdbm.sa(__libc.o):6008f204 A _optarg
+/usr/lib/libdbm.sa(__libc.o):6008f20c A _opterr
+/usr/lib/libdbm.sa(__libc.o):6008f208 A _optind
+/usr/lib/libdbm.sa(__libc.o):6008f2e4 A _optopt
+/usr/lib/libdbm.sa(__libc.o):6008f218 A _ospeed
+/usr/lib/libdbm.sa(__libc.o):6008f26c A _re_max_failures
+/usr/lib/libdbm.sa(__libc.o):6008f210 A _re_syntax_options
+/usr/lib/libdbm.sa(__libc.o):6008f1e0 A _rexecoptions
+/usr/lib/libdbm.sa(__libc.o):6008f230 A _rpc_createerr
+/usr/lib/libdbm.sa(__libc.o):6008f25c A _stderr
+/usr/lib/libdbm.sa(__libc.o):6008f254 A _stdin
+/usr/lib/libdbm.sa(__libc.o):6008f258 A _stdout
+/usr/lib/libdbm.sa(__libc.o):6008f054 A _stdscr
+/usr/lib/libdbm.sa(__libc.o):6008f2e8 A _svc_fdset
+/usr/lib/libdbm.sa(__libc.o):6008f224 A _timezone
+/usr/lib/libdbm.sa(__libc.o):6008f21c A _tputs_baud_rate
+/usr/lib/libdbm.sa(__libc.o):6008f038 A _ttytype
+/usr/lib/libdbm.sa(__libc.o):6008f220 A _tzname
+/usr/lib/libgcc.sa(__libc.o):00001000 a __GOT_SIZE
+/usr/lib/libgcc.sa(__libc.o):6008f0b0 A _AL
+/usr/lib/libgcc.sa(__libc.o):6008f198 A _AL_PARM
+/usr/lib/libgcc.sa(__libc.o):6008f060 A _AM
+/usr/lib/libgcc.sa(__libc.o):6008f0b4 A _BC
+/usr/lib/libgcc.sa(__libc.o):6008f064 A _BS
+/usr/lib/libgcc.sa(__libc.o):6008f0bc A _BT
+/usr/lib/libgcc.sa(__libc.o):6008f068 A _CA
+/usr/lib/libgcc.sa(__libc.o):6008f0c0 A _CD
+/usr/lib/libgcc.sa(__libc.o):6008f0c4 A _CE
+/usr/lib/libgcc.sa(__libc.o):6008f0c8 A _CL
+/usr/lib/libgcc.sa(__libc.o):6008f0cc A _CM
+/usr/lib/libgcc.sa(__libc.o):6008f048 A _COLS
+/usr/lib/libgcc.sa(__libc.o):6008f0d0 A _CR
+/usr/lib/libgcc.sa(__libc.o):6008f0d4 A _CS
+/usr/lib/libgcc.sa(__libc.o):6008f06c A _DA
+/usr/lib/libgcc.sa(__libc.o):6008f070 A _DB
+/usr/lib/libgcc.sa(__libc.o):6008f0d8 A _DC
+/usr/lib/libgcc.sa(__libc.o):6008f0dc A _DL
+/usr/lib/libgcc.sa(__libc.o):6008f19c A _DL_PARM
+/usr/lib/libgcc.sa(__libc.o):6008f0e0 A _DM
+/usr/lib/libgcc.sa(__libc.o):6008f0e4 A _DO
+/usr/lib/libgcc.sa(__libc.o):6008f1a4 A _DOWN_PARM
+/usr/lib/libgcc.sa(__libc.o):6008f03c A _Def_term
+/usr/lib/libgcc.sa(__libc.o):6008f0e8 A _ED
+/usr/lib/libgcc.sa(__libc.o):6008f0ec A _EI
+/usr/lib/libgcc.sa(__libc.o):6008f074 A _EO
+/usr/lib/libgcc.sa(__libc.o):6008f1b8 A _GT
+/usr/lib/libgcc.sa(__libc.o):6008f078 A _HC
+/usr/lib/libgcc.sa(__libc.o):6008f118 A _HO
+/usr/lib/libgcc.sa(__libc.o):6008f07c A _HZ
+/usr/lib/libgcc.sa(__libc.o):6008f11c A _IC
+/usr/lib/libgcc.sa(__libc.o):6008f120 A _IM
+/usr/lib/libgcc.sa(__libc.o):6008f080 A _IN
+/usr/lib/libgcc.sa(__libc.o):6008f124 A _IP
+/usr/lib/libgcc.sa(__libc.o):6008f0f0 A _K0
+/usr/lib/libgcc.sa(__libc.o):6008f0f4 A _K1
+/usr/lib/libgcc.sa(__libc.o):6008f0f8 A _K2
+/usr/lib/libgcc.sa(__libc.o):6008f0fc A _K3
+/usr/lib/libgcc.sa(__libc.o):6008f100 A _K4
+/usr/lib/libgcc.sa(__libc.o):6008f104 A _K5
+/usr/lib/libgcc.sa(__libc.o):6008f108 A _K6
+/usr/lib/libgcc.sa(__libc.o):6008f10c A _K7
+/usr/lib/libgcc.sa(__libc.o):6008f110 A _K8
+/usr/lib/libgcc.sa(__libc.o):6008f114 A _K9
+/usr/lib/libgcc.sa(__libc.o):6008f128 A _KD
+/usr/lib/libgcc.sa(__libc.o):6008f12c A _KE
+/usr/lib/libgcc.sa(__libc.o):6008f130 A _KH
+/usr/lib/libgcc.sa(__libc.o):6008f134 A _KL
+/usr/lib/libgcc.sa(__libc.o):6008f138 A _KR
+/usr/lib/libgcc.sa(__libc.o):6008f13c A _KS
+/usr/lib/libgcc.sa(__libc.o):6008f140 A _KU
+/usr/lib/libgcc.sa(__libc.o):6008f1a8 A _LEFT_PARM
+/usr/lib/libgcc.sa(__libc.o):6008f044 A _LINES
+/usr/lib/libgcc.sa(__libc.o):6008f144 A _LL
+/usr/lib/libgcc.sa(__libc.o):6008f148 A _MA
+/usr/lib/libgcc.sa(__libc.o):6008f084 A _MI
+/usr/lib/libgcc.sa(__libc.o):6008f088 A _MS
+/usr/lib/libgcc.sa(__libc.o):6008f030 A _My_term
+/usr/lib/libgcc.sa(__libc.o):6008f08c A _NC
+/usr/lib/libgcc.sa(__libc.o):6008f14c A _ND
+/usr/lib/libgcc.sa(__libc.o):6008f150 A _NL
+/usr/lib/libgcc.sa(__libc.o):6008f1bc A _NONL
+/usr/lib/libgcc.sa(__libc.o):6008f090 A _NS
+/usr/lib/libgcc.sa(__libc.o):6008f094 A _OS
+/usr/lib/libgcc.sa(__libc.o):6008f1b0 A _PC
+/usr/lib/libgcc.sa(__libc.o):6008f154 A _RC
+/usr/lib/libgcc.sa(__libc.o):6008f1ac A _RIGHT_PARM
+/usr/lib/libgcc.sa(__libc.o):6008f158 A _SC
+/usr/lib/libgcc.sa(__libc.o):6008f15c A _SE
+/usr/lib/libgcc.sa(__libc.o):6008f160 A _SF
+/usr/lib/libgcc.sa(__libc.o):6008f164 A _SO
+/usr/lib/libgcc.sa(__libc.o):6008f168 A _SR
+/usr/lib/libgcc.sa(__libc.o):6008f16c A _TA
+/usr/lib/libgcc.sa(__libc.o):6008f170 A _TE
+/usr/lib/libgcc.sa(__libc.o):6008f174 A _TI
+/usr/lib/libgcc.sa(__libc.o):6008f178 A _UC
+/usr/lib/libgcc.sa(__libc.o):6008f17c A _UE
+/usr/lib/libgcc.sa(__libc.o):6008f098 A _UL
+/usr/lib/libgcc.sa(__libc.o):6008f180 A _UP
+/usr/lib/libgcc.sa(__libc.o):6008f1c0 A _UPPERCASE
+/usr/lib/libgcc.sa(__libc.o):6008f1a0 A _UP_PARM
+/usr/lib/libgcc.sa(__libc.o):6008f188 A _US
+/usr/lib/libgcc.sa(__libc.o):6008f18c A _VB
+/usr/lib/libgcc.sa(__libc.o):6008f194 A _VE
+/usr/lib/libgcc.sa(__libc.o):6008f190 A _VS
+/usr/lib/libgcc.sa(__libc.o):6008f09c A _XB
+/usr/lib/libgcc.sa(__libc.o):6008f0a0 A _XN
+/usr/lib/libgcc.sa(__libc.o):6008f0a8 A _XS
+/usr/lib/libgcc.sa(__libc.o):6008f0a4 A _XT
+/usr/lib/libgcc.sa(__libc.o):6008f0ac A _XX
+/usr/lib/libgcc.sa(__libc.o):6008f1f4 A __9streambuf$_list_all
+/usr/lib/libgcc.sa(__libc.o):6008f214 A ____brk_addr
+/usr/lib/libgcc.sa(__libc.o):6008f01c A ___ctype_b
+/usr/lib/libgcc.sa(__libc.o):6008f020 A ___ctype_tolower
+/usr/lib/libgcc.sa(__libc.o):6008f024 A ___ctype_toupper
+/usr/lib/libgcc.sa(__libc.o):6008f1fc A ___environ
+/usr/lib/libgcc.sa(__libc.o):6008f250 A ___exit_funcs
+/usr/lib/libgcc.sa(__libc.o):6008f2f0 A ___glob_closedir_hook
+/usr/lib/libgcc.sa(__libc.o):6008f2f4 A ___glob_opendir_hook
+/usr/lib/libgcc.sa(__libc.o):6008f2f8 A ___glob_readdir_hook
+/usr/lib/libgcc.sa(__libc.o):6008f018 A ___new_handler
+/usr/lib/libgcc.sa(__libc.o):6008f1e4 A ___std_filebuf_0
+/usr/lib/libgcc.sa(__libc.o):6008f1e8 A ___std_filebuf_1
+/usr/lib/libgcc.sa(__libc.o):6008f1ec A ___std_filebuf_2
+/usr/lib/libgcc.sa(__libc.o):6008f278 A ___ttyname
+/usr/lib/libgcc.sa(__libc.o):6008f238 A __collate_info
+/usr/lib/libgcc.sa(__libc.o):6008f23c A __ctype_info
+/usr/lib/libgcc.sa(__libc.o):6008f028 A __echoit
+/usr/lib/libgcc.sa(__libc.o):6008f034 A __endwin
+/usr/lib/libgcc.sa(__libc.o):6008f288 A __gdbm_fetch_val
+/usr/lib/libgcc.sa(__libc.o):6008f280 A __gdbm_file
+/usr/lib/libgcc.sa(__libc.o):6008f284 A __gdbm_memory
+/usr/lib/libgcc.sa(__libc.o):6008f1f8 A __iob
+/usr/lib/libgcc.sa(__libc.o):6008f240 A __monetary_info
+/usr/lib/libgcc.sa(__libc.o):6008f234 A __null_auth
+/usr/lib/libgcc.sa(__libc.o):6008f244 A __numeric_info
+/usr/lib/libgcc.sa(__libc.o):6008f2ec A __obstack
+/usr/lib/libgcc.sa(__libc.o):6008f1c8 A __pfast
+/usr/lib/libgcc.sa(__libc.o):6008f02c A __rawmode
+/usr/lib/libgcc.sa(__libc.o):6008f1dc A __res
+/usr/lib/libgcc.sa(__libc.o):6008f04c A __res_iflg
+/usr/lib/libgcc.sa(__libc.o):6008f050 A __res_lflg
+/usr/lib/libgcc.sa(__libc.o):6008f270 A __res_opcodes
+/usr/lib/libgcc.sa(__libc.o):6008f274 A __res_resultcodes
+/usr/lib/libgcc.sa(__libc.o):6008f248 A __response_info
+/usr/lib/libgcc.sa(__libc.o):6008f2fc A __sigintr
+/usr/lib/libgcc.sa(__libc.o):6008f00c A __sys_errlist
+/usr/lib/libgcc.sa(__libc.o):6008f010 A __sys_nerr
+/usr/lib/libgcc.sa(__libc.o):6008f014 A __sys_siglist
+/usr/lib/libgcc.sa(__libc.o):6008f24c A __time_info
+/usr/lib/libgcc.sa(__libc.o):6008f05c A __tty
+/usr/lib/libgcc.sa(__libc.o):6008f040 A __tty_ch
+/usr/lib/libgcc.sa(__libc.o):6008f1cc A __unctrl
+/usr/lib/libgcc.sa(__libc.o):6008f2c8 A __vt$10istrstream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2c4 A __vt$10ostrstream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2e0 A __vt$11fstreambase$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2cc A __vt$13strstreambase$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2d4 A __vt$7fstream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2ac A __vt$7ostream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2dc A __vt$8ifstream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2a4 A __vt$8iostream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2d8 A __vt$8ofstream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2c0 A __vt$9strstream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2b4 A __vt$backupbuf
+/usr/lib/libgcc.sa(__libc.o):6008f2b0 A __vt$filebuf
+/usr/lib/libgcc.sa(__libc.o):6008f2bc A __vt$ios
+/usr/lib/libgcc.sa(__libc.o):6008f2a8 A __vt$istream$3ios
+/usr/lib/libgcc.sa(__libc.o):6008f2b8 A __vt$streambuf
+/usr/lib/libgcc.sa(__libc.o):6008f2d0 A __vt$strstreambuf
+/usr/lib/libgcc.sa(__libc.o):6008f27c A __win
+/usr/lib/libgcc.sa(__libc.o):6008f294 A _cerr
+/usr/lib/libgcc.sa(__libc.o):6008f298 A _cin
+/usr/lib/libgcc.sa(__libc.o):6008f29c A _clog
+/usr/lib/libgcc.sa(__libc.o):6008f290 A _cout
+/usr/lib/libgcc.sa(__libc.o):6008f058 A _curscr
+/usr/lib/libgcc.sa(__libc.o):6008f228 A _daylight
+/usr/lib/libgcc.sa(__libc.o):6008f200 A _errno
+/usr/lib/libgcc.sa(__libc.o):6008f1d0 A _gdbm_errno
+/usr/lib/libgcc.sa(__libc.o):6008f28c A _gdbm_version
+/usr/lib/libgcc.sa(__libc.o):6008f008 A _h_errlist
+/usr/lib/libgcc.sa(__libc.o):6008f1d8 A _h_errno
+/usr/lib/libgcc.sa(__libc.o):6008f2a0 A _h_nerr
+/usr/lib/libgcc.sa(__libc.o):6008f1c4 A _normtty
+/usr/lib/libgcc.sa(__libc.o):6008f1f0 A _not_open_filebuf
+/usr/lib/libgcc.sa(__libc.o):6008f204 A _optarg
+/usr/lib/libgcc.sa(__libc.o):6008f20c A _opterr
+/usr/lib/libgcc.sa(__libc.o):6008f208 A _optind
+/usr/lib/libgcc.sa(__libc.o):6008f2e4 A _optopt
+/usr/lib/libgcc.sa(__libc.o):6008f218 A _ospeed
+/usr/lib/libgcc.sa(__libc.o):6008f26c A _re_max_failures
+/usr/lib/libgcc.sa(__libc.o):6008f210 A _re_syntax_options
+/usr/lib/libgcc.sa(__libc.o):6008f1e0 A _rexecoptions
+/usr/lib/libgcc.sa(__libc.o):6008f230 A _rpc_createerr
+/usr/lib/libgcc.sa(__libc.o):6008f25c A _stderr
+/usr/lib/libgcc.sa(__libc.o):6008f254 A _stdin
+/usr/lib/libgcc.sa(__libc.o):6008f258 A _stdout
+/usr/lib/libgcc.sa(__libc.o):6008f054 A _stdscr
+/usr/lib/libgcc.sa(__libc.o):6008f2e8 A _svc_fdset
+/usr/lib/libgcc.sa(__libc.o):6008f224 A _timezone
+/usr/lib/libgcc.sa(__libc.o):6008f21c A _tputs_baud_rate
+/usr/lib/libgcc.sa(__libc.o):6008f038 A _ttytype
+/usr/lib/libgcc.sa(__libc.o):6008f220 A _tzname
+/usr/lib/libm.sa(__libm.o):00000100 a __GOT_SIZE
+/usr/lib/libm.sa(__libm.o):600f7f08 A _signgam
+/usr/lib/libtermcap.sa(__libc.o):00001000 a __GOT_SIZE
+/usr/lib/libtermcap.sa(__libc.o):6008f0b0 A _AL
+/usr/lib/libtermcap.sa(__libc.o):6008f198 A _AL_PARM
+/usr/lib/libtermcap.sa(__libc.o):6008f060 A _AM
+/usr/lib/libtermcap.sa(__libc.o):6008f0b4 A _BC
+/usr/lib/libtermcap.sa(__libc.o):6008f064 A _BS
+/usr/lib/libtermcap.sa(__libc.o):6008f0bc A _BT
+/usr/lib/libtermcap.sa(__libc.o):6008f068 A _CA
+/usr/lib/libtermcap.sa(__libc.o):6008f0c0 A _CD
+/usr/lib/libtermcap.sa(__libc.o):6008f0c4 A _CE
+/usr/lib/libtermcap.sa(__libc.o):6008f0c8 A _CL
+/usr/lib/libtermcap.sa(__libc.o):6008f0cc A _CM
+/usr/lib/libtermcap.sa(__libc.o):6008f048 A _COLS
+/usr/lib/libtermcap.sa(__libc.o):6008f0d0 A _CR
+/usr/lib/libtermcap.sa(__libc.o):6008f0d4 A _CS
+/usr/lib/libtermcap.sa(__libc.o):6008f06c A _DA
+/usr/lib/libtermcap.sa(__libc.o):6008f070 A _DB
+/usr/lib/libtermcap.sa(__libc.o):6008f0d8 A _DC
+/usr/lib/libtermcap.sa(__libc.o):6008f0dc A _DL
+/usr/lib/libtermcap.sa(__libc.o):6008f19c A _DL_PARM
+/usr/lib/libtermcap.sa(__libc.o):6008f0e0 A _DM
+/usr/lib/libtermcap.sa(__libc.o):6008f0e4 A _DO
+/usr/lib/libtermcap.sa(__libc.o):6008f1a4 A _DOWN_PARM
+/usr/lib/libtermcap.sa(__libc.o):6008f03c A _Def_term
+/usr/lib/libtermcap.sa(__libc.o):6008f0e8 A _ED
+/usr/lib/libtermcap.sa(__libc.o):6008f0ec A _EI
+/usr/lib/libtermcap.sa(__libc.o):6008f074 A _EO
+/usr/lib/libtermcap.sa(__libc.o):6008f1b8 A _GT
+/usr/lib/libtermcap.sa(__libc.o):6008f078 A _HC
+/usr/lib/libtermcap.sa(__libc.o):6008f118 A _HO
+/usr/lib/libtermcap.sa(__libc.o):6008f07c A _HZ
+/usr/lib/libtermcap.sa(__libc.o):6008f11c A _IC
+/usr/lib/libtermcap.sa(__libc.o):6008f120 A _IM
+/usr/lib/libtermcap.sa(__libc.o):6008f080 A _IN
+/usr/lib/libtermcap.sa(__libc.o):6008f124 A _IP
+/usr/lib/libtermcap.sa(__libc.o):6008f0f0 A _K0
+/usr/lib/libtermcap.sa(__libc.o):6008f0f4 A _K1
+/usr/lib/libtermcap.sa(__libc.o):6008f0f8 A _K2
+/usr/lib/libtermcap.sa(__libc.o):6008f0fc A _K3
+/usr/lib/libtermcap.sa(__libc.o):6008f100 A _K4
+/usr/lib/libtermcap.sa(__libc.o):6008f104 A _K5
+/usr/lib/libtermcap.sa(__libc.o):6008f108 A _K6
+/usr/lib/libtermcap.sa(__libc.o):6008f10c A _K7
+/usr/lib/libtermcap.sa(__libc.o):6008f110 A _K8
+/usr/lib/libtermcap.sa(__libc.o):6008f114 A _K9
+/usr/lib/libtermcap.sa(__libc.o):6008f128 A _KD
+/usr/lib/libtermcap.sa(__libc.o):6008f12c A _KE
+/usr/lib/libtermcap.sa(__libc.o):6008f130 A _KH
+/usr/lib/libtermcap.sa(__libc.o):6008f134 A _KL
+/usr/lib/libtermcap.sa(__libc.o):6008f138 A _KR
+/usr/lib/libtermcap.sa(__libc.o):6008f13c A _KS
+/usr/lib/libtermcap.sa(__libc.o):6008f140 A _KU
+/usr/lib/libtermcap.sa(__libc.o):6008f1a8 A _LEFT_PARM
+/usr/lib/libtermcap.sa(__libc.o):6008f044 A _LINES
+/usr/lib/libtermcap.sa(__libc.o):6008f144 A _LL
+/usr/lib/libtermcap.sa(__libc.o):6008f148 A _MA
+/usr/lib/libtermcap.sa(__libc.o):6008f084 A _MI
+/usr/lib/libtermcap.sa(__libc.o):6008f088 A _MS
+/usr/lib/libtermcap.sa(__libc.o):6008f030 A _My_term
+/usr/lib/libtermcap.sa(__libc.o):6008f08c A _NC
+/usr/lib/libtermcap.sa(__libc.o):6008f14c A _ND
+/usr/lib/libtermcap.sa(__libc.o):6008f150 A _NL
+/usr/lib/libtermcap.sa(__libc.o):6008f1bc A _NONL
+/usr/lib/libtermcap.sa(__libc.o):6008f090 A _NS
+/usr/lib/libtermcap.sa(__libc.o):6008f094 A _OS
+/usr/lib/libtermcap.sa(__libc.o):6008f1b0 A _PC
+/usr/lib/libtermcap.sa(__libc.o):6008f154 A _RC
+/usr/lib/libtermcap.sa(__libc.o):6008f1ac A _RIGHT_PARM
+/usr/lib/libtermcap.sa(__libc.o):6008f158 A _SC
+/usr/lib/libtermcap.sa(__libc.o):6008f15c A _SE
+/usr/lib/libtermcap.sa(__libc.o):6008f160 A _SF
+/usr/lib/libtermcap.sa(__libc.o):6008f164 A _SO
+/usr/lib/libtermcap.sa(__libc.o):6008f168 A _SR
+/usr/lib/libtermcap.sa(__libc.o):6008f16c A _TA
+/usr/lib/libtermcap.sa(__libc.o):6008f170 A _TE
+/usr/lib/libtermcap.sa(__libc.o):6008f174 A _TI
+/usr/lib/libtermcap.sa(__libc.o):6008f178 A _UC
+/usr/lib/libtermcap.sa(__libc.o):6008f17c A _UE
+/usr/lib/libtermcap.sa(__libc.o):6008f098 A _UL
+/usr/lib/libtermcap.sa(__libc.o):6008f180 A _UP
+/usr/lib/libtermcap.sa(__libc.o):6008f1c0 A _UPPERCASE
+/usr/lib/libtermcap.sa(__libc.o):6008f1a0 A _UP_PARM
+/usr/lib/libtermcap.sa(__libc.o):6008f188 A _US
+/usr/lib/libtermcap.sa(__libc.o):6008f18c A _VB
+/usr/lib/libtermcap.sa(__libc.o):6008f194 A _VE
+/usr/lib/libtermcap.sa(__libc.o):6008f190 A _VS
+/usr/lib/libtermcap.sa(__libc.o):6008f09c A _XB
+/usr/lib/libtermcap.sa(__libc.o):6008f0a0 A _XN
+/usr/lib/libtermcap.sa(__libc.o):6008f0a8 A _XS
+/usr/lib/libtermcap.sa(__libc.o):6008f0a4 A _XT
+/usr/lib/libtermcap.sa(__libc.o):6008f0ac A _XX
+/usr/lib/libtermcap.sa(__libc.o):6008f1f4 A __9streambuf$_list_all
+/usr/lib/libtermcap.sa(__libc.o):6008f214 A ____brk_addr
+/usr/lib/libtermcap.sa(__libc.o):6008f01c A ___ctype_b
+/usr/lib/libtermcap.sa(__libc.o):6008f020 A ___ctype_tolower
+/usr/lib/libtermcap.sa(__libc.o):6008f024 A ___ctype_toupper
+/usr/lib/libtermcap.sa(__libc.o):6008f1fc A ___environ
+/usr/lib/libtermcap.sa(__libc.o):6008f250 A ___exit_funcs
+/usr/lib/libtermcap.sa(__libc.o):6008f2f0 A ___glob_closedir_hook
+/usr/lib/libtermcap.sa(__libc.o):6008f2f4 A ___glob_opendir_hook
+/usr/lib/libtermcap.sa(__libc.o):6008f2f8 A ___glob_readdir_hook
+/usr/lib/libtermcap.sa(__libc.o):6008f018 A ___new_handler
+/usr/lib/libtermcap.sa(__libc.o):6008f1e4 A ___std_filebuf_0
+/usr/lib/libtermcap.sa(__libc.o):6008f1e8 A ___std_filebuf_1
+/usr/lib/libtermcap.sa(__libc.o):6008f1ec A ___std_filebuf_2
+/usr/lib/libtermcap.sa(__libc.o):6008f278 A ___ttyname
+/usr/lib/libtermcap.sa(__libc.o):6008f238 A __collate_info
+/usr/lib/libtermcap.sa(__libc.o):6008f23c A __ctype_info
+/usr/lib/libtermcap.sa(__libc.o):6008f028 A __echoit
+/usr/lib/libtermcap.sa(__libc.o):6008f034 A __endwin
+/usr/lib/libtermcap.sa(__libc.o):6008f288 A __gdbm_fetch_val
+/usr/lib/libtermcap.sa(__libc.o):6008f280 A __gdbm_file
+/usr/lib/libtermcap.sa(__libc.o):6008f284 A __gdbm_memory
+/usr/lib/libtermcap.sa(__libc.o):6008f1f8 A __iob
+/usr/lib/libtermcap.sa(__libc.o):6008f240 A __monetary_info
+/usr/lib/libtermcap.sa(__libc.o):6008f234 A __null_auth
+/usr/lib/libtermcap.sa(__libc.o):6008f244 A __numeric_info
+/usr/lib/libtermcap.sa(__libc.o):6008f2ec A __obstack
+/usr/lib/libtermcap.sa(__libc.o):6008f1c8 A __pfast
+/usr/lib/libtermcap.sa(__libc.o):6008f02c A __rawmode
+/usr/lib/libtermcap.sa(__libc.o):6008f1dc A __res
+/usr/lib/libtermcap.sa(__libc.o):6008f04c A __res_iflg
+/usr/lib/libtermcap.sa(__libc.o):6008f050 A __res_lflg
+/usr/lib/libtermcap.sa(__libc.o):6008f270 A __res_opcodes
+/usr/lib/libtermcap.sa(__libc.o):6008f274 A __res_resultcodes
+/usr/lib/libtermcap.sa(__libc.o):6008f248 A __response_info
+/usr/lib/libtermcap.sa(__libc.o):6008f2fc A __sigintr
+/usr/lib/libtermcap.sa(__libc.o):6008f00c A __sys_errlist
+/usr/lib/libtermcap.sa(__libc.o):6008f010 A __sys_nerr
+/usr/lib/libtermcap.sa(__libc.o):6008f014 A __sys_siglist
+/usr/lib/libtermcap.sa(__libc.o):6008f24c A __time_info
+/usr/lib/libtermcap.sa(__libc.o):6008f05c A __tty
+/usr/lib/libtermcap.sa(__libc.o):6008f040 A __tty_ch
+/usr/lib/libtermcap.sa(__libc.o):6008f1cc A __unctrl
+/usr/lib/libtermcap.sa(__libc.o):6008f2c8 A __vt$10istrstream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2c4 A __vt$10ostrstream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2e0 A __vt$11fstreambase$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2cc A __vt$13strstreambase$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2d4 A __vt$7fstream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2ac A __vt$7ostream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2dc A __vt$8ifstream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2a4 A __vt$8iostream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2d8 A __vt$8ofstream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2c0 A __vt$9strstream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2b4 A __vt$backupbuf
+/usr/lib/libtermcap.sa(__libc.o):6008f2b0 A __vt$filebuf
+/usr/lib/libtermcap.sa(__libc.o):6008f2bc A __vt$ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2a8 A __vt$istream$3ios
+/usr/lib/libtermcap.sa(__libc.o):6008f2b8 A __vt$streambuf
+/usr/lib/libtermcap.sa(__libc.o):6008f2d0 A __vt$strstreambuf
+/usr/lib/libtermcap.sa(__libc.o):6008f27c A __win
+/usr/lib/libtermcap.sa(__libc.o):6008f294 A _cerr
+/usr/lib/libtermcap.sa(__libc.o):6008f298 A _cin
+/usr/lib/libtermcap.sa(__libc.o):6008f29c A _clog
+/usr/lib/libtermcap.sa(__libc.o):6008f290 A _cout
+/usr/lib/libtermcap.sa(__libc.o):6008f058 A _curscr
+/usr/lib/libtermcap.sa(__libc.o):6008f228 A _daylight
+/usr/lib/libtermcap.sa(__libc.o):6008f200 A _errno
+/usr/lib/libtermcap.sa(__libc.o):6008f1d0 A _gdbm_errno
+/usr/lib/libtermcap.sa(__libc.o):6008f28c A _gdbm_version
+/usr/lib/libtermcap.sa(__libc.o):6008f008 A _h_errlist
+/usr/lib/libtermcap.sa(__libc.o):6008f1d8 A _h_errno
+/usr/lib/libtermcap.sa(__libc.o):6008f2a0 A _h_nerr
+/usr/lib/libtermcap.sa(__libc.o):6008f1c4 A _normtty
+/usr/lib/libtermcap.sa(__libc.o):6008f1f0 A _not_open_filebuf
+/usr/lib/libtermcap.sa(__libc.o):6008f204 A _optarg
+/usr/lib/libtermcap.sa(__libc.o):6008f20c A _opterr
+/usr/lib/libtermcap.sa(__libc.o):6008f208 A _optind
+/usr/lib/libtermcap.sa(__libc.o):6008f2e4 A _optopt
+/usr/lib/libtermcap.sa(__libc.o):6008f218 A _ospeed
+/usr/lib/libtermcap.sa(__libc.o):6008f26c A _re_max_failures
+/usr/lib/libtermcap.sa(__libc.o):6008f210 A _re_syntax_options
+/usr/lib/libtermcap.sa(__libc.o):6008f1e0 A _rexecoptions
+/usr/lib/libtermcap.sa(__libc.o):6008f230 A _rpc_createerr
+/usr/lib/libtermcap.sa(__libc.o):6008f25c A _stderr
+/usr/lib/libtermcap.sa(__libc.o):6008f254 A _stdin
+/usr/lib/libtermcap.sa(__libc.o):6008f258 A _stdout
+/usr/lib/libtermcap.sa(__libc.o):6008f054 A _stdscr
+/usr/lib/libtermcap.sa(__libc.o):6008f2e8 A _svc_fdset
+/usr/lib/libtermcap.sa(__libc.o):6008f224 A _timezone
+/usr/lib/libtermcap.sa(__libc.o):6008f21c A _tputs_baud_rate
+/usr/lib/libtermcap.sa(__libc.o):6008f038 A _ttytype
+/usr/lib/libtermcap.sa(__libc.o):6008f220 A _tzname
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/jump/jump.vars isode-8.0/jump/jump.vars
--- old/isode-8.0/jump/jump.vars	Thu Jan  1 01:00:00 1970
+++ isode-8.0/jump/jump.vars	Thu Aug 26 15:46:06 1993
@@ -0,0 +1,325 @@
+00000018 D __ZptrtabRONOT       libisode       RONOT_tables
+00000024 D __ZRONOT_mod         libisode       RONOT_tables
+00000004 D _ronotversion        libisode       ronotvrsn
+00000074 D __ZptrtabROS         libisode       ROS_tables
+00000024 D __ZROS_mod           libisode       ROS_tables
+00000004 C _rosap_operation     libisode       ROS_tables
+00000004 C _rosap_error         libisode       ROS_tables
+00000004 C _rosap_type          libisode       ROS_tables
+00000004 C _rosap_id            libisode       ROS_tables
+00000004 C _rosap_null          libisode       ROS_tables
+00000004 C _rosap_linked        libisode       ROS_tables
+00000004 C _rosap_lnull         libisode       ROS_tables
+00000004 C _rosap_data          libisode       ROS_tables
+00000004 C _rosap_reason        libisode       ROS_tables
+00000004 D _rosapversion        libisode       rosapvrsn
+0000008c D __ZptrtabRTS         libisode       RTS_tables
+00000024 D __ZRTS_mod           libisode       RTS_tables
+00000004 C _rtsap_priority      libisode       RTS_tables
+00000004 D _rtsapversion        libisode       rtsapvrsn
+00000004 D _acsap_lookup        libisode       acsapdse
+000000d8 D __ZptrtabACS         libisode       ACS_tables
+00000024 D __ZACS_mod           libisode       ACS_tables
+00000068 D __ZptrtabOACS        libisode       OACS_tables
+00000024 D __ZOACS_mod          libisode       OACS_tables
+00000014 D __ZptrtabDSE         libisode       DSE_tables
+00000024 D __ZDSE_mod           libisode       DSE_tables
+00000078 D __ZptrtabDASE        libisode       DASE_tables
+00000024 D __ZDASE_mod          libisode       DASE_tables
+00000004 D _acsapversion        libisode       acsapvrsn
+00000018 D _preq_pairs          libisode       psaprovider
+00000060 D _sreq_pairs          libisode       psaprovider
+0000013c D __ZptrtabPS          libisode       PS_tables
+00000024 D __ZPS_mod            libisode       PS_tables
+00000004 D _psap2version        libisode       psap2vrsn
+00000004 D _NullParm            libisode       UPEPY-52
+00000004 D _xlevel              libisode       prnt
+00000004 D _tabed               libisode       prnt
+00000004 D _xpushed             libisode       prnt
+00000004 D _vfnx                libisode       vprint
+00000004 D _vfp                 libisode       vprint
+00000060 D __ZptrtabUNIV        libisode       UNIV_tables
+00000024 D __ZUNIV_mod          libisode       UNIV_tables
+0000005c D _pepy_strings        libisode       pepsy_str
+00000400 D _PY_pepy             libisode       py_advise
+00000030 D _dmsize              libisode       gtime
+00000004 C _Len                 libisode       pe2qb_f
+00000004 C _Qcp                 libisode       pe2qb_f
+00000004 C _Ecp                 libisode       pe2qb_f
+00000004 D _pe_list             libisode       pe_alloc
+00000004 C _pe_allocs           libisode       pe_alloc
+00000004 C _pe_frees            libisode       pe_alloc
+00000004 C _pe_most             libisode       pe_alloc
+00000010 D _pe_classlist        libisode       pl_tables
+00000004 D _pe_maxclass         libisode       pl_tables
+00000074 D _pe_univlist         libisode       pl_tables
+00000004 D _pe_maxuniv          libisode       pl_tables
+00000004 D _pe_maxappl          libisode       pl_tables
+00000004 D _pe_applist          libisode       pl_tables
+00000004 D _pe_maxpriv          libisode       pl_tables
+00000004 D _pe_privlist         libisode       pl_tables
+00000004 D _ps_len_strategy     libisode       ps_get_abs
+00000004 D _Byteno              libisode       qbuf2pe_f
+00000004 D _Qbrefs              libisode       qbuf2pe_f
+00000004 D _Hqb                 libisode       qbuf2pe_f
+00000004 D _Fqb                 libisode       qbuf2pe_f
+00000004 D _Qb                  libisode       qbuf2pe_f
+00000004 D _psapversion         libisode       psapvrsn
+00000004 D _ssapversion         libisode       ssapvrsn
+00000004 D __listen_opts        libisode       tsaplisten
+00000004 D _tsapversion         libisode       tsapvrsn
+00000004 D _direntversion       libisode       direntvrsn
+00000004 D _xselect_blocking_on_intr libisode       select
+00000004 D __iosignals_set      libisode       signals
+00000080 D _hex2nib             libisode       implode
+00000004 D _isodename           libisode       tailor
+00000004 D _isodebinpath        libisode       tailor
+00000004 D _isodesbinpath       libisode       tailor
+00000004 D _isodetcpath         libisode       tailor
+00000004 D _isodelogpath        libisode       tailor
+00000004 D __tailor_logging_only libisode       tailor
+00000020 D __compat_log         libisode       tailor
+00000004 D _compat_log          libisode       tailor
+00000020 D __addr_log           libisode       tailor
+00000004 D _addr_log            libisode       tailor
+00000020 D __tsap_log           libisode       tailor
+00000004 D _tsap_log            libisode       tailor
+00000020 D __ssap_log           libisode       tailor
+00000004 D _ssap_log            libisode       tailor
+00000020 D __psap_log           libisode       tailor
+00000004 D _psap_log            libisode       tailor
+00000020 D __psap2_log          libisode       tailor
+00000004 D _psap2_log           libisode       tailor
+00000020 D __acsap_log          libisode       tailor
+00000004 D _acsap_log           libisode       tailor
+00000020 D __rtsap_log          libisode       tailor
+00000004 D _rtsap_log           libisode       tailor
+00000020 D __rosap_log          libisode       tailor
+00000004 D _rosap_log           libisode       tailor
+00000004 D _ts_stacks           libisode       tailor
+000002a8 D _ts_interim          libisode       tailor
+00000004 D _ts_comm_nsap_default libisode       tailor
+00000004 D _ts_comm_x25_default libisode       tailor
+00000004 D _ts_comm_tcp_default libisode       tailor
+00000004 D _tsb_default_address libisode       tailor
+00000004 D _local_nsap          libisode       tailor
+00000004 D _nsap_default_stack  libisode       tailor
+00000004 D _ses_ab_timer        libisode       tailor
+00000004 D _ses_dn_timer        libisode       tailor
+00000004 D _ses_rf_timer        libisode       tailor
+00000004 D _ns_enabled          libisode       tailor
+00000004 D _ns_address          libisode       tailor
+00000044 C _ts_communities      libisode       tailor
+00000044 C _tsb_addresses       libisode       tailor
+00000044 C _tsb_communities     libisode       tailor
+00000100 D _chrcnv              libisode       chrcnv
+00000100 D _nochrcnv            libisode       nochrcnv
+00000004 D _compatversion       libisode       compatvrsn
+00000004 D _isodeversion        libisode       isodevrsn
+00000004 D _dsapversion         libdsap        dsapvrsn
+00000044 D __ZptrtabIF          libdsap        IF_tables
+00000024 D __ZIF_mod            libdsap        IF_tables
+00000038 D __ZptrtabThorn       libdsap        Thorn_tables
+00000024 D __ZThorn_mod         libdsap        Thorn_tables
+00000088 D __ZptrtabAF          libdsap        AF_tables
+00000024 D __ZAF_mod            libdsap        AF_tables
+00000124 D __ZptrtabDO          libdsap        DO_tables
+00000024 D __ZDO_mod            libdsap        DO_tables
+00000284 D __ZptrtabDAS         libdsap        DAS_tables
+00000024 D __ZDAS_mod           libdsap        DAS_tables
+0000017c D __ZptrtabQuipu       libdsap        Quipu_tables
+00000024 D __ZQuipu_mod         libdsap        Quipu_tables
+00000074 D __ZptrtabSA          libdsap        SA_tables
+00000024 D __ZSA_mod            libdsap        SA_tables
+0000007c D __ZptrtabNRS         libdsap        NRS_tables
+00000024 D __ZNRS_mod           libdsap        NRS_tables
+00000004 D _x500asversion       libdsap        x500asvrsn
+00000014 D _acl_sel             libdsap        acl
+00000004 C _t61_flag            libdsap        attrv
+00000004 C _crypt_flag          libdsap        attrv
+00000004 D _mydsadn             libdsap        ca
+00000004 C _dsa_dead            libdsap        ds_error
+00000004 D _NumEntries          libdsap        oid
+00000004 D _attrNumEntries      libdsap        oid
+00000004 D _ocNumEntries        libdsap        oid
+00000008 D _attr_index          libdsap        oid
+00000004 D _oc_load             libdsap        oid
+00000004 D _oc_macro_add        libdsap        oid
+00000004 C _f_table             libdsap        oid
+000012c0 C _OIDTable            libdsap        oid
+00001770 C _attrOIDTable        libdsap        oid
+000020d0 C _ocOIDTable          libdsap        oid
+00000004 D _NumMacro            libdsap        oid2
+0000a640 C _macro               libdsap        oid2
+00000004 D _print_parse_errors  libdsap        parse_error
+00000004 D _parse_status        libdsap        parse_error
+00000004 D _opt                 libdsap        parse_error
+00000004 D _parse_line          libdsap        parse_error
+00000004 D _acl_fn              libdsap        util
+00000004 D _parse_file          libdsap        file_print
+00000004 D _parse_rdn           libdsap        file_print
+00000004 C _file_attr_length    libdsap        file_enc
+00000004 D _avs_count           libdsap        attrt_print
+00000004 C _last_at             libdsap        attrt_print
+00000004 D _inherit_sntx        libdsap        as_print
+00000004 D _oc_avsprint         libdsap        avs_print
+00000004 D _oc_sntx             libdsap        avs_str
+00000004 D _oc_hier             libdsap        avs_str
+00000004 D _acl_sntx            libdsap        avs_str
+00000004 D _merge_acl           libdsap        avs_str
+00000004 D _ufn_indent          libdsap        dn_print
+00000004 D _syntax_dn           libdsap        dn_str
+00000004 D _ch_set              libdsap        string
+00000004 D _postal_indent       libdsap        post
+00000004 D _sizelimit           libdsap        conf
+00000004 D _timelimit           libdsap        conf
+00000004 D _oidtable            libdsap        conf
+00000004 D _tailfile            libdsap        conf
+00000004 D _isotailor           libdsap        conf
+00000004 D _dsa_address         libdsap        conf
+00000004 D _myname              libdsap        conf
+00000004 D _local_dit           libdsap        conf
+00000004 D _dishinit            libdsap        conf
+00000004 D _cache_timeout       libdsap        conf
+00000004 D _log_dsap            libdsap        conf
+00000004 D _log_stat            libdsap        conf
+00000004 D _oidformat           libdsap        conf
+00000004 D _mem_heap            libdsap        conf
+00000004 D _dsaoidtable         libdsap        conf
+00000004 D _dsatailfile         libdsap        conf
+00000004 D _treedir             libdsap        conf
+00000004 D _no_last_mod         libdsap        conf
+00000004 D _startup_update      libdsap        conf
+00000004 D _search_level        libdsap        conf
+00000004 D _read_only           libdsap        conf
+00000004 D _admin_size          libdsap        conf
+00000004 D _admin_time          libdsap        conf
+00000004 D _conn_timeout        libdsap        conf
+00000004 D _nsap_timeout        libdsap        conf
+00000004 D _slave_timeout       libdsap        conf
+00000004 D _retry_timeout       libdsap        conf
+00000004 D _watchdog_time       libdsap        conf
+00000004 D _watchdog_delta      libdsap        conf
+00000004 D _dsa_mode            libdsap        conf
+00000004 D _quipu_faststart     libdsap        conf
+00000004 C _dsap_id             libdsap        conf
+00000004 C _dsap_ad             libdsap        conf
+00000004 D _dsap_usage          libdsap        tai_args
+00000004 D _options             libdsap        tai_args
+00000004 D _list_top            libdsap        cache
+00000004 D _current_entry       libdsap        cache
+00000004 D _current_dn          libdsap        cache
+00000004 D _unrav_fn            libdsap        cache
+00000004 D _schema_fn           libdsap        cache
+00000004 C _at_alias            libdsap        entry
+00000004 C _at_objectclass      libdsap        entry
+00000004 D _database_root       libdsap        parse
+00000004 D _local_master_size   libdsap        parse
+00000004 D _local_slave_size    libdsap        parse
+00000004 D _local_cache_size    libdsap        parse
+00000004 C _savefile            libdsap        parse
+00000004 D _ufn_notify          libdsap        ufn_parse
+00000004 D _ufn_flags           libdsap        ufn_parse
+00000004 D _ufnas               libdsap        ufn_parse
+00000004 D _ufn_abort           libdsap        ufn_parse
+00000004 D _ufn_bad_dsa         libdsap        ufn_parse
+00000004 D _ufn_partials        libdsap        ufn_parse
+00000004 C _at_OrgUnit          libdsap        ufn_parse
+00000004 C _at_Organisation     libdsap        ufn_parse
+00000004 C _at_Locality         libdsap        ufn_parse
+00000004 C _at_CountryName      libdsap        ufn_parse
+00000004 C _at_FriendlyCountryName libdsap        ufn_parse
+00000004 C _at_CommonName       libdsap        ufn_parse
+00000004 C _at_Surname          libdsap        ufn_parse
+00000004 C _at_Userid           libdsap        ufn_parse
+00000004 C _at_ObjectClass      libdsap        ufn_parse
+00000004 D _chase_flag          libdsap        cstrings
+00000004 D _result_sequence     libdsap        service
+00000004 D _current_sequence    libdsap        service
+00000004 D _top_sequence        libdsap        service
+00000004 C _copy_flag           libdsap        service
+00000004 D _dsap_security       libdsap        security
+00000004 C _turbo_index_types   libdsap        turbo_index
+00000004 C _turbo_index_num     libdsap        turbo_index
+00000004 C _subtree_index       libdsap        turbo_index
+00000004 C _sibling_index       libdsap        turbo_index
+00000004 C _optimized_only      libdsap        turbo_index
+00000004 C _at_certificate      libdsap        attribute
+00000004 C _at_p_password       libdsap        attribute
+00000004 C _at_password         libdsap        attribute
+00000004 C _at_acl              libdsap        attribute
+00000004 C _at_control          libdsap        attribute
+00000004 C _at_dsa_control      libdsap        attribute
+00000004 C _at_schema           libdsap        attribute
+00000004 C _at_applctx          libdsap        attribute
+00000004 C _at_edbinfo          libdsap        attribute
+00000004 C _at_masterdsa        libdsap        attribute
+00000004 C _at_slavedsa         libdsap        attribute
+00000004 C _at_relaydsa         libdsap        attribute
+00000004 C _at_dsaaddress       libdsap        attribute
+00000004 C _at_version          libdsap        attribute
+00000004 C _at_inherit          libdsap        attribute
+00000004 C _at_subord           libdsap        attribute
+00000004 C _at_xref             libdsap        attribute
+00000004 C _at_nssr             libdsap        attribute
+00000004 C _at_listen           libdsap        attribute
+00000004 C _at_searchacl        libdsap        attribute
+00000004 C _at_listacl          libdsap        attribute
+00000004 C _at_authpolicy       libdsap        attribute
+00000004 C _alias_oc            libdsap        attribute
+00000004 C _quipu_dsa_oid       libdsap        attribute
+00000004 C _extern_obj_oid      libdsap        attribute
+00000004 D _qos_indent          libdsap        qos
+00000004 C _as_sntx             libdsap        attr_sntx
+00000004 C _bl_tree_top         libdsap        photo_dec
+00000004 C _wt_tree_top         libdsap        photo_dec
+00000004 C _two_tree_top        libdsap        photo_dec
+00000004 C _position            libdsap        photo_dec
+00000004 C _bitmap              libdsap        photo_dec
+00000004 D _built               libdsap        photo_build
+00000004 C _PIC_LINESIZE        libdsap        photo_util
+00000004 C _STOP                libdsap        photo_util
+00000004 C _NUMLINES            libdsap        photo_util
+00000004 D _sacl_sntx           libdsap        searchacl
+00000004 D _lacl_sntx           libdsap        searchacl
+00000014 D _selector_rank       libdsap        searchacl
+00000004 C _authp_sntx          libdsap        authpolicy
+00000004 D _commonversion       libdsap        commonvrsn
+00000004 D _x500_da_pcdl        libdsap        dsapcontexts
+00000004 D _x500_ds_pcdl        libdsap        dsapcontexts
+00000004 D _quipu_ds_pcdl       libdsap        dsapcontexts
+00000004 D _internet_ds_pcdl    libdsap        dsapcontexts
+00000004 C _acse_pci            libdsap        dsapcontexts
+00000004 C _x500_da_as          libdsap        dsapcontexts
+00000004 C _x500_ds_as          libdsap        dsapcontexts
+00000004 C _quipu_ds_as         libdsap        dsapcontexts
+00000004 C _internet_ds_as      libdsap        dsapcontexts
+00000004 C _x500_da_ac          libdsap        dsapcontexts
+00000004 C _x500_ds_ac          libdsap        dsapcontexts
+00000004 C _quipu_ds_ac         libdsap        dsapcontexts
+00000004 C _internet_ds_ac      libdsap        dsapcontexts
+000000a4 C _x500_da_pcdl_s      libdsap        dsapcontexts
+000000a4 C _x500_ds_pcdl_s      libdsap        dsapcontexts
+000000a4 C _quipu_ds_pcdl_s     libdsap        dsapcontexts
+000000a4 C _internet_ds_pcdl_s  libdsap        dsapcontexts
+00000008 D _restart_fn          libdsap        dsapwait
+00000330 C _dsa_bound           libdsap        dapbind
+00000004 D _abort_vector        libdsap        plog
+00000004 D _netversion          libdsap        netvrsn
+00000030 D _fclass_pairs        libftam        ftamprovider
+00000050 D _funit_pairs         libftam        ftamprovider
+00000020 D _fattr_pairs         libftam        ftamprovider
+00000098 D _fname_pairs         libftam        ftamprovider
+00000030 D _fmode_pairs         libftam        ftamprovider
+00000048 D _frequested_pairs    libftam        ftamprovider
+00000060 D _fpermitted_pairs    libftam        ftamprovider
+00000020 D __ftam_log           libftam        ftamtrace
+00000004 D _ftam_log            libftam        ftamtrace
+00000028 D _fconctl_pairs       libftam        ftamconctl
+00000004 D __ZptrtabCONT        libftam        CONT_tables
+00000024 D __ZCONT_mod          libftam        CONT_tables
+00000058 D __ZptrtabFADU        libftam        FADU_tables
+00000024 D __ZFADU_mod          libftam        FADU_tables
+00000420 D __ZptrtabFTAM        libftam        FTAM_tables
+00000024 D __ZFTAM_mod          libftam        FTAM_tables
+00000004 D _ftamversion         libftam        ftamvrsn
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/image/Makefile isode-8.0/others/quipu/image/Makefile
--- old/isode-8.0/others/quipu/image/Makefile	Tue Jun 16 13:43:25 1992
+++ isode-8.0/others/quipu/image/Makefile	Fri Aug 20 14:36:07 1993
@@ -70,7 +70,7 @@
 xface:		xface.o imagesbr.o \
 			$(TOPDIR)libisode.a $(TOPDIR)libdsap.a
 		$(LDCC) $(LDFLAGS) -o $@ xface.o imagesbr.o \
-			$(LIBDSAP) $(LIBISODE) $(LSOCKET) -lX11 $(LIBGDBM)
+			$(LIBDSAP) $(LIBISODE) $(LSOCKET) -L/usr/X386/lib -lX11 $(LIBGDBM)
 
 l-xface:;	$(LINT) $(LFLAGS) xface.c imagesbr.c $(LLIBS) \
 			| grep -v "warning: possible pointer alignment problem"
@@ -95,7 +95,7 @@
 xwho:		xwho.o imagesbr.o \
 			$(TOPDIR)libisode.a $(TOPDIR)libdsap.a
 		$(LDCC) $(LDFLAGS) -o $@ xwho.o imagesbr.o \
-			$(LIBDSAP) $(LIBISODE) $(LSOCKET) -lX11 $(LIBGDBM)
+			$(LIBDSAP) $(LIBISODE) $(LSOCKET) -L/usr/X386/lib -lX11 $(LIBGDBM)
 
 l-xwho:;	$(LINT) $(LFLAGS) xwho.c imagesbr.c $(LLIBS) \
 			| grep -v "warning: possible pointer alignment problem"
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/photo/Makefile isode-8.0/others/quipu/photo/Makefile
--- old/isode-8.0/others/quipu/photo/Makefile	Tue Jun 16 13:43:36 1992
+++ isode-8.0/others/quipu/photo/Makefile	Fri Aug 20 14:04:10 1993
@@ -27,7 +27,7 @@
 
 # Select you display type(s)...
 # should really go in config/CONFIG.make
-DISPLAY = ttyphoto fax2ps
+DISPLAY = ttyphoto fax2ps Xphoto xfax hexphoto jpeg
 # DISPLAY = sunphoto Xphoto xfax ttyphoto hexphoto t4014 fax2ps jpeg
 
 # UNIX path for the xv binary
@@ -62,11 +62,11 @@
 
 Xphoto: $(TOPDIR)libdsap.a d_main.o winx.o
 	$(LDCC) $(LDFLAGS) -o Xphoto \
-		d_main.o winx.o -lX11 $(LIBDSAP) $(LIBISODE) $(LSOCKET)
+		d_main.o winx.o -L/usr/X386/lib -lX11 $(LIBDSAP) $(LIBISODE) $(LSOCKET)
 
 xfax: $(TOPDIR)libdsap.a d_main.o faxx.o
 	$(LDCC) $(LDFLAGS) -o xfax \
-		d_main.o faxx.o -lX11 $(LIBDSAP) $(LIBISODE) $(LSOCKET)
+		d_main.o faxx.o -L/usr/X386/lib -lX11 $(LIBDSAP) $(LIBISODE) $(LSOCKET)
 
 fax2ps: $(TOPDIR)libdsap.a d_main.o ps.o
 	$(LDCC) $(LDFLAGS) -o fax2ps \
@@ -98,7 +98,8 @@
 PBMSRC  =	/usr/src/pbmplus/
 PBMDIR	=	$(PBMSRC)pbm/
 PBMINC	=	-I$(PBMSRC) -I$(PBMDIR)
-LIBPBM	=	$(PBMDIR)libpbm.a
+#LIBPBM	=	$(PBMDIR)libpbm.a
+LIBPBM	=	/usr/local/lib/libpbm.a
 
 pbm:		faxtopbm pbmtofax
 
@@ -107,14 +108,14 @@
 			$(LIBDSAP) $(LIBPBM) $(LIBISODE) $(LSOCKET)
 
 faxtopbm.o:	faxtopbm.c
-		$(CC) $(CFLAGS) $(PBMINC) -c faxtopbm.c
+		$(CC) $(XFLAGS) $(CFLAGS) $(PBMINC) -c faxtopbm.c
 
 pbmtofax:	pbmtofax.o encode.o code_word.o $(TOPDIR)libdsap.a $(LIBPBM)
 		$(LDCC) $(LDFLAGS) -o $@ pbmtofax.o encode.o code_word.o \
 			$(LIBDSAP) $(LIBPBM) $(LIBISODE) $(LSOCKET)
 
 pbmtofax.o:	pbmtofax.c
-		$(CC) $(CFLAGS) $(PBMINC) -c pbmtofax.c
+		$(CC) $(XFLAGS) $(CFLAGS) $(PBMINC) -c pbmtofax.c
 
 
 #####################################################################
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/photo/pbmtofax.c isode-8.0/others/quipu/photo/pbmtofax.c
--- old/isode-8.0/others/quipu/photo/pbmtofax.c	Tue Jun 16 13:43:41 1992
+++ isode-8.0/others/quipu/photo/pbmtofax.c	Fri Aug 20 14:00:47 1993
@@ -28,7 +28,7 @@
 #include <stdio.h>
 #include "quipu/photo.h"
 #include "pbm.h"
-#include "general.h"
+/*#include "general.h"*/
 
 /*    DATA */
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/tools/dsaconfig/dsaconfig.c isode-8.0/others/quipu/tools/dsaconfig/dsaconfig.c
--- old/isode-8.0/others/quipu/tools/dsaconfig/dsaconfig.c	Tue Jun 16 13:43:58 1992
+++ isode-8.0/others/quipu/tools/dsaconfig/dsaconfig.c	Fri Aug 20 15:07:26 1993
@@ -1334,6 +1334,7 @@
 
 /*    MISCELLANY */
 
+#ifndef _POSIX_SOURCE
 #ifndef	lint
 static char *strdup (s)
 char   *s;
@@ -1347,4 +1348,5 @@
 
     return p;
 }
+#endif
 #endif
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/tools/dsaconfig/usconfig.c isode-8.0/others/quipu/tools/dsaconfig/usconfig.c
--- old/isode-8.0/others/quipu/tools/dsaconfig/usconfig.c	Tue Jun 16 13:44:00 1992
+++ isode-8.0/others/quipu/tools/dsaconfig/usconfig.c	Fri Aug 20 15:08:36 1993
@@ -32,6 +32,9 @@
 #include <sys/file.h>
 #include <pwd.h>
 #include <grp.h>
+#ifdef _POSIX_SOURCE
+#include <unistd.h>
+#endif
 
 #include "general.h"
 #include "manifest.h"
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/uips/de/config.h isode-8.0/others/quipu/uips/de/config.h
--- old/isode-8.0/others/quipu/uips/de/config.h	Tue Jun 16 13:46:07 1992
+++ isode-8.0/others/quipu/uips/de/config.h	Tue Aug 31 15:14:25 1993
@@ -24,6 +24,6 @@
 #ifndef _deconfig_h
 #define _deconfig_h
 
-#define PAGER "/usr/5bin/pg -e -n -p \"RETURN for next screen; q to quit\""
+#define PAGER "/usr/bin/less"
 
 #endif _deconfig_h
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/uips/de/rawinput.c isode-8.0/others/quipu/uips/de/rawinput.c
--- old/isode-8.0/others/quipu/uips/de/rawinput.c	Tue Jun 16 13:46:33 1992
+++ isode-8.0/others/quipu/uips/de/rawinput.c	Tue Aug 31 15:19:01 1993
@@ -26,7 +26,11 @@
 
 
 #include <stdio.h>
+#ifdef __linux__
+#include <termios.h>
+#else
 #include <sys/termio.h>
+#endif
 
 static short savemode;
 static unsigned char savemin;
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/uips/dish/socket.c isode-8.0/others/quipu/uips/dish/socket.c
--- old/isode-8.0/others/quipu/uips/dish/socket.c	Tue Jun 16 13:44:26 1992
+++ isode-8.0/others/quipu/uips/dish/socket.c	Tue Aug 31 17:00:54 1993
@@ -69,12 +69,20 @@
 		else
 		    (void) sprintf (buffer, "127.0.0.1 %d", portno);
 
+#ifdef _POSIX_SOURCE
+		(void) setenv ("DISHPROC", ptr = buffer, 1);
+#else
 		(void) setenv ("DISHPROC", ptr = buffer);
+#endif
         }
 
         if (pid !=0 || (prnt = getenv ("DISHPARENT")) == NULLCP) {
 		(void) sprintf (parent, "%d", myppid);
+#ifdef _POSIX_SOURCE
+		(void) setenv ("DISHPARENT", prnt = parent, 1);
+#else
 		(void) setenv ("DISHPARENT", prnt = parent);
+#endif
 	}
 
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/uips/fred/Makefile isode-8.0/others/quipu/uips/fred/Makefile
--- old/isode-8.0/others/quipu/uips/fred/Makefile	Tue Jun 16 13:44:31 1992
+++ isode-8.0/others/quipu/uips/fred/Makefile	Wed Sep  1 10:26:42 1993
@@ -82,6 +82,7 @@
 		-@echo ""
 
 fred:		xfred
+		:
 
 xfred:		fred.o dispatch.o miscellany.o pipe.o socket.o whois.o
 		$(LDCC) $(LDFLAGS) -o $@ fred.o dispatch.o miscellany.o \
@@ -156,6 +157,7 @@
 		-@echo ""
 
 fredsh:		xfredsh
+		:
 
 xfredsh:	fredsh.sh
 		cp fredsh.sh $@
@@ -193,6 +195,7 @@
 		-@echo ""
 
 dad:		xdad
+		:
 
 xdad:		dad.o socket.o
 		$(LDCC) $(LDFLAGS) -o $@ dad.o socket.o $(LIBES) $(LSOCKET)
@@ -215,6 +218,7 @@
 		-@echo ""
 
 whitepages:	xwhitepages
+		:
 
 xwhitepages:	whitepages.sh
 		cp whitepages.sh $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/uips/manage/Makefile isode-8.0/others/quipu/uips/manage/Makefile
--- old/isode-8.0/others/quipu/uips/manage/Makefile	Tue Jun 16 13:44:45 1992
+++ isode-8.0/others/quipu/uips/manage/Makefile	Tue Aug 31 17:08:55 1993
@@ -64,6 +64,7 @@
 		-@echo ""
 
 dish:		xdish
+		:
 
 xdish:		dish.o libmanage.a
 		$(LDCC) $(LDFLAGS) -o $@ dish.o $(LIBES) 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/uips/pod/Makefile isode-8.0/others/quipu/uips/pod/Makefile
--- old/isode-8.0/others/quipu/uips/pod/Makefile	Tue Jun 16 13:44:54 1992
+++ isode-8.0/others/quipu/uips/pod/Makefile	Fri Aug 27 16:38:28 1993
@@ -10,7 +10,7 @@
 ###############################################################################
 
 #X app-defaults directory.
-APPDEFDIR =	/usr/lib/X11/app-defaults
+APPDEFDIR =	/usr/X386/lib/X11/app-defaults
 
 #yacc flags
 YFLAGS  =	-d
@@ -24,7 +24,7 @@
 
 ISOLIBS =	$(TOPDIR)libdsap.a $(TOPDIR)libisode.a 
 
-XLIBS   =	-lXaw -lXmu -lXt -lX11 -lXext
+XLIBS   =	-L/usr/X386/lib -lXaw -lXmu -lXt -lX11 -lXext
 
 LIBES   =       $(ISOLIBS) $(XLIBS)
 LLIBS   =       $(TOPDIR)llib-ldsap $(TOPDIR)llib-lisode
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/others/quipu/uips/pod/Pod.ad isode-8.0/others/quipu/uips/pod/Pod.ad
--- old/isode-8.0/others/quipu/uips/pod/Pod.ad	Tue Jun 16 13:44:55 1992
+++ isode-8.0/others/quipu/uips/pod/Pod.ad	Wed Sep  1 11:54:46 1993
@@ -1,19 +1,19 @@
 /* $Header: /xtel/isode/isode/others/quipu/uips/pod/RCS/Pod.ad,v 9.0 1992/06/16 12:44:54 isode Rel $ */
 
-Pod*PosTitle.font:		-*-helvetica-*-*-*-*-11-*
-Pod*readTitle.font:		-*-helvetica-*-*-*-*-11-*
-Pod*listTitle.font:		-*-helvetica-*-*-*-*-11-*
-Pod*HistoryTitle.font:		-*-helvetica-*-*-*-*-11-*
-Pod*MenuButton*font:		-*-helvetica-*-r-*-*-11-*
+Pod*PosTitle.font:		-*-helvetica-*-*-*-*-10-*
+Pod*readTitle.font:		-*-helvetica-*-*-*-*-10-*
+Pod*listTitle.font:		-*-helvetica-*-*-*-*-10-*
+Pod*HistoryTitle.font:		-*-helvetica-*-*-*-*-10-*
+Pod*MenuButton*font:		-*-helvetica-*-r-*-*-10-*
 Pod*standby*font:		-*-helvetica-bold-r-*-*-14-*
 Pod*error_popup*font:		-*-helvetica-bold-r-*-*-14-*
-Pod*popup_help_form*font:	-*-helvetica-medium-r-*-*-11-*
+Pod*popup_help_form*font:	-*-helvetica-medium-r-*-*-10-*
 Pod*About Pod*font:		-*-helvetica-bold-r-*-*-14-*
 Pod*SearchVal*font:		-adobe-helvetica-medium-r-*-*-12-*
 Pod*SearchValLabel.font:	-adobe-helvetica-medium-r-*-*-12-*
 Pod*TypeButton.font:		-adobe-helvetica-bold-r-*-*-12-*
 Pod*menu*font:			-adobe-helvetica-bold-r-*-*-12-*
-Pod*font:			-*-helvetica-medium-r-*-*-11-*
+Pod*font:			-*-helvetica-medium-r-*-*-10-*
 
 #ifdef COLOR
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/pepsy/Makefile isode-8.0/pepsy/Makefile
--- old/isode-8.0/pepsy/Makefile	Tue Jun 16 13:24:04 1992
+++ isode-8.0/pepsy/Makefile	Wed Aug 25 14:28:32 1993
@@ -81,6 +81,7 @@
 		-@echo ""
 
 pepsy:		xpepsy
+		:
 
 xpepsy:		pepsyvrsn.o $(PEPSYLIBES)
 		$(LDCC) $(LDFLAGS) -o $@ $(PEPSY-O) \
@@ -142,6 +143,18 @@
 ################################################################
 
 inst-libpepsy:	$(LIBDIR)libpepsy.a inst-headers
+
+zap-pepsy:
+		-rm -f $(LIBFILES) libpepsy.a
+
+linux-lib:	zap-pepsy ../jump/libpepsy.a
+
+../jump/libpepsy.a:	libpepsy
+		-rm -f $@
+		cp libpepsy.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
 
 libpepsy:	libpepsy.a true
 		-@rm -f $(TOPDIR)h/UNIV*.h
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/pepy/Makefile isode-8.0/pepy/Makefile
--- old/isode-8.0/pepy/Makefile	Tue Jun 16 13:25:02 1992
+++ isode-8.0/pepy/Makefile	Tue Aug 24 11:52:30 1993
@@ -81,6 +81,7 @@
 		-@echo ""
 
 pepy:		xpepy
+		:
 
 xpepy:		pepyvrsn.o $(PEPYLIBES)
 		$(LDCC) $(LDFLAGS) -o $@ pepy.o pepy_do.o pepy_undo.o \
@@ -142,6 +143,7 @@
 		-@echo ""
 
 posy:		xposy
+		:
 
 xposy:		posy.o pepy_misc.o yacc.o pepyvrsn.o $(PEPYLIBES)
 		$(LDCC) $(LDFLAGS) -o $@ posy.o pepy_misc.o yacc.o \
@@ -165,6 +167,18 @@
 HEADERS	=	UNIV.ph UNIV-types.h
 
 inst-libpepy:	$(LIBDIR)libpepy.a inst-headers
+
+zap-pepy:
+		-rm -f $(OFILES) libpepy.a UPEPY-[0-9]*.o VPEPY-[0-9]*.o
+
+linux-lib:	zap-pepy ../jump/libpepy.a
+
+../jump/libpepy.a:	libpepy.a
+		-rm -f $@
+		cp libpepy.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
 
 $(LIBDIR)libpepy.a:	libpepy.a
 		-rm -f $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/pepy/dotests isode-8.0/pepy/dotests
--- old/isode-8.0/pepy/dotests	Thu Jan  1 01:00:00 1970
+++ isode-8.0/pepy/dotests	Thu Aug 26 17:09:25 1993
@@ -0,0 +1,9 @@
+for f in test/test*.pe; \
+		do (echo pepytest $f; ./pepytest < $f); done
+for f in test/test*.pe test/mhs/msg*.pe; \
+		do (echo pp $f; ./pp < $f); done
+for f in test/mhs/msg*.pe; \
+		do (echo mpp $f; ./mpp < $f); done
+./salary fritz 10
+./hello_world
+./bigpepytest
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/psap/Makefile isode-8.0/psap/Makefile
--- old/isode-8.0/psap/Makefile	Tue Jun 16 13:25:44 1992
+++ isode-8.0/psap/Makefile	Tue Aug 24 11:53:07 1993
@@ -85,6 +85,18 @@
 
 inst-libpsap:	$(LIBDIR)libpsap.a $(LINTDIR)llib-lpsap
 
+zap-psap:
+		-rm -f $(OFILES) libpsap.a psapvrsn.o
+
+linux-lib:	zap-psap ../jump/libpsap.a
+
+../jump/libpsap.a:	libpsap.a
+		-rm -f $@
+		cp libpsap.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libpsap.a:	libpsap.a
 		-rm -f $@
 		cp libpsap.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/psap2/Makefile isode-8.0/psap2/Makefile
--- old/isode-8.0/psap2/Makefile	Tue Jun 16 13:29:43 1992
+++ isode-8.0/psap2/Makefile	Tue Aug 24 11:52:20 1993
@@ -68,6 +68,18 @@
 
 inst-libpsap2:	$(LIBDIR)libpsap2.a $(LINTDIR)llib-lpsap2
 
+zap-psap2:
+		-rm -f $(OFILES) libpsap2.a PS_tables.o psap2vrsn.o
+
+linux-lib:	zap-psap2 ../jump/libpsap2.a
+
+../jump/libpsap2.a:	libpsap2.a
+		-rm -f $@
+		cp libpsap2.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libpsap2.a:	libpsap2.a
 		-rm -f $@
 		cp libpsap2.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/psap2-lpp/Makefile isode-8.0/psap2-lpp/Makefile
--- old/isode-8.0/psap2-lpp/Makefile	Tue Jun 16 13:31:58 1992
+++ isode-8.0/psap2-lpp/Makefile	Fri Aug 27 11:04:05 1993
@@ -66,6 +66,18 @@
 
 inst-libpsap2:	$(LIBDIR)libpsap2-lpp.a $(LINTDIR)llib-lpsap2-lpp
 
+zap-psap2-lpp:
+		-rm -f $(OFILES) libpsap2.a PS_tables.o psap2vrsn.o
+
+linux-lib:	zap-psap2-lpp ../jump/libpsap2-lpp.a
+
+../jump/libpsap2-lpp.a:	libpsap2-lpp.a
+		-rm -f $@
+		cp libpsap2-lpp.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libpsap2-lpp.a:	libpsap2-lpp.a
 		-rm -f $@
 		cp libpsap2-lpp.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/quipu/Makefile isode-8.0/quipu/Makefile
--- old/isode-8.0/quipu/Makefile	Tue Jun 16 13:34:01 1992
+++ isode-8.0/quipu/Makefile	Mon Aug 23 11:24:13 1993
@@ -37,8 +37,8 @@
 
 # Remove these two definitions if you do not want the QUIPU optimised malloc.
 # Performace may suffer if you do!
-MALLOC_C =	malloc.c
-MALLOC_O =	malloc.o
+#MALLOC_C =	malloc.c
+#MALLOC_O =	malloc.o
 #DEBUGLIB  =	/xtel/user/cjr/src/mprof/libc_mp.a
 
 ##############################################################
@@ -133,7 +133,7 @@
 		$(LDCC) $(LDFLAGS) -o $@ malloc_test.o qmalloc.o
 
 qmalloc.o:	malloc.c
-		$(CC) $(CFLAGS) -DMALLOC_TEST -o $@ -c malloc.c 
+		$(CC) $(CFLAGS) -o $@ -c malloc.c 
 
 quipuvrsn.c:	$(OFILES)
 		@$(UTILDIR)version.sh quipu > $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/quipu/dish/Makefile isode-8.0/quipu/dish/Makefile
--- old/isode-8.0/quipu/dish/Makefile	Tue Jun 16 13:35:40 1992
+++ isode-8.0/quipu/dish/Makefile	Mon Aug 23 15:52:33 1993
@@ -78,6 +78,7 @@
 		-@echo ""
 
 dish:		xdish
+		:
 
 xdish:		libdish.a dish.o $(LIBES)
 		$(LDCC) $(LDFLAGS) -o $@ dish.o $(LIBDISH) \
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/quipu/dish/dishlib.c isode-8.0/quipu/dish/dishlib.c
--- old/isode-8.0/quipu/dish/dishlib.c	Tue Jun 16 13:35:46 1992
+++ isode-8.0/quipu/dish/dishlib.c	Fri Aug 20 11:20:34 1993
@@ -160,9 +160,13 @@
 	(void) signal (SIGHUP,	dish_quit);
 	(void) signal (SIGQUIT,	dish_quit);
 	(void) signal (SIGILL, 	dish_quit);
+#ifdef SIGBUS
 	(void) signal (SIGBUS,	dish_quit);
+#endif
 	(void) signal (SIGSEGV,	dish_quit);
+#ifdef SIGSYS
 	(void) signal (SIGSYS,	dish_quit);
+#endif
 	(void) signal (SIGTERM,	dish_quit);
 
 #ifdef TURBO_DISK
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/quipu/dish/fred.c isode-8.0/quipu/dish/fred.c
--- old/isode-8.0/quipu/dish/fred.c	Tue Jun 16 13:35:49 1992
+++ isode-8.0/quipu/dish/fred.c	Fri Aug 20 11:18:39 1993
@@ -137,7 +137,11 @@
 	if (argc != 3)
 	    goto usage;
 
+#ifdef _POSIX_SOURCE
+	(void) setenv ("DISPLAY", argv[2], 1);
+#else
 	(void) setenv ("DISPLAY", argv[2]);
+#endif
 	if (s_photo)
 	    set_av_pe_print (s_photo,
 			     strdup (isodefile ("g3fax/Xphoto", 1)));
@@ -1599,10 +1603,18 @@
 			}
 			ps_print (ps, " ");
 			*--ps -> ps_ptr = NULL, ps -> ps_cnt++;
+#ifdef _POSIX_SOURCE
+			(void) setenv ("RDN", ps -> ps_base, 1);
+#else
 			(void) setenv ("RDN", ps -> ps_base);
+#endif
 		    }
 		    else
+#ifdef _POSIX_SOURCE
+			(void) setenv ("RDN", "Photo", 1);
+#else
 			(void) setenv ("RDN", "Photo");
+#endif
 		}
 		break;
 	    }
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/quipu/dish/pipe.c isode-8.0/quipu/dish/pipe.c
--- old/isode-8.0/quipu/dish/pipe.c	Tue Jun 16 13:35:55 1992
+++ isode-8.0/quipu/dish/pipe.c	Fri Aug 20 11:21:19 1993
@@ -64,7 +64,11 @@
 
 	if ((cp = getenv ("DISHPARENT")) == NULLCP) {
 		(void) sprintf (parent, "%d", getppid ());
+#ifdef _POSIX_SOURCE
+		(void) setenv ("DISHPARENT", cp = parent, 1);
+#else
 		(void) setenv ("DISHPARENT", cp = parent);
+#endif
 	}
 
 
@@ -360,7 +364,11 @@
 #else
 		(void) sprintf (buffer, "127.0.0.1 %d", portno);
 #endif
+#ifdef _POSIX_SOURCE
+		(void) setenv ("DISHPROC", ptr = buffer, 1);
+#else
 		(void) setenv ("DISHPROC", ptr = buffer);
+#endif
 	}
 
 	if ((dp = index (ptr, ' ')) == NULLCP || sscanf (dp + 1, "%d", &portno) != 1) {
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/quipu/dsa.c isode-8.0/quipu/dsa.c
--- old/isode-8.0/quipu/dsa.c	Tue Jun 16 13:34:19 1992
+++ isode-8.0/quipu/dsa.c	Fri Aug 20 11:08:31 1993
@@ -281,9 +281,13 @@
     /* now started don't stop on core dumps !!! */
     (void) signal (SIGQUIT, attempt_restart);
     (void) signal (SIGILL,  attempt_restart);
+#ifdef SIGBUS
     (void) signal (SIGBUS,  attempt_restart);
+#endif
     (void) signal (SIGSEGV, attempt_restart);
+#ifdef SIGSYS
     (void) signal (SIGSYS,  attempt_restart);
+#endif
     (void) signal (SIGPIPE,  attempt_restart);
 #ifdef	SIGUSR1
     (void) signal (SIGUSR1, list_status);
@@ -743,9 +747,13 @@
 
 	(void) signal (SIGQUIT, attempt_restart);
 	(void) signal (SIGILL,  attempt_restart);
+#ifdef SIGBUS
 	(void) signal (SIGBUS,  attempt_restart);
+#endif
 	(void) signal (SIGSEGV, attempt_restart);
+#ifdef SIGSYS
 	(void) signal (SIGSYS,  attempt_restart);
+#endif
 
 	if (sig >= 0 && debug)
 		(void) fprintf (stderr,"DSA %s has a problem\n",mydsaname);
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/quipu/malloc.c isode-8.0/quipu/malloc.c
--- old/isode-8.0/quipu/malloc.c	Tue Jun 16 13:34:31 1992
+++ isode-8.0/quipu/malloc.c	Fri Aug 20 11:11:21 1993
@@ -1,3 +1,5 @@
+#ifndef __linux__
+
 /* malloc.c - Quipu DSA specific memory management */
 
 #ifndef	lint
@@ -804,3 +806,5 @@
 }
 
 #endif	/* QUIPUMALLOC */
+
+#endif /* __linux__ */
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ronot/Makefile isode-8.0/ronot/Makefile
--- old/isode-8.0/ronot/Makefile	Tue Jun 16 13:36:37 1992
+++ isode-8.0/ronot/Makefile	Tue Aug 24 11:51:28 1993
@@ -59,6 +59,18 @@
 
 inst-libronot:	$(LIBDIR)libronot.a $(LINTDIR)llib-lronot
 
+zap-ronot:
+		-rm -f $(OFILES) libronot.a ronotvrsn.o
+
+linux-lib:	zap-ronot ../jump/libronot.a
+
+../jump/libronot.a:	libronot.a
+		-rm -f $@
+		cp libronot.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libronot.a:	libronot.a
 		-rm -f $@
 		cp libronot.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/rosap/Makefile isode-8.0/rosap/Makefile
--- old/isode-8.0/rosap/Makefile	Tue Jun 16 13:37:02 1992
+++ isode-8.0/rosap/Makefile	Wed Aug 25 14:14:43 1993
@@ -78,6 +78,18 @@
 
 inst-librosap:	$(LIBDIR)librosap.a $(LINTDIR)llib-lrosap
 
+zap-rosap:
+		-rm -f $(OFILES) librosap.a ROS_tables.o rosapvrsn.o
+
+linux-lib:	zap-rosap ../jump/librosap.a
+
+../jump/librosap.a:	librosap.a
+		-rm -f $@
+		cp librosap.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)librosap.a:	librosap.a
 		-rm -f $@
 		cp librosap.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/rosy/Makefile isode-8.0/rosy/Makefile
--- old/isode-8.0/rosy/Makefile	Tue Jun 16 13:37:29 1992
+++ isode-8.0/rosy/Makefile	Tue Aug 24 11:51:15 1993
@@ -69,6 +69,7 @@
 		-@echo ""
 
 rosy:		xrosy
+		:
 
 xrosy:		rosyvrsn.o $(PEPYLIBES)
 		$(LDCC) $(LDFLAGS) -o $@ rosy.o yacc.o pepy_misc.o \
@@ -133,6 +134,18 @@
 OFILES=		$(P-OFILES) $(N-OFILES) $(OSTRINGS)
 
 inst-librosy:	$(LIBDIR)librosy.a $(LINTDIR)llib-lrosy
+
+zap-rosy:
+		-rm -f $(OFILES) librosy.a
+
+linux-lib:	zap-rosy ../jump/librosy.a
+
+../jump/librosy.a:	librosy.a
+		-rm -f $@
+		cp librosy.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
 
 $(LIBDIR)librosy.a:	librosy.a
 		-rm -f $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/rtsap/Makefile isode-8.0/rtsap/Makefile
--- old/isode-8.0/rtsap/Makefile	Tue Jun 16 13:37:45 1992
+++ isode-8.0/rtsap/Makefile	Tue Aug 24 11:51:56 1993
@@ -73,6 +73,18 @@
 
 inst-librtsap:	$(LIBDIR)librtsap.a $(LINTDIR)llib-lrtsap
 
+zap-rtsap:
+		-rm -f $(OFILES) librtsap.a RTS_tables.o rtsapvrsn.o
+
+linux-lib:	zap-rtsap ../jump/librtsap.a
+
+../jump/librtsap.a:	librtsap.a
+		-rm -f $@
+		cp librtsap.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)librtsap.a:	librtsap.a
 		-rm -f $@
 		cp librtsap.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/snmp/objects.defs isode-8.0/snmp/objects.defs
--- old/isode-8.0/snmp/objects.defs	Tue Jun 16 12:33:20 1992
+++ isode-8.0/snmp/objects.defs	Mon Aug 23 16:07:25 1993
@@ -462,6 +462,530 @@
 ospfVirtNbrLSRetransQLen ospfVirtNbrEntry.7 Gauge           read-only       mandatory
 
 
+-- automatically generated by mosy 7.0 #65 (dbc), do not edit!
+
+-- object definitions compiled from RFC1269-MIB
+
+bgp                  mib-2.15
+
+bgpVersion           bgp.1            OctetString     read-only       mandatory
+bgpLocalAs           bgp.2            INTEGER         read-only       mandatory
+bgpPeerTable         bgp.3            Aggregate       not-accessible  mandatory
+bgpIdentifier        bgp.4            IpAddress       read-only       mandatory
+bgpPeerEntry         bgpPeerTable.1   Aggregate       not-accessible  mandatory
+bgpPeerIdentifier    bgpPeerEntry.1   IpAddress       read-only       mandatory
+bgpPeerState         bgpPeerEntry.2   INTEGER         read-only       mandatory
+bgpPeerAdminStatus   bgpPeerEntry.3   INTEGER         read-write      mandatory
+bgpPeerNegotiatedVersion bgpPeerEntry.4   INTEGER         read-only       mandatory
+bgpPeerLocalAddr     bgpPeerEntry.5   IpAddress       read-only       mandatory
+bgpPeerLocalPort     bgpPeerEntry.6   INTEGER         read-only       mandatory
+bgpPeerRemoteAddr    bgpPeerEntry.7   IpAddress       read-only       mandatory
+bgpPeerRemotePort    bgpPeerEntry.8   INTEGER         read-only       mandatory
+bgpPeerRemoteAs      bgpPeerEntry.9   INTEGER         read-only       mandatory
+bgpPeerInUpdates     bgpPeerEntry.10  Counter         read-only       mandatory
+bgpPeerOutUpdates    bgpPeerEntry.11  Counter         read-only       mandatory
+bgpPeerInTotalMessages bgpPeerEntry.12  Counter         read-only       mandatory
+bgpPeerOutTotalMessages bgpPeerEntry.13  Counter         read-only       mandatory
+bgpPeerLastError     bgpPeerEntry.14  OctetString     read-only       mandatory
+bgpRcvdPathAttrTable bgp.5            Aggregate       not-accessible  mandatory
+bgpPathAttrEntry     bgpRcvdPathAttrTable.1 Aggregate       not-accessible  mandatory
+bgpPathAttrPeer      bgpPathAttrEntry.1 IpAddress       read-only       mandatory
+bgpPathAttrDestNetwork bgpPathAttrEntry.2 IpAddress       read-only       mandatory
+bgpPathAttrOrigin    bgpPathAttrEntry.3 INTEGER         read-only       mandatory
+bgpPathAttrASPath    bgpPathAttrEntry.4 OctetString     read-only       mandatory
+bgpPathAttrNextHop   bgpPathAttrEntry.5 IpAddress       read-only       mandatory
+bgpPathAttrInterASMetric bgpPathAttrEntry.6 IpAddress       read-only       mandatory
+
+
+-- automatically generated by mosy 7.0 #65 (dbc), do not edit!
+
+-- object definitions compiled from RFC1271-MIB
+
+rmon                 mib-2.16
+statistics           rmon.1
+history              rmon.2
+alarm                rmon.3
+hosts                rmon.4
+hostTopN             rmon.5
+matrix               rmon.6
+filter               rmon.7
+capture              rmon.8
+event                rmon.9
+
+etherStatsTable      statistics.1     Aggregate       not-accessible  mandatory
+etherStatsEntry      etherStatsTable.1 Aggregate       not-accessible  mandatory
+etherStatsIndex      etherStatsEntry.1 INTEGER         read-only       mandatory
+etherStatsDataSource etherStatsEntry.2 ObjectID        read-write      mandatory
+etherStatsDropEvents etherStatsEntry.3 Counter         read-only       mandatory
+etherStatsOctets     etherStatsEntry.4 Counter         read-only       mandatory
+etherStatsPkts       etherStatsEntry.5 Counter         read-only       mandatory
+etherStatsBroadcastPkts etherStatsEntry.6 Counter         read-only       mandatory
+etherStatsMulticastPkts etherStatsEntry.7 Counter         read-only       mandatory
+etherStatsCRCAlignErrors etherStatsEntry.8 Counter         read-only       mandatory
+etherStatsUndersizePkts etherStatsEntry.9 Counter         read-only       mandatory
+etherStatsOversizePkts etherStatsEntry.10 Counter         read-only       mandatory
+etherStatsFragments  etherStatsEntry.11 Counter         read-only       mandatory
+etherStatsJabbers    etherStatsEntry.12 Counter         read-only       mandatory
+etherStatsCollisions etherStatsEntry.13 Counter         read-only       mandatory
+etherStatsPkts64Octets etherStatsEntry.14 Counter         read-only       mandatory
+etherStatsPkts65to127Octets etherStatsEntry.15 Counter         read-only       mandatory
+etherStatsPkts128to255Octets etherStatsEntry.16 Counter         read-only       mandatory
+etherStatsPkts256to511Octets etherStatsEntry.17 Counter         read-only       mandatory
+etherStatsPkts512to1023Octets etherStatsEntry.18 Counter         read-only       mandatory
+etherStatsPkts1024to1518Octets etherStatsEntry.19 Counter         read-only       mandatory
+etherStatsOwner      etherStatsEntry.20 DisplayString   read-write      mandatory
+etherStatsStatus     etherStatsEntry.21 INTEGER         read-write      mandatory
+historyControlTable  history.1        Aggregate       not-accessible  mandatory
+historyControlEntry  historyControlTable.1 Aggregate       not-accessible  mandatory
+historyControlIndex  historyControlEntry.1 INTEGER         read-only       mandatory
+historyControlDataSource historyControlEntry.2 ObjectID        read-write      mandatory
+historyControlBucketsRequested historyControlEntry.3 INTEGER         read-write      mandatory
+historyControlBucketsGranted historyControlEntry.4 INTEGER         read-only       mandatory
+historyControlInterval historyControlEntry.5 INTEGER         read-write      mandatory
+historyControlOwner  historyControlEntry.6 DisplayString   read-write      mandatory
+historyControlStatus historyControlEntry.7 INTEGER         read-write      mandatory
+etherHistoryTable    history.2        Aggregate       not-accessible  mandatory
+etherHistoryEntry    etherHistoryTable.1 Aggregate       not-accessible  mandatory
+etherHistoryIndex    etherHistoryEntry.1 INTEGER         read-only       mandatory
+etherHistorySampleIndex etherHistoryEntry.2 INTEGER         read-only       mandatory
+etherHistoryIntervalStart etherHistoryEntry.3 TimeTicks       read-only       mandatory
+etherHistoryDropEvents etherHistoryEntry.4 Counter         read-only       mandatory
+etherHistoryOctets   etherHistoryEntry.5 Counter         read-only       mandatory
+etherHistoryPkts     etherHistoryEntry.6 Counter         read-only       mandatory
+etherHistoryBroadcastPkts etherHistoryEntry.7 Counter         read-only       mandatory
+etherHistoryMulticastPkts etherHistoryEntry.8 Counter         read-only       mandatory
+etherHistoryCRCAlignErrors etherHistoryEntry.9 Counter         read-only       mandatory
+etherHistoryUndersizePkts etherHistoryEntry.10 Counter         read-only       mandatory
+etherHistoryOversizePkts etherHistoryEntry.11 Counter         read-only       mandatory
+etherHistoryFragments etherHistoryEntry.12 Counter         read-only       mandatory
+etherHistoryJabbers  etherHistoryEntry.13 Counter         read-only       mandatory
+etherHistoryCollisions etherHistoryEntry.14 Counter         read-only       mandatory
+etherHistoryUtilization etherHistoryEntry.15 INTEGER         read-only       mandatory
+alarmTable           alarm.1          Aggregate       not-accessible  mandatory
+alarmEntry           alarmTable.1     Aggregate       not-accessible  mandatory
+alarmIndex           alarmEntry.1     INTEGER         read-only       mandatory
+alarmInterval        alarmEntry.2     INTEGER         read-write      mandatory
+alarmVariable        alarmEntry.3     ObjectID        read-write      mandatory
+alarmSampleType      alarmEntry.4     INTEGER         read-write      mandatory
+alarmValue           alarmEntry.5     INTEGER         read-only       mandatory
+alarmStartupAlarm    alarmEntry.6     INTEGER         read-write      mandatory
+alarmRisingThreshold alarmEntry.7     INTEGER         read-write      mandatory
+alarmFallingThreshold alarmEntry.8     INTEGER         read-write      mandatory
+alarmRisingEventIndex alarmEntry.9     INTEGER         read-write      mandatory
+alarmFallingEventIndex alarmEntry.10    INTEGER         read-write      mandatory
+alarmOwner           alarmEntry.11    DisplayString   read-write      mandatory
+alarmStatus          alarmEntry.12    INTEGER         read-write      mandatory
+hostControlTable     hosts.1          Aggregate       not-accessible  mandatory
+hostControlEntry     hostControlTable.1 Aggregate       not-accessible  mandatory
+hostControlIndex     hostControlEntry.1 INTEGER         read-only       mandatory
+hostControlDataSource hostControlEntry.2 ObjectID        read-write      mandatory
+hostControlTableSize hostControlEntry.3 INTEGER         read-only       mandatory
+hostControlLastDeleteTime hostControlEntry.4 TimeTicks       read-only       mandatory
+hostControlOwner     hostControlEntry.5 DisplayString   read-write      mandatory
+hostControlStatus    hostControlEntry.6 INTEGER         read-write      mandatory
+hostTable            hosts.2          Aggregate       not-accessible  mandatory
+hostEntry            hostTable.1      Aggregate       not-accessible  mandatory
+hostAddress          hostEntry.1      OctetString     read-only       mandatory
+hostCreationOrder    hostEntry.2      INTEGER         read-only       mandatory
+hostIndex            hostEntry.3      INTEGER         read-only       mandatory
+hostInPkts           hostEntry.4      Counter         read-only       mandatory
+hostOutPkts          hostEntry.5      Counter         read-only       mandatory
+hostInOctets         hostEntry.6      Counter         read-only       mandatory
+hostOutOctets        hostEntry.7      Counter         read-only       mandatory
+hostOutErrors        hostEntry.8      Counter         read-only       mandatory
+hostOutBroadcastPkts hostEntry.9      Counter         read-only       mandatory
+hostOutMulticastPkts hostEntry.10     Counter         read-only       mandatory
+hostTimeTable        hosts.3          Aggregate       not-accessible  mandatory
+hostTimeEntry        hostTimeTable.1  Aggregate       not-accessible  mandatory
+hostTimeAddress      hostTimeEntry.1  OctetString     read-only       mandatory
+hostTimeCreationOrder hostTimeEntry.2  INTEGER         read-only       mandatory
+hostTimeIndex        hostTimeEntry.3  INTEGER         read-only       mandatory
+hostTimeInPkts       hostTimeEntry.4  Counter         read-only       mandatory
+hostTimeOutPkts      hostTimeEntry.5  Counter         read-only       mandatory
+hostTimeInOctets     hostTimeEntry.6  Counter         read-only       mandatory
+hostTimeOutOctets    hostTimeEntry.7  Counter         read-only       mandatory
+hostTimeOutErrors    hostTimeEntry.8  Counter         read-only       mandatory
+hostTimeOutBroadcastPkts hostTimeEntry.9  Counter         read-only       mandatory
+hostTimeOutMulticastPkts hostTimeEntry.10 Counter         read-only       mandatory
+hostTopNControlTable hostTopN.1       Aggregate       not-accessible  mandatory
+hostTopNControlEntry hostTopNControlTable.1 Aggregate       not-accessible  mandatory
+hostTopNControlIndex hostTopNControlEntry.1 INTEGER         read-only       mandatory
+hostTopNHostIndex    hostTopNControlEntry.2 INTEGER         read-write      mandatory
+hostTopNRateBase     hostTopNControlEntry.3 INTEGER         read-write      mandatory
+hostTopNTimeRemaining hostTopNControlEntry.4 INTEGER         read-write      mandatory
+hostTopNDuration     hostTopNControlEntry.5 INTEGER         read-only       mandatory
+hostTopNRequestedSize hostTopNControlEntry.6 INTEGER         read-write      mandatory
+hostTopNGrantedSize  hostTopNControlEntry.7 INTEGER         read-only       mandatory
+hostTopNStartTime    hostTopNControlEntry.8 TimeTicks       read-only       mandatory
+hostTopNOwner        hostTopNControlEntry.9 DisplayString   read-write      mandatory
+hostTopNStatus       hostTopNControlEntry.10 INTEGER         read-write      mandatory
+hostTopNTable        hostTopN.2       Aggregate       not-accessible  mandatory
+hostTopNEntry        hostTopNTable.1  Aggregate       not-accessible  mandatory
+hostTopNReport       hostTopNEntry.1  INTEGER         read-only       mandatory
+hostTopNIndex        hostTopNEntry.2  INTEGER         read-only       mandatory
+hostTopNAddress      hostTopNEntry.3  OctetString     read-only       mandatory
+hostTopNRate         hostTopNEntry.4  INTEGER         read-only       mandatory
+matrixControlTable   matrix.1         Aggregate       not-accessible  mandatory
+matrixControlEntry   matrixControlTable.1 Aggregate       not-accessible  mandatory
+matrixControlIndex   matrixControlEntry.1 INTEGER         read-only       mandatory
+matrixControlDataSource matrixControlEntry.2 ObjectID        read-write      mandatory
+matrixControlTableSize matrixControlEntry.3 INTEGER         read-only       mandatory
+matrixControlLastDeleteTime matrixControlEntry.4 TimeTicks       read-only       mandatory
+matrixControlOwner   matrixControlEntry.5 DisplayString   read-write      mandatory
+matrixControlStatus  matrixControlEntry.6 INTEGER         read-write      mandatory
+matrixSDTable        matrix.2         Aggregate       not-accessible  mandatory
+matrixSDEntry        matrixSDTable.1  Aggregate       not-accessible  mandatory
+matrixSDSourceAddress matrixSDEntry.1  OctetString     read-only       mandatory
+matrixSDDestAddress  matrixSDEntry.2  OctetString     read-only       mandatory
+matrixSDIndex        matrixSDEntry.3  INTEGER         read-only       mandatory
+matrixSDPkts         matrixSDEntry.4  Counter         read-only       mandatory
+matrixSDOctets       matrixSDEntry.5  Counter         read-only       mandatory
+matrixSDErrors       matrixSDEntry.6  Counter         read-only       mandatory
+matrixDSTable        matrix.3         Aggregate       not-accessible  mandatory
+matrixDSEntry        matrixDSTable.1  Aggregate       not-accessible  mandatory
+matrixDSSourceAddress matrixDSEntry.1  OctetString     read-only       mandatory
+matrixDSDestAddress  matrixDSEntry.2  OctetString     read-only       mandatory
+matrixDSIndex        matrixDSEntry.3  INTEGER         read-only       mandatory
+matrixDSPkts         matrixDSEntry.4  Counter         read-only       mandatory
+matrixDSOctets       matrixDSEntry.5  Counter         read-only       mandatory
+matrixDSErrors       matrixDSEntry.6  Counter         read-only       mandatory
+filterTable          filter.1         Aggregate       not-accessible  mandatory
+filterEntry          filterTable.1    Aggregate       not-accessible  mandatory
+filterIndex          filterEntry.1    INTEGER         read-only       mandatory
+filterChannelIndex   filterEntry.2    INTEGER         read-write      mandatory
+filterPktDataOffset  filterEntry.3    INTEGER         read-write      mandatory
+filterPktData        filterEntry.4    OctetString     read-write      mandatory
+filterPktDataMask    filterEntry.5    OctetString     read-write      mandatory
+filterPktDataNotMask filterEntry.6    OctetString     read-write      mandatory
+filterPktStatus      filterEntry.7    INTEGER         read-write      mandatory
+filterPktStatusMask  filterEntry.8    INTEGER         read-write      mandatory
+filterPktStatusNotMask filterEntry.9    INTEGER         read-write      mandatory
+filterOwner          filterEntry.10   DisplayString   read-write      mandatory
+filterStatus         filterEntry.11   INTEGER         read-write      mandatory
+channelTable         filter.2         Aggregate       not-accessible  mandatory
+channelEntry         channelTable.1   Aggregate       not-accessible  mandatory
+channelIndex         channelEntry.1   INTEGER         read-only       mandatory
+channelIfIndex       channelEntry.2   INTEGER         read-write      mandatory
+channelAcceptType    channelEntry.3   INTEGER         read-write      mandatory
+channelDataControl   channelEntry.4   INTEGER         read-write      mandatory
+channelTurnOnEventIndex channelEntry.5   INTEGER         read-write      mandatory
+channelTurnOffEventIndex channelEntry.6   INTEGER         read-write      mandatory
+channelEventIndex    channelEntry.7   INTEGER         read-write      mandatory
+channelEventStatus   channelEntry.8   INTEGER         read-write      mandatory
+channelMatches       channelEntry.9   Counter         read-only       mandatory
+channelDescription   channelEntry.10  DisplayString   read-write      mandatory
+channelOwner         channelEntry.11  DisplayString   read-write      mandatory
+channelStatus        channelEntry.12  INTEGER         read-write      mandatory
+bufferControlTable   capture.1        Aggregate       not-accessible  mandatory
+bufferControlEntry   bufferControlTable.1 Aggregate       not-accessible  mandatory
+bufferControlIndex   bufferControlEntry.1 INTEGER         read-only       mandatory
+bufferControlChannelIndex bufferControlEntry.2 INTEGER         read-write      mandatory
+bufferControlFullStatus bufferControlEntry.3 INTEGER         read-only       mandatory
+bufferControlFullAction bufferControlEntry.4 INTEGER         read-write      mandatory
+bufferControlCaptureSliceSize bufferControlEntry.5 INTEGER         read-write      mandatory
+bufferControlDownloadSliceSize bufferControlEntry.6 INTEGER         read-write      mandatory
+bufferControlDownloadOffset bufferControlEntry.7 INTEGER         read-write      mandatory
+bufferControlMaxOctetsRequested bufferControlEntry.8 INTEGER         read-write      mandatory
+bufferControlMaxOctetsGranted bufferControlEntry.9 INTEGER         read-only       mandatory
+bufferControlCapturedPackets bufferControlEntry.10 INTEGER         read-only       mandatory
+bufferControlTurnOnTime bufferControlEntry.11 TimeTicks       read-only       mandatory
+bufferControlOwner   bufferControlEntry.12 DisplayString   read-write      mandatory
+bufferControlStatus  bufferControlEntry.13 INTEGER         read-write      mandatory
+captureBufferTable   capture.2        Aggregate       not-accessible  mandatory
+captureBufferEntry   captureBufferTable.1 Aggregate       not-accessible  mandatory
+captureBufferControlIndex captureBufferEntry.1 INTEGER         read-only       mandatory
+captureBufferIndex   captureBufferEntry.2 INTEGER         read-only       mandatory
+captureBufferPacketID captureBufferEntry.3 INTEGER         read-only       mandatory
+captureBufferPacketData captureBufferEntry.4 OctetString     read-only       mandatory
+captureBufferPacketLength captureBufferEntry.5 INTEGER         read-only       mandatory
+captureBufferPacketTime captureBufferEntry.6 INTEGER         read-only       mandatory
+captureBufferPacketStatus captureBufferEntry.7 INTEGER         read-only       mandatory
+eventTable           event.1          Aggregate       not-accessible  mandatory
+eventEntry           eventTable.1     Aggregate       not-accessible  mandatory
+eventIndex           eventEntry.1     INTEGER         read-only       mandatory
+eventDescription     eventEntry.2     DisplayString   read-write      mandatory
+eventType            eventEntry.3     INTEGER         read-write      mandatory
+eventCommunity       eventEntry.4     OctetString     read-write      mandatory
+eventLastTimeSent    eventEntry.5     TimeTicks       read-only       mandatory
+eventOwner           eventEntry.6     DisplayString   read-write      mandatory
+eventStatus          eventEntry.7     INTEGER         read-write      mandatory
+logTable             event.2          Aggregate       not-accessible  mandatory
+logEntry             logTable.1       Aggregate       not-accessible  mandatory
+logEventIndex        logEntry.1       INTEGER         read-only       mandatory
+logIndex             logEntry.2       INTEGER         read-only       mandatory
+logTime              logEntry.3       TimeTicks       read-only       mandatory
+logDescription       logEntry.4       DisplayString   read-only       mandatory
+
+
+-- automatically generated by mosy 7.0 #65 (dbc), do not edit!
+
+-- object definitions compiled from RFC1286-MIB
+
+dot1dBridge          mib-2.17
+dot1dBase            dot1dBridge.1
+dot1dStp             dot1dBridge.2
+dot1dSr              dot1dBridge.3
+dot1dTp              dot1dBridge.4
+dot1dStatic          dot1dBridge.5
+
+dot1dBaseBridgeAddress dot1dBase.1      OctetString     read-only       mandatory
+dot1dBaseNumPorts    dot1dBase.2      INTEGER         read-only       mandatory
+dot1dBaseType        dot1dBase.3      INTEGER         read-only       mandatory
+dot1dBasePortTable   dot1dBase.4      Aggregate       not-accessible  mandatory
+dot1dBasePortEntry   dot1dBasePortTable.1 Aggregate       not-accessible  mandatory
+dot1dBasePort        dot1dBasePortEntry.1 INTEGER         read-only       mandatory
+dot1dBasePortIfIndex dot1dBasePortEntry.2 INTEGER         read-only       mandatory
+dot1dBasePortCircuit dot1dBasePortEntry.3 ObjectID        read-only       mandatory
+dot1dBasePortDelayExceededDiscards dot1dBasePortEntry.4 Counter         read-only       mandatory
+dot1dBasePortMtuExceededDiscards dot1dBasePortEntry.5 Counter         read-only       mandatory
+dot1dStpProtocolSpecification dot1dStp.1       INTEGER         read-only       mandatory
+dot1dStpPriority     dot1dStp.2       INTEGER         read-write      mandatory
+dot1dStpTimeSinceTopologyChange dot1dStp.3       TimeTicks       read-only       mandatory
+dot1dStpTopChanges   dot1dStp.4       Counter         read-only       mandatory
+dot1dStpDesignatedRoot dot1dStp.5       OctetString     read-only       mandatory
+dot1dStpRootCost     dot1dStp.6       INTEGER         read-only       mandatory
+dot1dStpRootPort     dot1dStp.7       INTEGER         read-only       mandatory
+dot1dStpMaxAge       dot1dStp.8       INTEGER         read-only       mandatory
+dot1dStpHelloTime    dot1dStp.9       INTEGER         read-only       mandatory
+dot1dStpHoldTime     dot1dStp.10      INTEGER         read-only       mandatory
+dot1dStpForwardDelay dot1dStp.11      INTEGER         read-only       mandatory
+dot1dStpBridgeMaxAge dot1dStp.12      INTEGER         read-write      mandatory
+dot1dStpBridgeHelloTime dot1dStp.13      INTEGER         read-write      mandatory
+dot1dStpBridgeForwardDelay dot1dStp.14      INTEGER         read-write      mandatory
+dot1dStpPortTable    dot1dStp.15      Aggregate       not-accessible  mandatory
+dot1dStpPortEntry    dot1dStpPortTable.1 Aggregate       not-accessible  mandatory
+dot1dStpPort         dot1dStpPortEntry.1 INTEGER         read-only       mandatory
+dot1dStpPortPriority dot1dStpPortEntry.2 INTEGER         read-write      mandatory
+dot1dStpPortState    dot1dStpPortEntry.3 INTEGER         read-only       mandatory
+dot1dStpPortEnable   dot1dStpPortEntry.4 INTEGER         read-write      mandatory
+dot1dStpPortPathCost dot1dStpPortEntry.5 INTEGER         read-write      mandatory
+dot1dStpPortDesignatedRoot dot1dStpPortEntry.6 OctetString     read-only       mandatory
+dot1dStpPortDesignatedCost dot1dStpPortEntry.7 INTEGER         read-only       mandatory
+dot1dStpPortDesignatedBridge dot1dStpPortEntry.8 OctetString     read-only       mandatory
+dot1dStpPortDesignatedPort dot1dStpPortEntry.9 OctetString     read-only       mandatory
+dot1dStpPortForwardTransitions dot1dStpPortEntry.10 Counter         read-only       mandatory
+dot1dSrPortTable     dot1dSr.1        Aggregate       not-accessible  mandatory
+dot1dSrPortEntry     dot1dSrPortTable.1 Aggregate       not-accessible  mandatory
+dot1dSrPort          dot1dSrPortEntry.1 INTEGER         read-only       mandatory
+dot1dSrPortHopCount  dot1dSrPortEntry.2 INTEGER         read-write      mandatory
+dot1dSrPortLocalSegment dot1dSrPortEntry.3 INTEGER         read-write      mandatory
+dot1dSrPortBridgeNum dot1dSrPortEntry.4 INTEGER         read-write      mandatory
+dot1dSrPortTargetSegment dot1dSrPortEntry.5 INTEGER         read-write      mandatory
+dot1dSrPortLargestFrame dot1dSrPortEntry.6 INTEGER         read-write      mandatory
+dot1dSrPortSTESpanMode dot1dSrPortEntry.7 INTEGER         read-write      mandatory
+dot1dSrPortSpecInFrames dot1dSrPortEntry.8 Counter         read-only       mandatory
+dot1dSrPortSpecOutFrames dot1dSrPortEntry.9 Counter         read-only       mandatory
+dot1dSrPortApeInFrames dot1dSrPortEntry.10 Counter         read-only       mandatory
+dot1dSrPortApeOutFrames dot1dSrPortEntry.11 Counter         read-only       mandatory
+dot1dSrPortSteInFrames dot1dSrPortEntry.12 Counter         read-only       mandatory
+dot1dSrPortSteOutFrames dot1dSrPortEntry.13 Counter         read-only       mandatory
+dot1dSrPortSegmentMismatchDiscards dot1dSrPortEntry.14 Counter         read-only       mandatory
+dot1dSrPortDuplicateSegmentDiscards dot1dSrPortEntry.15 Counter         read-only       mandatory
+dot1dSrPortHopCountExceededDiscards dot1dSrPortEntry.16 Counter         read-only       mandatory
+dot1dTpLearnedEntryDiscards dot1dTp.1        Counter         read-only       mandatory
+dot1dTpAgingTime     dot1dTp.2        INTEGER         read-write      mandatory
+dot1dTpFdbTable      dot1dTp.3        Aggregate       not-accessible  mandatory
+dot1dTpFdbEntry      dot1dTpFdbTable.1 Aggregate       not-accessible  mandatory
+dot1dTpFdbAddress    dot1dTpFdbEntry.1 OctetString     read-only       mandatory
+dot1dTpFdbPort       dot1dTpFdbEntry.2 INTEGER         read-only       mandatory
+dot1dTpFdbStatus     dot1dTpFdbEntry.3 INTEGER         read-only       mandatory
+dot1dTpPortTable     dot1dTp.4        Aggregate       not-accessible  mandatory
+dot1dTpPortEntry     dot1dTpPortTable.1 Aggregate       not-accessible  mandatory
+dot1dTpPort          dot1dTpPortEntry.1 INTEGER         read-only       mandatory
+dot1dTpPortMaxInfo   dot1dTpPortEntry.2 INTEGER         read-only       mandatory
+dot1dTpPortInFrames  dot1dTpPortEntry.3 Counter         read-only       mandatory
+dot1dTpPortOutFrames dot1dTpPortEntry.4 Counter         read-only       mandatory
+dot1dTpPortInDiscards dot1dTpPortEntry.5 Counter         read-only       mandatory
+dot1dStaticTable     dot1dStatic.1    Aggregate       not-accessible  mandatory
+dot1dStaticEntry     dot1dStaticTable.1 Aggregate       not-accessible  mandatory
+dot1dStaticAddress   dot1dStaticEntry.1 OctetString     read-write      mandatory
+dot1dStaticReceivePort dot1dStaticEntry.2 INTEGER         read-write      mandatory
+dot1dStaticAllowedToGoTo dot1dStaticEntry.3 OctetString     read-write      mandatory
+dot1dStaticStatus    dot1dStaticEntry.4 INTEGER         read-write      mandatory
+
+
+-- automatically generated by mosy 7.0 #62 (dbc), do not edit!
+
+-- object definitions compiled from RFCxxxx-MIB
+
+dot3                 experimental.3
+dot3Errors           dot3.7
+dot3ErrorInitError   dot3Errors.1
+dot3ErrorLoopbackError dot3Errors.2
+dot3Tests            dot3.6
+dot3TestTdr          dot3Tests.1
+dot3ChipSets         dot3.8
+dot3ChipSetAMD       dot3ChipSets.1
+dot3ChipSetAMD7990   dot3ChipSetAMD.1
+dot3ChipSetAMD79900  dot3ChipSetAMD.2
+dot3ChipSetIntel     dot3ChipSets.2
+dot3ChipSetIntel82586 dot3ChipSetIntel.1
+dot3ChipSetIntel82596 dot3ChipSetIntel.2
+dot3ChipSetSeeq      dot3ChipSets.3
+dot3ChipSetSeeq8003  dot3ChipSetSeeq.1
+dot3ChipSetNational  dot3ChipSets.4
+dot3ChipSetNational8390 dot3ChipSetNational.1
+dot3ChipSetNationalSonic dot3ChipSetNational.2
+dot3ChipSetFujitsu   dot3ChipSets.5
+dot3ChipSetFujitsu86950 dot3ChipSetFujitsu.1
+
+dot3Table            dot3.1           Aggregate       not-accessible  mandatory
+dot3Entry            dot3Table.1      Aggregate       not-accessible  mandatory
+dot3Index            dot3Entry.1      INTEGER         read-only       mandatory
+dot3InitializeMac    dot3Entry.2      INTEGER         read-write      mandatory
+dot3MacSubLayerStatus dot3Entry.3      INTEGER         read-write      mandatory
+dot3MulticastReceiveStatus dot3Entry.4      INTEGER         read-write      mandatory
+dot3TxEnabled        dot3Entry.5      INTEGER         read-write      mandatory
+dot3TestTdrValue     dot3Entry.6      Gauge           read-only       mandatory
+dot3StatsTable       dot3.2           Aggregate       not-accessible  mandatory
+dot3StatsEntry       dot3StatsTable.1 Aggregate       not-accessible  mandatory
+dot3StatsIndex       dot3StatsEntry.1 INTEGER         read-only       mandatory
+dot3StatsAlignmentErrors dot3StatsEntry.2 Counter         read-only       mandatory
+dot3StatsFCSErrors   dot3StatsEntry.3 Counter         read-only       mandatory
+dot3StatsSingleCollisionFrames dot3StatsEntry.4 Counter         read-only       mandatory
+dot3StatsMultipleCollisionFrames dot3StatsEntry.5 Counter         read-only       mandatory
+dot3StatsSQETestErrors dot3StatsEntry.6 Counter         read-only       mandatory
+dot3StatsDeferredTransmissions dot3StatsEntry.7 Counter         read-only       mandatory
+dot3StatsLateCollisions dot3StatsEntry.8 Counter         read-only       mandatory
+dot3StatsExcessiveCollisions dot3StatsEntry.9 Counter         read-only       mandatory
+dot3StatsInternalMacTransmitErrors dot3StatsEntry.10 Counter         read-only       mandatory
+dot3StatsCarrierSenseErrors dot3StatsEntry.11 Counter         read-only       mandatory
+dot3StatsExcessiveDeferrals dot3StatsEntry.12 Counter         read-only       mandatory
+dot3StatsFrameTooLongs dot3StatsEntry.13 Counter         read-only       mandatory
+dot3StatsInRangeLengthErrors dot3StatsEntry.14 Counter         read-only       mandatory
+dot3StatsOutOfRangeLengthFields dot3StatsEntry.15 Counter         read-only       mandatory
+dot3StatsInternalMacReceiveErrors dot3StatsEntry.16 Counter         read-only       mandatory
+dot3CollTable        dot3.5           Aggregate       not-accessible  mandatory
+dot3CollEntry        dot3CollTable.1  Aggregate       not-accessible  mandatory
+dot3CollIndex        dot3CollEntry.1  INTEGER         read-only       mandatory
+dot3CollCount        dot3CollEntry.2  INTEGER         read-only       mandatory
+dot3CollFrequency    dot3CollEntry.3  Counter         read-only       mandatory
+
+
+-- automatically generated by mosy 7.0 #62 (dbc), do not edit!
+
+-- object definitions compiled from RFC1231-MIB
+
+dot5                 transmission.9
+dot5Tests            dot5.3
+testInsertFunc       dot5Tests.1
+dot5ChipSets         dot5.4
+chipSetIBM16         dot5ChipSets.1
+chipSetTItms380      dot5ChipSets.2
+chipSetTItms380c16   dot5ChipSets.3
+
+dot5Table            dot5.1           Aggregate       not-accessible  mandatory
+dot5Entry            dot5Table.1      Aggregate       not-accessible  mandatory
+dot5IfIndex          dot5Entry.1      INTEGER         read-only       mandatory
+dot5Commands         dot5Entry.2      INTEGER         read-write      mandatory
+dot5RingStatus       dot5Entry.3      INTEGER         read-only       mandatory
+dot5RingState        dot5Entry.4      INTEGER         read-only       mandatory
+dot5RingOpenStatus   dot5Entry.5      INTEGER         read-only       mandatory
+dot5RingSpeed        dot5Entry.6      INTEGER         read-write      mandatory
+dot5UpStream         dot5Entry.7      OctetString     read-only       mandatory
+dot5ActMonParticipate dot5Entry.8      INTEGER         read-write      mandatory
+dot5Functional       dot5Entry.9      OctetString     read-write      mandatory
+dot5StatsTable       dot5.2           Aggregate       not-accessible  mandatory
+dot5StatsEntry       dot5StatsTable.1 Aggregate       not-accessible  mandatory
+dot5StatsIfIndex     dot5StatsEntry.1 INTEGER         read-only       mandatory
+dot5StatsLineErrors  dot5StatsEntry.2 Counter         read-only       mandatory
+dot5StatsBurstErrors dot5StatsEntry.3 Counter         read-only       mandatory
+dot5StatsACErrors    dot5StatsEntry.4 Counter         read-only       mandatory
+dot5StatsAbortTransErrors dot5StatsEntry.5 Counter         read-only       mandatory
+dot5StatsInternalErrors dot5StatsEntry.6 Counter         read-only       mandatory
+dot5StatsLostFrameErrors dot5StatsEntry.7 Counter         read-only       mandatory
+dot5StatsReceiveCongestions dot5StatsEntry.8 Counter         read-only       mandatory
+dot5StatsFrameCopiedErrors dot5StatsEntry.9 Counter         read-only       mandatory
+dot5StatsTokenErrors dot5StatsEntry.10 Counter         read-only       mandatory
+dot5StatsSoftErrors  dot5StatsEntry.11 Counter         read-only       mandatory
+dot5StatsHardErrors  dot5StatsEntry.12 Counter         read-only       mandatory
+dot5StatsSignalLoss  dot5StatsEntry.13 Counter         read-only       mandatory
+dot5StatsTransmitBeacons dot5StatsEntry.14 Counter         read-only       mandatory
+dot5StatsRecoverys   dot5StatsEntry.15 Counter         read-only       mandatory
+dot5StatsLobeWires   dot5StatsEntry.16 Counter         read-only       mandatory
+dot5StatsRemoves     dot5StatsEntry.17 Counter         read-only       mandatory
+dot5StatsSingles     dot5StatsEntry.18 Counter         read-only       mandatory
+dot5StatsFreqErrors  dot5StatsEntry.19 Counter         read-only       optional
+dot5TimerTable       dot5.5           Aggregate       not-accessible  mandatory
+dot5TimerEntry       dot5TimerTable.1 Aggregate       not-accessible  mandatory
+dot5TimerIfIndex     dot5TimerEntry.1 INTEGER         read-only       mandatory
+dot5TimerReturnRepeat dot5TimerEntry.2 INTEGER         read-only       mandatory
+dot5TimerHolding     dot5TimerEntry.3 INTEGER         read-only       mandatory
+dot5TimerQueuePDU    dot5TimerEntry.4 INTEGER         read-only       mandatory
+dot5TimerValidTransmit dot5TimerEntry.5 INTEGER         read-only       mandatory
+dot5TimerNoToken     dot5TimerEntry.6 INTEGER         read-only       mandatory
+dot5TimerActiveMon   dot5TimerEntry.7 INTEGER         read-only       mandatory
+dot5TimerStandbyMon  dot5TimerEntry.8 INTEGER         read-only       mandatory
+dot5TimerErrorReport dot5TimerEntry.9 INTEGER         read-only       mandatory
+dot5TimerBeaconTransmit dot5TimerEntry.10 INTEGER         read-only       mandatory
+dot5TimerBeaconReceive dot5TimerEntry.11 INTEGER         read-only       mandatory
+
+
+-- automatically generated by mosy 7.0 #62 (dbc), do not edit!
+
+-- object definitions compiled from RFC1230-MIB
+
+dot4                 transmission.8
+dot4Tests            dot4.5
+dot4Errors           dot4.4
+dot4ModemInitFailed  dot4Errors.1
+testFifoPath         dot4Tests.1
+testExternalLoopback dot4Tests.2
+dot4ChipSets         dot4.6
+chipSetMc68824       dot4ChipSets.1
+
+dot4Table            dot4.1           Aggregate       not-accessible  mandatory
+dot4Entry            dot4Table.1      Aggregate       not-accessible  mandatory
+dot4IfIndex          dot4Entry.1      INTEGER         read-only       mandatory
+dot4Options          dot4Entry.2      INTEGER         read-only       mandatory
+dot4State            dot4Entry.3      INTEGER         read-only       mandatory
+dot4Commands         dot4Entry.4      INTEGER         read-write      mandatory
+dot4MacAddrLen       dot4Entry.5      INTEGER         read-only       mandatory
+dot4NextStation      dot4Entry.6      OctetString     read-only       mandatory
+dot4PreviousStation  dot4Entry.7      OctetString     read-only       mandatory
+dot4SlotTime         dot4Entry.8      INTEGER         read-only       mandatory
+dot4LastTokenRotTime dot4Entry.9      INTEGER         read-only       mandatory
+dot4HiPriTokenHoldTime dot4Entry.10     INTEGER         read-only       mandatory
+dot4TargetRotTimeClass4 dot4Entry.11     INTEGER         read-only       mandatory
+dot4TargetRotTimeClass2 dot4Entry.12     INTEGER         read-only       mandatory
+dot4TargetRotTimeClass0 dot4Entry.13     INTEGER         read-only       mandatory
+dot4TargetRotTimeRingMaint dot4Entry.14     INTEGER         read-only       mandatory
+dot4RingMaintTimerInitValue dot4Entry.15     INTEGER         read-only       mandatory
+dot4MaxInterSolicitCount dot4Entry.16     INTEGER         read-only       mandatory
+dot4MaxRetries       dot4Entry.17     INTEGER         read-only       mandatory
+dot4MinPostSilencePreambLen dot4Entry.18     INTEGER         read-only       mandatory
+dot4StandardRevision dot4Entry.19     INTEGER         read-only       mandatory
+dot4InitTable        dot4.2           Aggregate       not-accessible  mandatory
+dot4InitEntry        dot4InitTable.1  Aggregate       not-accessible  mandatory
+dot4InitIfIndex      dot4InitEntry.1  INTEGER         read-only       mandatory
+dot4InitSlotTime     dot4InitEntry.2  INTEGER         read-write      mandatory
+dot4InitMaxInterSolicitCount dot4InitEntry.3  INTEGER         read-write      mandatory
+dot4InitMaxRetries   dot4InitEntry.4  INTEGER         read-write      mandatory
+dot4InitHiPriTokenHoldTime dot4InitEntry.5  INTEGER         read-write      mandatory
+dot4InitTargetRotTimeClass4 dot4InitEntry.6  INTEGER         read-write      mandatory
+dot4InitTargetRotTimeClass2 dot4InitEntry.7  INTEGER         read-write      mandatory
+dot4InitTargetRotTimeClass0 dot4InitEntry.8  INTEGER         read-write      mandatory
+dot4InitTargetRotTimeRingMaint dot4InitEntry.9  INTEGER         read-write      mandatory
+dot4InitRingMaintTimerInitValue dot4InitEntry.10 INTEGER         read-write      mandatory
+dot4InitMinPostSilencePreambLen dot4InitEntry.11 INTEGER         read-write      mandatory
+dot4InitInRingDesired dot4InitEntry.12 INTEGER         read-write      mandatory
+dot4StatsTable       dot4.3           Aggregate       not-accessible  mandatory
+dot4StatsEntry       dot4StatsTable.1 Aggregate       not-accessible  mandatory
+dot4StatsIfIndex     dot4StatsEntry.1 INTEGER         read-only       mandatory
+dot4StatsTokenPasses dot4StatsEntry.2 Counter         read-only       optional
+dot4StatsTokenHeards dot4StatsEntry.3 Counter         read-only       optional
+dot4StatsNoSuccessors dot4StatsEntry.4 Counter         read-only       mandatory
+dot4StatsWhoFollows  dot4StatsEntry.5 Counter         read-only       mandatory
+dot4StatsTokenPassFails dot4StatsEntry.6 Counter         read-only       mandatory
+dot4StatsNonSilences dot4StatsEntry.7 Counter         read-only       mandatory
+dot4StatsFcsErrors   dot4StatsEntry.8 Counter         read-only       mandatory
+dot4StatsEbitErrors  dot4StatsEntry.9 Counter         read-only       mandatory
+dot4StatsFrameFrags  dot4StatsEntry.10 Counter         read-only       mandatory
+dot4StatsFrameTooLongs dot4StatsEntry.11 Counter         read-only       mandatory
+dot4StatsOverRuns    dot4StatsEntry.12 Counter         read-only       mandatory
+dot4StatsDupAddresses dot4StatsEntry.13 Counter         read-only       mandatory
+
+
 -- automatically generated by mosy 7.0 #62 (dbc), do not edit!
 
 -- object definitions compiled from RFC1232-MIB
@@ -895,39 +1419,68 @@
 viewTranType         viewTranEntry.5  INTEGER         read-write      mandatory
 
 
--- automatically generated by mosy 7.0 #65 (dbc), do not edit!
-
--- object definitions compiled from RFC1269-MIB
+-- automatically generated by mosy 7.0 #62 (dbc), do not edit!
 
-bgp                  mib-2.15
+-- object definitions compiled from RFCxxxx-MIB
 
-bgpVersion           bgp.1            OctetString     read-only       mandatory
-bgpLocalAs           bgp.2            INTEGER         read-only       mandatory
-bgpPeerTable         bgp.3            Aggregate       not-accessible  mandatory
-bgpIdentifier        bgp.4            IpAddress       read-only       mandatory
-bgpPeerEntry         bgpPeerTable.1   Aggregate       not-accessible  mandatory
-bgpPeerIdentifier    bgpPeerEntry.1   IpAddress       read-only       mandatory
-bgpPeerState         bgpPeerEntry.2   INTEGER         read-only       mandatory
-bgpPeerAdminStatus   bgpPeerEntry.3   INTEGER         read-write      mandatory
-bgpPeerNegotiatedVersion bgpPeerEntry.4   INTEGER         read-only       mandatory
-bgpPeerLocalAddr     bgpPeerEntry.5   IpAddress       read-only       mandatory
-bgpPeerLocalPort     bgpPeerEntry.6   INTEGER         read-only       mandatory
-bgpPeerRemoteAddr    bgpPeerEntry.7   IpAddress       read-only       mandatory
-bgpPeerRemotePort    bgpPeerEntry.8   INTEGER         read-only       mandatory
-bgpPeerRemoteAs      bgpPeerEntry.9   INTEGER         read-only       mandatory
-bgpPeerInUpdates     bgpPeerEntry.10  Counter         read-only       mandatory
-bgpPeerOutUpdates    bgpPeerEntry.11  Counter         read-only       mandatory
-bgpPeerInTotalMessages bgpPeerEntry.12  Counter         read-only       mandatory
-bgpPeerOutTotalMessages bgpPeerEntry.13  Counter         read-only       mandatory
-bgpPeerLastError     bgpPeerEntry.14  OctetString     read-only       mandatory
-bgpRcvdPathAttrTable bgp.5            Aggregate       not-accessible  mandatory
-bgpPathAttrEntry     bgpRcvdPathAttrTable.1 Aggregate       not-accessible  mandatory
-bgpPathAttrPeer      bgpPathAttrEntry.1 IpAddress       read-only       mandatory
-bgpPathAttrDestNetwork bgpPathAttrEntry.2 IpAddress       read-only       mandatory
-bgpPathAttrOrigin    bgpPathAttrEntry.3 INTEGER         read-only       mandatory
-bgpPathAttrASPath    bgpPathAttrEntry.4 OctetString     read-only       mandatory
-bgpPathAttrNextHop   bgpPathAttrEntry.5 IpAddress       read-only       mandatory
-bgpPathAttrInterASMetric bgpPathAttrEntry.6 IpAddress       read-only       mandatory
+sip                  experimental.16
+sipPLCP              sip.3
+smdsApplications     sip.4
+ipOverSMDS           smdsApplications.1
+smdsCarrierSelection sip.5
+sipErrorLog          sip.6
+
+sipL3Table           sip.1            Aggregate       not-accessible  mandatory
+sipL3Entry           sipL3Table.1     Aggregate       not-accessible  mandatory
+sipL3Index           sipL3Entry.1     INTEGER         read-only       mandatory
+receivedIndividualDAedSIPL3PDUs sipL3Entry.2     Counter         read-only       mandatory
+receivedGAedSIPL3PDUs sipL3Entry.3     Counter         read-only       mandatory
+sentIndividualDAedSIPL3PDUs sipL3Entry.4     Counter         read-only       mandatory
+sentGAedSIPL3PDUs    sipL3Entry.5     Counter         read-only       mandatory
+erroredSIPL3PDUs     sipL3Entry.6     Counter         read-only       mandatory
+unrecognizedDestinationAddresses sipL3Entry.7     Counter         read-only       mandatory
+unrecognizedGroupAddresses sipL3Entry.8     Counter         read-only       mandatory
+invalidSMDSAddressTypes sipL3Entry.9     Counter         read-only       mandatory
+versionSupport       sipL3Entry.10    INTEGER         read-only       mandatory
+sipL2Table           sip.2            Aggregate       not-accessible  mandatory
+sipL2Entry           sipL2Table.1     Aggregate       not-accessible  mandatory
+sipL2Index           sipL2Entry.1     INTEGER         read-only       mandatory
+receivedSIPL2PDUs    sipL2Entry.2     Counter         read-only       mandatory
+sentSIPL2PDUs        sipL2Entry.3     Counter         read-only       mandatory
+hcsOrCRCErrors       sipL2Entry.4     Counter         read-only       mandatory
+payloadLengthErrors  sipL2Entry.5     Counter         read-only       mandatory
+sequenceNumberErrors sipL2Entry.6     Counter         read-only       mandatory
+midCurrentlyActiveErrors sipL2Entry.7     Counter         read-only       mandatory
+bomOrSSMsMIDErrors   sipL2Entry.8     Counter         read-only       mandatory
+eomsMIDErrors        sipL2Entry.9     Counter         read-only       mandatory
+sipDS1PLCPTable      sipPLCP.1        Aggregate       not-accessible  mandatory
+sipDS1PLCPEntry      sipDS1PLCPTable.1 Aggregate       not-accessible  mandatory
+sipDS1PLCPIndex      sipDS1PLCPEntry.1 INTEGER         read-only       mandatory
+ds1PLCPSEFSs         sipDS1PLCPEntry.2 Counter         read-only       mandatory
+ds1PLCPYellowSignal  sipDS1PLCPEntry.3 INTEGER         read-only       mandatory
+ds1PLCPRedAlarm      sipDS1PLCPEntry.4 INTEGER         read-only       mandatory
+ds1PLCPUASs          sipDS1PLCPEntry.5 Counter         read-only       mandatory
+sipDS3PLCPTable      sipPLCP.2        Aggregate       not-accessible  mandatory
+sipDS3PLCPEntry      sipDS3PLCPTable.1 Aggregate       not-accessible  mandatory
+sipDS3PLCPIndex      sipDS3PLCPEntry.1 INTEGER         read-only       mandatory
+ds3PLCPSEFSs         sipDS3PLCPEntry.2 Counter         read-only       mandatory
+ds3PLCPYellowSignal  sipDS3PLCPEntry.3 INTEGER         read-only       mandatory
+ds3PLCPRedAlarm      sipDS3PLCPEntry.4 INTEGER         read-only       mandatory
+ds3PLCPUASs          sipDS3PLCPEntry.5 Counter         read-only       mandatory
+ipOverSMDSAddressTable ipOverSMDS.1     Aggregate       not-accessible  mandatory
+ipOverSMDSAddressEntry ipOverSMDSAddressTable.1 Aggregate       not-accessible  mandatory
+ipEntryAddressIfIndex ipOverSMDSAddressEntry.1 INTEGER         read-only       mandatory
+ipEntryAddress       ipOverSMDSAddressEntry.2 IpAddress       read-only       mandatory
+smdsHA               ipOverSMDSAddressEntry.3 OctetString     read-only       mandatory
+smdsLISGA            ipOverSMDSAddressEntry.4 OctetString     read-only       mandatory
+smdsARPReq           ipOverSMDSAddressEntry.5 OctetString     read-only       mandatory
+sipL3PDUErrorTable   sipErrorLog.1    Aggregate       not-accessible  mandatory
+sipL3PDUErrorEntry   sipL3PDUErrorTable.1 Aggregate       not-accessible  mandatory
+sipL3PDUErrorIndex   sipL3PDUErrorEntry.1 INTEGER         read-only       mandatory
+sipL3PDUErrorType    sipL3PDUErrorEntry.2 INTEGER         read-only       mandatory
+erroredL3PDUSourceAddress sipL3PDUErrorEntry.3 OctetString     read-only       mandatory
+erroredL3PDUDestinationAddress sipL3PDUErrorEntry.4 OctetString     read-only       mandatory
+sipL3PDUErrorTimeStamp sipL3PDUErrorEntry.5 TimeTicks       read-only       mandatory
 
 
 -- automatically generated by mosy 7.0 #62 (dbc), do not edit!
@@ -1148,6 +1701,33 @@
 
 -- object definitions compiled from RFCxxxx-MIB
 
+para                 experimental.21
+
+paraNumber           para.1           INTEGER         read-only       mandatory
+paraPortTable        para.2           Aggregate       not-accessible  mandatory
+paraPortEntry        paraPortTable.1  Aggregate       not-accessible  mandatory
+paraPortIndex        paraPortEntry.1  INTEGER         read-only       mandatory
+paraPortType         paraPortEntry.2  INTEGER         read-only       mandatory
+paraPortInSigNumber  paraPortEntry.3  INTEGER         read-only       mandatory
+paraPortOutSigNumber paraPortEntry.4  INTEGER         read-only       mandatory
+paraInSigTable       para.3           Aggregate       not-accessible  mandatory
+paraInSigEntry       paraInSigTable.1 Aggregate       not-accessible  mandatory
+paraInSigPortIndex   paraInSigEntry.1 INTEGER         read-only       mandatory
+paraInSigName        paraInSigEntry.2 INTEGER         read-only       mandatory
+paraInSigState       paraInSigEntry.3 INTEGER         read-only       mandatory
+paraInSigChanges     paraInSigEntry.4 Counter         read-only       mandatory
+paraOutSigTable      para.4           Aggregate       not-accessible  mandatory
+paraOutSigEntry      paraOutSigTable.1 Aggregate       not-accessible  mandatory
+paraOutSigPortIndex  paraOutSigEntry.1 INTEGER         read-only       mandatory
+paraOutSigName       paraOutSigEntry.2 INTEGER         read-only       mandatory
+paraOutSigState      paraOutSigEntry.3 INTEGER         read-only       mandatory
+paraOutSigChanges    paraOutSigEntry.4 Counter         read-only       mandatory
+
+
+-- automatically generated by mosy 7.0 #62 (dbc), do not edit!
+
+-- object definitions compiled from RFCxxxx-MIB
+
 frame-relay          experimental.26
 
 frDlcmiTable         frame-relay.1    Aggregate       not-accessible  mandatory
@@ -1186,226 +1766,6 @@
 frErrTime            frErrEntry.4     TimeTicks       read-only       mandatory
 
 
--- automatically generated by mosy 7.0 #65 (dbc), do not edit!
-
--- object definitions compiled from RFC1271-MIB
-
-rmon                 mib-2.16
-statistics           rmon.1
-history              rmon.2
-alarm                rmon.3
-hosts                rmon.4
-hostTopN             rmon.5
-matrix               rmon.6
-filter               rmon.7
-capture              rmon.8
-event                rmon.9
-
-etherStatsTable      statistics.1     Aggregate       not-accessible  mandatory
-etherStatsEntry      etherStatsTable.1 Aggregate       not-accessible  mandatory
-etherStatsIndex      etherStatsEntry.1 INTEGER         read-only       mandatory
-etherStatsDataSource etherStatsEntry.2 ObjectID        read-write      mandatory
-etherStatsDropEvents etherStatsEntry.3 Counter         read-only       mandatory
-etherStatsOctets     etherStatsEntry.4 Counter         read-only       mandatory
-etherStatsPkts       etherStatsEntry.5 Counter         read-only       mandatory
-etherStatsBroadcastPkts etherStatsEntry.6 Counter         read-only       mandatory
-etherStatsMulticastPkts etherStatsEntry.7 Counter         read-only       mandatory
-etherStatsCRCAlignErrors etherStatsEntry.8 Counter         read-only       mandatory
-etherStatsUndersizePkts etherStatsEntry.9 Counter         read-only       mandatory
-etherStatsOversizePkts etherStatsEntry.10 Counter         read-only       mandatory
-etherStatsFragments  etherStatsEntry.11 Counter         read-only       mandatory
-etherStatsJabbers    etherStatsEntry.12 Counter         read-only       mandatory
-etherStatsCollisions etherStatsEntry.13 Counter         read-only       mandatory
-etherStatsPkts64Octets etherStatsEntry.14 Counter         read-only       mandatory
-etherStatsPkts65to127Octets etherStatsEntry.15 Counter         read-only       mandatory
-etherStatsPkts128to255Octets etherStatsEntry.16 Counter         read-only       mandatory
-etherStatsPkts256to511Octets etherStatsEntry.17 Counter         read-only       mandatory
-etherStatsPkts512to1023Octets etherStatsEntry.18 Counter         read-only       mandatory
-etherStatsPkts1024to1518Octets etherStatsEntry.19 Counter         read-only       mandatory
-etherStatsOwner      etherStatsEntry.20 DisplayString   read-write      mandatory
-etherStatsStatus     etherStatsEntry.21 INTEGER         read-write      mandatory
-historyControlTable  history.1        Aggregate       not-accessible  mandatory
-historyControlEntry  historyControlTable.1 Aggregate       not-accessible  mandatory
-historyControlIndex  historyControlEntry.1 INTEGER         read-only       mandatory
-historyControlDataSource historyControlEntry.2 ObjectID        read-write      mandatory
-historyControlBucketsRequested historyControlEntry.3 INTEGER         read-write      mandatory
-historyControlBucketsGranted historyControlEntry.4 INTEGER         read-only       mandatory
-historyControlInterval historyControlEntry.5 INTEGER         read-write      mandatory
-historyControlOwner  historyControlEntry.6 DisplayString   read-write      mandatory
-historyControlStatus historyControlEntry.7 INTEGER         read-write      mandatory
-etherHistoryTable    history.2        Aggregate       not-accessible  mandatory
-etherHistoryEntry    etherHistoryTable.1 Aggregate       not-accessible  mandatory
-etherHistoryIndex    etherHistoryEntry.1 INTEGER         read-only       mandatory
-etherHistorySampleIndex etherHistoryEntry.2 INTEGER         read-only       mandatory
-etherHistoryIntervalStart etherHistoryEntry.3 TimeTicks       read-only       mandatory
-etherHistoryDropEvents etherHistoryEntry.4 Counter         read-only       mandatory
-etherHistoryOctets   etherHistoryEntry.5 Counter         read-only       mandatory
-etherHistoryPkts     etherHistoryEntry.6 Counter         read-only       mandatory
-etherHistoryBroadcastPkts etherHistoryEntry.7 Counter         read-only       mandatory
-etherHistoryMulticastPkts etherHistoryEntry.8 Counter         read-only       mandatory
-etherHistoryCRCAlignErrors etherHistoryEntry.9 Counter         read-only       mandatory
-etherHistoryUndersizePkts etherHistoryEntry.10 Counter         read-only       mandatory
-etherHistoryOversizePkts etherHistoryEntry.11 Counter         read-only       mandatory
-etherHistoryFragments etherHistoryEntry.12 Counter         read-only       mandatory
-etherHistoryJabbers  etherHistoryEntry.13 Counter         read-only       mandatory
-etherHistoryCollisions etherHistoryEntry.14 Counter         read-only       mandatory
-etherHistoryUtilization etherHistoryEntry.15 INTEGER         read-only       mandatory
-alarmTable           alarm.1          Aggregate       not-accessible  mandatory
-alarmEntry           alarmTable.1     Aggregate       not-accessible  mandatory
-alarmIndex           alarmEntry.1     INTEGER         read-only       mandatory
-alarmInterval        alarmEntry.2     INTEGER         read-write      mandatory
-alarmVariable        alarmEntry.3     ObjectID        read-write      mandatory
-alarmSampleType      alarmEntry.4     INTEGER         read-write      mandatory
-alarmValue           alarmEntry.5     INTEGER         read-only       mandatory
-alarmStartupAlarm    alarmEntry.6     INTEGER         read-write      mandatory
-alarmRisingThreshold alarmEntry.7     INTEGER         read-write      mandatory
-alarmFallingThreshold alarmEntry.8     INTEGER         read-write      mandatory
-alarmRisingEventIndex alarmEntry.9     INTEGER         read-write      mandatory
-alarmFallingEventIndex alarmEntry.10    INTEGER         read-write      mandatory
-alarmOwner           alarmEntry.11    DisplayString   read-write      mandatory
-alarmStatus          alarmEntry.12    INTEGER         read-write      mandatory
-hostControlTable     hosts.1          Aggregate       not-accessible  mandatory
-hostControlEntry     hostControlTable.1 Aggregate       not-accessible  mandatory
-hostControlIndex     hostControlEntry.1 INTEGER         read-only       mandatory
-hostControlDataSource hostControlEntry.2 ObjectID        read-write      mandatory
-hostControlTableSize hostControlEntry.3 INTEGER         read-only       mandatory
-hostControlLastDeleteTime hostControlEntry.4 TimeTicks       read-only       mandatory
-hostControlOwner     hostControlEntry.5 DisplayString   read-write      mandatory
-hostControlStatus    hostControlEntry.6 INTEGER         read-write      mandatory
-hostTable            hosts.2          Aggregate       not-accessible  mandatory
-hostEntry            hostTable.1      Aggregate       not-accessible  mandatory
-hostAddress          hostEntry.1      OctetString     read-only       mandatory
-hostCreationOrder    hostEntry.2      INTEGER         read-only       mandatory
-hostIndex            hostEntry.3      INTEGER         read-only       mandatory
-hostInPkts           hostEntry.4      Counter         read-only       mandatory
-hostOutPkts          hostEntry.5      Counter         read-only       mandatory
-hostInOctets         hostEntry.6      Counter         read-only       mandatory
-hostOutOctets        hostEntry.7      Counter         read-only       mandatory
-hostOutErrors        hostEntry.8      Counter         read-only       mandatory
-hostOutBroadcastPkts hostEntry.9      Counter         read-only       mandatory
-hostOutMulticastPkts hostEntry.10     Counter         read-only       mandatory
-hostTimeTable        hosts.3          Aggregate       not-accessible  mandatory
-hostTimeEntry        hostTimeTable.1  Aggregate       not-accessible  mandatory
-hostTimeAddress      hostTimeEntry.1  OctetString     read-only       mandatory
-hostTimeCreationOrder hostTimeEntry.2  INTEGER         read-only       mandatory
-hostTimeIndex        hostTimeEntry.3  INTEGER         read-only       mandatory
-hostTimeInPkts       hostTimeEntry.4  Counter         read-only       mandatory
-hostTimeOutPkts      hostTimeEntry.5  Counter         read-only       mandatory
-hostTimeInOctets     hostTimeEntry.6  Counter         read-only       mandatory
-hostTimeOutOctets    hostTimeEntry.7  Counter         read-only       mandatory
-hostTimeOutErrors    hostTimeEntry.8  Counter         read-only       mandatory
-hostTimeOutBroadcastPkts hostTimeEntry.9  Counter         read-only       mandatory
-hostTimeOutMulticastPkts hostTimeEntry.10 Counter         read-only       mandatory
-hostTopNControlTable hostTopN.1       Aggregate       not-accessible  mandatory
-hostTopNControlEntry hostTopNControlTable.1 Aggregate       not-accessible  mandatory
-hostTopNControlIndex hostTopNControlEntry.1 INTEGER         read-only       mandatory
-hostTopNHostIndex    hostTopNControlEntry.2 INTEGER         read-write      mandatory
-hostTopNRateBase     hostTopNControlEntry.3 INTEGER         read-write      mandatory
-hostTopNTimeRemaining hostTopNControlEntry.4 INTEGER         read-write      mandatory
-hostTopNDuration     hostTopNControlEntry.5 INTEGER         read-only       mandatory
-hostTopNRequestedSize hostTopNControlEntry.6 INTEGER         read-write      mandatory
-hostTopNGrantedSize  hostTopNControlEntry.7 INTEGER         read-only       mandatory
-hostTopNStartTime    hostTopNControlEntry.8 TimeTicks       read-only       mandatory
-hostTopNOwner        hostTopNControlEntry.9 DisplayString   read-write      mandatory
-hostTopNStatus       hostTopNControlEntry.10 INTEGER         read-write      mandatory
-hostTopNTable        hostTopN.2       Aggregate       not-accessible  mandatory
-hostTopNEntry        hostTopNTable.1  Aggregate       not-accessible  mandatory
-hostTopNReport       hostTopNEntry.1  INTEGER         read-only       mandatory
-hostTopNIndex        hostTopNEntry.2  INTEGER         read-only       mandatory
-hostTopNAddress      hostTopNEntry.3  OctetString     read-only       mandatory
-hostTopNRate         hostTopNEntry.4  INTEGER         read-only       mandatory
-matrixControlTable   matrix.1         Aggregate       not-accessible  mandatory
-matrixControlEntry   matrixControlTable.1 Aggregate       not-accessible  mandatory
-matrixControlIndex   matrixControlEntry.1 INTEGER         read-only       mandatory
-matrixControlDataSource matrixControlEntry.2 ObjectID        read-write      mandatory
-matrixControlTableSize matrixControlEntry.3 INTEGER         read-only       mandatory
-matrixControlLastDeleteTime matrixControlEntry.4 TimeTicks       read-only       mandatory
-matrixControlOwner   matrixControlEntry.5 DisplayString   read-write      mandatory
-matrixControlStatus  matrixControlEntry.6 INTEGER         read-write      mandatory
-matrixSDTable        matrix.2         Aggregate       not-accessible  mandatory
-matrixSDEntry        matrixSDTable.1  Aggregate       not-accessible  mandatory
-matrixSDSourceAddress matrixSDEntry.1  OctetString     read-only       mandatory
-matrixSDDestAddress  matrixSDEntry.2  OctetString     read-only       mandatory
-matrixSDIndex        matrixSDEntry.3  INTEGER         read-only       mandatory
-matrixSDPkts         matrixSDEntry.4  Counter         read-only       mandatory
-matrixSDOctets       matrixSDEntry.5  Counter         read-only       mandatory
-matrixSDErrors       matrixSDEntry.6  Counter         read-only       mandatory
-matrixDSTable        matrix.3         Aggregate       not-accessible  mandatory
-matrixDSEntry        matrixDSTable.1  Aggregate       not-accessible  mandatory
-matrixDSSourceAddress matrixDSEntry.1  OctetString     read-only       mandatory
-matrixDSDestAddress  matrixDSEntry.2  OctetString     read-only       mandatory
-matrixDSIndex        matrixDSEntry.3  INTEGER         read-only       mandatory
-matrixDSPkts         matrixDSEntry.4  Counter         read-only       mandatory
-matrixDSOctets       matrixDSEntry.5  Counter         read-only       mandatory
-matrixDSErrors       matrixDSEntry.6  Counter         read-only       mandatory
-filterTable          filter.1         Aggregate       not-accessible  mandatory
-filterEntry          filterTable.1    Aggregate       not-accessible  mandatory
-filterIndex          filterEntry.1    INTEGER         read-only       mandatory
-filterChannelIndex   filterEntry.2    INTEGER         read-write      mandatory
-filterPktDataOffset  filterEntry.3    INTEGER         read-write      mandatory
-filterPktData        filterEntry.4    OctetString     read-write      mandatory
-filterPktDataMask    filterEntry.5    OctetString     read-write      mandatory
-filterPktDataNotMask filterEntry.6    OctetString     read-write      mandatory
-filterPktStatus      filterEntry.7    INTEGER         read-write      mandatory
-filterPktStatusMask  filterEntry.8    INTEGER         read-write      mandatory
-filterPktStatusNotMask filterEntry.9    INTEGER         read-write      mandatory
-filterOwner          filterEntry.10   DisplayString   read-write      mandatory
-filterStatus         filterEntry.11   INTEGER         read-write      mandatory
-channelTable         filter.2         Aggregate       not-accessible  mandatory
-channelEntry         channelTable.1   Aggregate       not-accessible  mandatory
-channelIndex         channelEntry.1   INTEGER         read-only       mandatory
-channelIfIndex       channelEntry.2   INTEGER         read-write      mandatory
-channelAcceptType    channelEntry.3   INTEGER         read-write      mandatory
-channelDataControl   channelEntry.4   INTEGER         read-write      mandatory
-channelTurnOnEventIndex channelEntry.5   INTEGER         read-write      mandatory
-channelTurnOffEventIndex channelEntry.6   INTEGER         read-write      mandatory
-channelEventIndex    channelEntry.7   INTEGER         read-write      mandatory
-channelEventStatus   channelEntry.8   INTEGER         read-write      mandatory
-channelMatches       channelEntry.9   Counter         read-only       mandatory
-channelDescription   channelEntry.10  DisplayString   read-write      mandatory
-channelOwner         channelEntry.11  DisplayString   read-write      mandatory
-channelStatus        channelEntry.12  INTEGER         read-write      mandatory
-bufferControlTable   capture.1        Aggregate       not-accessible  mandatory
-bufferControlEntry   bufferControlTable.1 Aggregate       not-accessible  mandatory
-bufferControlIndex   bufferControlEntry.1 INTEGER         read-only       mandatory
-bufferControlChannelIndex bufferControlEntry.2 INTEGER         read-write      mandatory
-bufferControlFullStatus bufferControlEntry.3 INTEGER         read-only       mandatory
-bufferControlFullAction bufferControlEntry.4 INTEGER         read-write      mandatory
-bufferControlCaptureSliceSize bufferControlEntry.5 INTEGER         read-write      mandatory
-bufferControlDownloadSliceSize bufferControlEntry.6 INTEGER         read-write      mandatory
-bufferControlDownloadOffset bufferControlEntry.7 INTEGER         read-write      mandatory
-bufferControlMaxOctetsRequested bufferControlEntry.8 INTEGER         read-write      mandatory
-bufferControlMaxOctetsGranted bufferControlEntry.9 INTEGER         read-only       mandatory
-bufferControlCapturedPackets bufferControlEntry.10 INTEGER         read-only       mandatory
-bufferControlTurnOnTime bufferControlEntry.11 TimeTicks       read-only       mandatory
-bufferControlOwner   bufferControlEntry.12 DisplayString   read-write      mandatory
-bufferControlStatus  bufferControlEntry.13 INTEGER         read-write      mandatory
-captureBufferTable   capture.2        Aggregate       not-accessible  mandatory
-captureBufferEntry   captureBufferTable.1 Aggregate       not-accessible  mandatory
-captureBufferControlIndex captureBufferEntry.1 INTEGER         read-only       mandatory
-captureBufferIndex   captureBufferEntry.2 INTEGER         read-only       mandatory
-captureBufferPacketID captureBufferEntry.3 INTEGER         read-only       mandatory
-captureBufferPacketData captureBufferEntry.4 OctetString     read-only       mandatory
-captureBufferPacketLength captureBufferEntry.5 INTEGER         read-only       mandatory
-captureBufferPacketTime captureBufferEntry.6 INTEGER         read-only       mandatory
-captureBufferPacketStatus captureBufferEntry.7 INTEGER         read-only       mandatory
-eventTable           event.1          Aggregate       not-accessible  mandatory
-eventEntry           eventTable.1     Aggregate       not-accessible  mandatory
-eventIndex           eventEntry.1     INTEGER         read-only       mandatory
-eventDescription     eventEntry.2     DisplayString   read-write      mandatory
-eventType            eventEntry.3     INTEGER         read-write      mandatory
-eventCommunity       eventEntry.4     OctetString     read-write      mandatory
-eventLastTimeSent    eventEntry.5     TimeTicks       read-only       mandatory
-eventOwner           eventEntry.6     DisplayString   read-write      mandatory
-eventStatus          eventEntry.7     INTEGER         read-write      mandatory
-logTable             event.2          Aggregate       not-accessible  mandatory
-logEntry             logTable.1       Aggregate       not-accessible  mandatory
-logEventIndex        logEntry.1       INTEGER         read-only       mandatory
-logIndex             logEntry.2       INTEGER         read-only       mandatory
-logTime              logEntry.3       TimeTicks       read-only       mandatory
-logDescription       logEntry.4       DisplayString   read-only       mandatory
-
-
 -- automatically generated by mosy 7.0 #62 (dbc), do not edit!
 
 -- object definitions compiled from SNMP-REPEATER-MIB
@@ -1638,30 +1998,5 @@
 exprExpr             exprEntry.3      OctetString     read-write      mandatory
 exprStatus           exprEntry.4      INTEGER         read-only       mandatory
 exprHints            exprEntry.5      DisplayString   read-only       mandatory
-
-
--- automatically generated by mosy 7.0 #69 (obel2), do not edit!
-
--- object definitions compiled from ApplicationMib { iso 3 6 1 4 1 453 1 1  }
-
-isode-consortium     enterprises.453
-application-mib      isode-consortium.2
-application          application-mib.1
-mta                  application-mib.2
-dsa                  application-mib.3
-
-distinguishedName    application.1    DisplayString   read-write      mandatory
-applicationStatus    application.2    INTEGER         read-only       mandatory
-applicationUptime    application.3    TimeTicks       read-only       mandatory
-inboundAssociations  application.4    Counter         read-only       mandatory
-outboundAssociations application.5    Counter         read-only       mandatory
-numberMessages       mta.1            Counter         read-only       mandatory
-volumeMessages       mta.2            Counter         read-only       mandatory
-submittedMessages    mta.3            Counter         read-only       mandatory
-deliveredMessages    mta.4            Counter         read-only       mandatory
-operations           dsa.1            Counter         read-only       mandatory
-masterEntries        dsa.2            Counter         read-only       mandatory
-copyEntries          dsa.3            Counter         read-only       mandatory
-cacheEntries         dsa.4            Counter         read-only       mandatory
 
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/snmp/snmpd.c isode-8.0/snmp/snmpd.c
--- old/isode-8.0/snmp/snmpd.c	Tue Jun 16 13:38:52 1992
+++ isode-8.0/snmp/snmpd.c	Mon Aug 23 16:00:34 1993
@@ -319,7 +319,9 @@
 			    failed++;
 			    continue;
 			}
+#ifdef FIOCLEX
 			(void) ioctl (udp, FIOCLEX, NULLCP);
+#endif
 			if (udp >= nfds)
 			    nfds = udp + 1;
 			FD_SET (udp, &ifds);
@@ -361,7 +363,9 @@
 			    failed++;
 			    continue;
 			}
+#ifdef FIOCLEX
 			(void) ioctl (clts, FIOCLEX, NULLCP);
+#endif
 			if (clts >= nfds)
 			    nfds = clts + 1;
 			FD_SET (clts, &ifds);
@@ -425,7 +429,9 @@
 	if (smux_enabled) {
 	    if ((smux = start_tcp_server (lsock, SOMAXCONN, 0, 0)) == NOTOK)
 		adios ("failed", "start_tcp_server for SMUX");
+#ifdef FIOCLEX
 	    (void) ioctl (smux, FIOCLEX, NULLCP);
+#endif
 	    if (smux >= nfds)
 		nfds = smux + 1;
 	    FD_SET (smux, &ifds);
@@ -475,7 +481,9 @@
 	if (smux != NOTOK
 		&& FD_ISSET (smux, &rfds)
 	        && (fd = start_smux ()) != NOTOK) {
+#ifdef FIOCLEX
 	    (void) ioctl (fd, FIOCLEX, NULLCP);
+#endif
 	    if (fd >= nfds)
 		nfds = fd + 1;
 	    FD_SET (fd, &ifds);
@@ -494,7 +502,9 @@
 
 #ifdef	COTS
 	if (vecp > 0 && (fd = start_tsap (vecp, vec)) != NOTOK) {
+#ifdef FIOCLEX
 	    (void) ioctl (fd, FIOCLEX, NULLCP);
+#endif
 	    if (fd >= nfds)
 		nfds = fd + 1;
 	    FD_SET (fd, &ifds);
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/ssap/Makefile isode-8.0/ssap/Makefile
--- old/isode-8.0/ssap/Makefile	Tue Jun 16 13:39:41 1992
+++ isode-8.0/ssap/Makefile	Tue Aug 24 11:53:19 1993
@@ -66,6 +66,18 @@
 
 inst-libssap:	$(LIBDIR)libssap.a $(LINTDIR)llib-lssap
 
+zap-ssap:
+		-rm -f $(OFILES) libssap.a ssapvrsn.o
+
+linux-lib:	zap-ssap ../jump/libssap.a
+
+../jump/libssap.a:	libssap.a
+		-rm -f $@
+		cp libssap.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libssap.a:	libssap.a
 		-rm -f $@
 		cp libssap.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/support/Makefile isode-8.0/support/Makefile
--- old/isode-8.0/support/Makefile	Tue Jun 16 13:40:09 1992
+++ isode-8.0/support/Makefile	Tue Aug 31 10:54:11 1993
@@ -83,6 +83,7 @@
 		-@echo ""
 
 tsapd:		xtsapd
+		:
 
 xtsapd:		tsapd.o $(TOPDIR)libisode.a
 		$(LDCC) $(LDFLAGS) -o $@ tsapd.o $(LIBISODE) $(LSOCKET)
@@ -103,6 +104,7 @@
 		-@echo ""
 
 iaed:		xiaed
+		:
 
 xiaed:		iaed.o $(TOPDIR)libdsap.a $(TOPDIR)libisode.a
 		$(LDCC) $(LDFLAGS) -o $@ iaed.o \
@@ -140,6 +142,7 @@
 		-@echo ""
 
 isore:		xisore
+		:
 
 xisore:		isore.o
 		$(LDCC) $(LDFLAGS) -o $@ isore.o $(TOPDIR)libcompat.a \
@@ -173,6 +176,7 @@
 		-@echo ""
 
 isod:		xisod
+		:
 
 xisod:		isod.o $(TOPDIR)libisode.a
 		$(LDCC) $(LDFLAGS) -o $@ isod.o $(LIBISODE) $(LSOCKET)
@@ -197,6 +201,7 @@
 		-@echo ""
 
 isoc:		xisoc
+		:
 
 xisoc:		isoc.o $(TOPDIR)libisode.a
 		$(LDCC) $(LDFLAGS) -o $@ isoc.o $(LIBISODE) $(LSOCKET)
@@ -213,6 +218,15 @@
 
 inst-libisode:	$(LIBDIR)libisode.a $(LINTDIR)llib-lisode
 
+zap-vrsn:
+		-rm -f isodevrsn.o
+
+linux-lib:	zap-vrsn ../jump/libisode.a
+
+../jump/libisode.a:	isodevrsn.o
+		ar r $@ isodevrsn.o
+		-@echo ""
+
 $(LIBDIR)libisode.a:	libisode.a
 		@for i in libisode.* ;\
 		do \
@@ -372,8 +386,8 @@
 # lppd
 ################################################################
 
-LPP-LIBES=	$(TOPDIR)libisode-lpp.a
-LPP-LLIBS=	$(TOPDIR)llib-lisode-lpp
+LPP-LIBES=	$(TOPDIR)libpsap2-lpp.a $(TOPDIR)libisode.a
+LPP-LLIBS=	$(TOPDIR)llib-psap2-lpp $(TOPDIR)llib-lisode
 
 inst-lppd:	$(SBINDIR)lppd
 
@@ -385,6 +399,7 @@
 		-@echo ""
 
 lppd:		xlppd
+		:
 
 xlppd:		lppd.o $(LPP-LIBES)
 		$(LDCC) $(LDFLAGS) -o $@ lppd.o $(LPP-LIBES) $(LSOCKET)
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/support/isore.c isode-8.0/support/isore.c
--- old/isode-8.0/support/isore.c	Tue Jun 16 13:40:16 1992
+++ isode-8.0/support/isore.c	Thu Aug 19 16:26:48 1993
@@ -30,6 +30,10 @@
 #include "general.h"
 #include "manifest.h"
 
+#ifndef SIGEMT
+#define SIGEMT	SIGUSR1
+#endif
+
 /*    MAIN */
 
 static SFD	EMTser ();
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/support/tsapd.c isode-8.0/support/tsapd.c
--- old/isode-8.0/support/tsapd.c	Thu Dec  9 17:14:08 1993
+++ isode-8.0/support/tsapd.c	Tue Jun 16 13:40:21 1992
@@ -332,18 +332,9 @@
 		== NULL) {
 #else
     for (is = iae; is < iz; is++)
-	
-#if 0
-	/* THIS doesn't work - JPO */
 	if (tsap_addr_cmp (&is -> is_addr, &ts -> ts_called) == OK)
 	    break;
-#else
-        if (is -> is_addr.ta_selectlen == ts -> ts_called.ta_selectlen
-	    && bcmp (is -> is_addr.ta_selector,
-		     ts -> ts_called.ta_selector,
-		     is -> is_addr.ta_selectlen) == 0)
-	    break;
-#endif
+
     if (is >= iz) {
 #endif
 	    (void) sprintf (buffer, "OSI service tsap/%s not found",
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/tsap/Makefile isode-8.0/tsap/Makefile
--- old/isode-8.0/tsap/Makefile	Tue Jun 16 13:40:41 1992
+++ isode-8.0/tsap/Makefile	Tue Aug 24 11:53:31 1993
@@ -63,6 +63,18 @@
 
 inst-libtsap:	$(LIBDIR)libtsap.a $(LINTDIR)llib-ltsap
 
+zap-tsap:
+		-rm -f $(OFILES) libtsap.a tsapvrsn.o
+
+linux-lib:	zap-tsap ../jump/libtsap.a
+
+../jump/libtsap.a:	libtsap.a
+		-rm -f $@
+		cp libtsap.a $@
+		@$(UTILDIR)make-lib.sh $(SYSTEM) $@ -ranlib
+		-@ls -gls $@
+		-@echo ""
+
 $(LIBDIR)libtsap.a:	libtsap.a
 		-rm -f $@
 		cp libtsap.a $@
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/tsap/ts2tcp.c isode-8.0/tsap/ts2tcp.c
--- old/isode-8.0/tsap/ts2tcp.c	Tue Jun 16 13:40:45 1992
+++ isode-8.0/tsap/ts2tcp.c	Tue Sep 14 10:48:33 1993
@@ -37,7 +37,7 @@
 #ifdef	BSD42
 #include <sys/ioctl.h>
 #endif
-#ifdef	SYS5
+#if defined(SYS5) || defined(__linux__)
 #include <fcntl.h>
 #endif
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/tsap/tsaprovider.c isode-8.0/tsap/tsaprovider.c
--- old/isode-8.0/tsap/tsaprovider.c	Tue Jun 16 13:40:51 1992
+++ isode-8.0/tsap/tsaprovider.c	Fri Sep 10 16:06:28 1993
@@ -36,6 +36,9 @@
 #include "sys.file.h"
 #include <sys/stat.h>
 
+#ifdef __linux__
+#include <linux/sockios.h>
+#endif
 
 #define	selmask(fd,m,n) \
 { \
@@ -421,7 +424,7 @@
     register struct TSAPdisconnect *td = &tds;
 
 #ifndef	BSDSIGS
-    (void) signal (SIGEMT, DATAser);
+    (void) signal (_SIGIO, DATAser);
 
     smask = sigioblock ();
 #endif
@@ -472,7 +475,7 @@
     }
 
 #ifndef	SIGPOLL
-    (void) kill (TPid, SIGEMT);
+    (void) kill (TPid, _SIGIO);
 #endif
 
 #ifndef	BSDSIGS
@@ -514,10 +517,10 @@
 	return tsaplose (td, DR_CONGEST, NULLCP, "you lose");
     if (!inited) {
 #ifndef	BSDSIGS
-	int    smask = sigsetmask (sigblock (0) & ~sigmask (SIGEMT));
+	int    smask = sigsetmask (sigblock (0) & ~sigmask (_SIGIO));
 #endif
 
-	(void) signal (SIGEMT, DATAser);
+	(void) signal (_SIGIO, DATAser);
 #ifndef	BSDSIGS
 	(void) sigiomask (smask);
 #endif
@@ -542,7 +545,7 @@
 		continue;
 
 	    case OK: 
-		(void) signal (SIGEMT, SIG_DFL);
+		(void) signal (_SIGIO, SIG_DFL);
 		(void) execv (*is -> is_vec, is -> is_vec);
 		_exit (1);
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/util/version.sh isode-8.0/util/version.sh
--- old/isode-8.0/util/version.sh	Tue Jun 16 11:12:10 1992
+++ isode-8.0/util/version.sh	Thu Aug 19 15:39:29 1993
@@ -1,7 +1,7 @@
 : run this script through /bin/sh
 
 : this hacks past a bug in make...
-exec 3<&- 4<&- 5<&- 6<&- 7<&-
+#exec 3<&- 4<&- 5<&- 6<&- 7<&-
 
 OFS="$IFS" IFS=:
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/vt/Makefile isode-8.0/vt/Makefile
--- old/isode-8.0/vt/Makefile	Tue Jun 16 13:41:09 1992
+++ isode-8.0/vt/Makefile	Mon Aug 23 15:16:14 1993
@@ -74,6 +74,7 @@
 		-@echo ""
 
 vtd:		xvtd
+		:
 
 xvtd:		vtd.o $(OFILES) libvt.a $(LIBES)
 		$(LDCC) $(LDFLAGS) -o $@ vtd.o $(OFILES) libvt.a \
@@ -108,6 +109,7 @@
 		-@echo ""
 
 vt:		xvt
+		:
 
 xvt:		vt.o $(OFILES) libvt.a $(LIBES)
 		$(LDCC) $(LDFLAGS) -o $@ vt.o $(OFILES) libvt.a \
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/vt/map.c isode-8.0/vt/map.c
--- old/isode-8.0/vt/map.c	Tue Jun 16 13:41:11 1992
+++ isode-8.0/vt/map.c	Mon Aug 23 14:38:05 1993
@@ -37,7 +37,12 @@
 #include <sys/ioctl.h>
 #endif
 #ifdef TERMIOS
+#ifdef __linux__
+#include <termios.h>
+#include <unistd.h>
+#else
 #include <sys/termios.h>
+#endif
 #endif
 #include <fcntl.h>
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/vt/vt.c isode-8.0/vt/vt.c
--- old/isode-8.0/vt/vt.c	Tue Jun 16 13:41:20 1992
+++ isode-8.0/vt/vt.c	Mon Aug 23 14:32:47 1993
@@ -34,7 +34,11 @@
 #include <sys/ioctl.h>
 #endif
 #ifdef TERMIOS
+#ifdef __linux__
+#include <termios.h>
+#else
 #include <sys/termios.h>
+#endif
 #endif
 #include <ctype.h>
 #include <setjmp.h>
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/vt/vtd.c isode-8.0/vt/vtd.c
--- old/isode-8.0/vt/vtd.c	Tue Jun 16 13:41:21 1992
+++ isode-8.0/vt/vtd.c	Fri Aug 27 09:29:56 1993
@@ -36,7 +36,12 @@
 #include <sys/ioctl.h>
 #endif
 #ifdef	TERMIOS
+#ifdef __linux__
+#include <termios.h>
+#include <unistd.h>
+#else
 #include <sys/termios.h>
+#endif
 #ifdef BSD44
 #include <sys/ttydefaults.h>
 #include <sys/stat.h>
@@ -61,13 +66,17 @@
 #include <varargs.h>
 
 #define	BELL	'\07'
-#ifndef	SUNOS4
-#define BANNER	"\r\n\r\n4.2 BSD UNIX (%s)\r\n\r\n\r%s"
-#else
+#ifdef	SUNOS4
 #define BANNER	"\r\n\r\nSunOS UNIX (%s)\r\n\r\n\r%s"
+#else
+#ifdef __linux__
+#define BANNER	"\r\n\r\nLinux (%s)\r\n\r\n\r%s"
+#else
+#define BANNER	"\r\n\r\n4.2 BSD UNIX (%s)\r\n\r\n\r%s"
 #endif
+#endif
 
-#if !defined(SYS5) && !defined(BSD44) && !defined(_AIX)
+#if !defined(SYS5) && !defined(BSD44) && !defined(_AIX) && !defined(__linux__)
 void	vhangup();
 #endif
 
@@ -149,6 +158,9 @@
 #ifndef TERMIOS
 	struct sgttyb b;
 #endif
+#ifdef __linux__
+	struct termios b;
+#endif
 
     if (myname = rindex (*argv, '/'))
 	myname++;
@@ -199,7 +211,7 @@
 	}
 	else
 		exit(1);
-#ifdef TERMIOS
+#if defined(TERMIOS) && !defined(__linux__)
 	na_image = 0;
 	nego_state = 0;			/*Start off in Local echo*/
 	i = forkpty(&p, line, NULL, NULL);
@@ -231,6 +243,9 @@
 gotpty:
 
 	cp[strlen("/dev/")] = 't';
+#ifdef __linux__
+	setsid();
+#else
 	t = open("/dev/tty", 2);
 	if (t >= 0) {
 		if (ioctl(t, TIOCNOTTY, 0) == -1) {
@@ -238,9 +253,24 @@
 		}
 		(void)close(t);
 	}
+#endif
 	t = open(cp, 2);
 	if (t < 0)
 		fatalperror(f, cp, errno);
+#ifdef __linux__
+	if (tcgetattr(t, (char*)&b) == -1) {
+		perror("tcgetattr");
+		adios(NULLCP, "tcgetattr failed");
+	}
+	if (telnet_profile)
+		b.c_lflag &= ~ECHO;
+	else
+		b.c_lflag |= ECHO;	/*Remote echo for Default*/
+	if (tcsetattr(t, TCSAFLUSH, (char*)&b) == -1) {
+		perror("tcsetattr");
+		adios(NULLCP, "tcsetattr failed");
+	}
+#else
 	if (ioctl(t, TIOCGETP, (char*)&b) == -1) {
 		perror("ioctl (TIOCGETP)");
 		adios(NULLCP, "ioctl failed (TIOCGETP)");
@@ -262,6 +292,7 @@
 		perror("ioctl (TIOCSETP)");
 		adios(NULLCP, "ioctl failed (TIOCSETP)");
 	}
+#endif
 	na_image = 0;
 	nego_state = 0;			/*Start off in Local echo*/
 
diff --new-file --recursive --unified --exclude=version.local --exclude=update.* old/isode-8.0/vt/vtd.c isode-8.0/vt/vtd.c
--- old/isode-8.0/quipu/sys_init.c	Tue Jun 16 13:41:21 1992
+++ isode-8.0/quipu/sys_init.c	Fri Aug 27 09:29:56 1993
@@ -107,7 +107,7 @@
 	    && ((statbuf.st_mode & S_IFMT) == S_IFDIR)) {
 		    /* tmpdir exists - clean it */
 		struct dirent **namelist;
-		(void) _scandir(edbtmp_buf, &namelist, rmFiles, NULLIFP);
+		(void) scandir(edbtmp_buf, &namelist, rmFiles, NULLIFP);
 		if (namelist)
 		    free((char *) namelist);
 
That's it. End of patch. If you've actually *read* all that - congratulations!
